package androidx.window.embedding;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.content.res.XmlResourceParser;
import androidx.window.R;
import b4.c0;
import com.yalantis.ucrop.view.CropImageView;
import java.util.HashSet;
import java.util.Set;
import kotlin.jvm.internal.i;
import q4.n;

public final class SplitRuleParser {
    private final ComponentName buildClassName(String str, CharSequence charSequence) {
        if (charSequence != null) {
            if (!(charSequence.length() == 0)) {
                String obj = charSequence.toString();
                if (obj.charAt(0) == '.') {
                    return new ComponentName(str, i.j(str, obj));
                }
                int i5 = n.z(obj, '/', 0, false, 6, null);
                if (i5 > 0) {
                    str = obj.substring(0, i5);
                    i.d(str, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                    obj = obj.substring(i5 + 1);
                    i.d(obj, "(this as java.lang.String).substring(startIndex)");
                }
                if (i.a(obj, "*") || n.z(obj, '.', 0, false, 6, null) >= 0) {
                    return new ComponentName(str, obj);
                }
                return new ComponentName(str, str + '.' + obj);
            }
        }
        throw new IllegalArgumentException("Activity name must not be null");
    }

    private final ActivityFilter parseActivityFilter(Context context, XmlResourceParser xmlResourceParser) {
        TypedArray obtainStyledAttributes = context.getTheme().obtainStyledAttributes(xmlResourceParser, R.styleable.ActivityFilter, 0, 0);
        String string = obtainStyledAttributes.getString(R.styleable.ActivityFilter_activityName);
        String string2 = obtainStyledAttributes.getString(R.styleable.ActivityFilter_activityAction);
        String packageName = context.getApplicationContext().getPackageName();
        i.d(packageName, "packageName");
        return new ActivityFilter(buildClassName(packageName, string), string2);
    }

    private final ActivityRule parseSplitActivityRule(Context context, XmlResourceParser xmlResourceParser) {
        return new ActivityRule(c0.b(), context.getTheme().obtainStyledAttributes(xmlResourceParser, R.styleable.ActivityRule, 0, 0).getBoolean(R.styleable.ActivityRule_alwaysExpand, false));
    }

    private final SplitPairFilter parseSplitPairFilter(Context context, XmlResourceParser xmlResourceParser) {
        TypedArray obtainStyledAttributes = context.getTheme().obtainStyledAttributes(xmlResourceParser, R.styleable.SplitPairFilter, 0, 0);
        String string = obtainStyledAttributes.getString(R.styleable.SplitPairFilter_primaryActivityName);
        String string2 = obtainStyledAttributes.getString(R.styleable.SplitPairFilter_secondaryActivityName);
        String string3 = obtainStyledAttributes.getString(R.styleable.SplitPairFilter_secondaryActivityAction);
        String packageName = context.getApplicationContext().getPackageName();
        i.d(packageName, "packageName");
        return new SplitPairFilter(buildClassName(packageName, string), buildClassName(packageName, string2), string3);
    }

    private final SplitPairRule parseSplitPairRule(Context context, XmlResourceParser xmlResourceParser) {
        TypedArray obtainStyledAttributes = context.getTheme().obtainStyledAttributes(xmlResourceParser, R.styleable.SplitPairRule, 0, 0);
        float f5 = obtainStyledAttributes.getFloat(R.styleable.SplitPairRule_splitRatio, CropImageView.DEFAULT_ASPECT_RATIO);
        int dimension = (int) obtainStyledAttributes.getDimension(R.styleable.SplitPairRule_splitMinWidth, CropImageView.DEFAULT_ASPECT_RATIO);
        int dimension2 = (int) obtainStyledAttributes.getDimension(R.styleable.SplitPairRule_splitMinSmallestWidth, CropImageView.DEFAULT_ASPECT_RATIO);
        int i5 = obtainStyledAttributes.getInt(R.styleable.SplitPairRule_splitLayoutDirection, 3);
        return new SplitPairRule(c0.b(), obtainStyledAttributes.getBoolean(R.styleable.SplitPairRule_finishPrimaryWithSecondary, false), obtainStyledAttributes.getBoolean(R.styleable.SplitPairRule_finishSecondaryWithPrimary, true), obtainStyledAttributes.getBoolean(R.styleable.SplitPairRule_clearTop, false), dimension, dimension2, f5, i5);
    }

    private final SplitPlaceholderRule parseSplitPlaceholderRule(Context context, XmlResourceParser xmlResourceParser) {
        TypedArray obtainStyledAttributes = context.getTheme().obtainStyledAttributes(xmlResourceParser, R.styleable.SplitPlaceholderRule, 0, 0);
        String string = obtainStyledAttributes.getString(R.styleable.SplitPlaceholderRule_placeholderActivityName);
        float f5 = obtainStyledAttributes.getFloat(R.styleable.SplitPlaceholderRule_splitRatio, CropImageView.DEFAULT_ASPECT_RATIO);
        int dimension = (int) obtainStyledAttributes.getDimension(R.styleable.SplitPlaceholderRule_splitMinWidth, CropImageView.DEFAULT_ASPECT_RATIO);
        int dimension2 = (int) obtainStyledAttributes.getDimension(R.styleable.SplitPlaceholderRule_splitMinSmallestWidth, CropImageView.DEFAULT_ASPECT_RATIO);
        int i5 = obtainStyledAttributes.getInt(R.styleable.SplitPlaceholderRule_splitLayoutDirection, 3);
        String packageName = context.getApplicationContext().getPackageName();
        i.d(packageName, "packageName");
        ComponentName buildClassName = buildClassName(packageName, string);
        Set b5 = c0.b();
        Intent component = new Intent().setComponent(buildClassName);
        i.d(component, "Intent().setComponent(pl…eholderActivityClassName)");
        return new SplitPlaceholderRule(b5, component, dimension, dimension2, f5, i5);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:62:0x00e5, code lost:
        continue;
     */
    private final Set<EmbeddingRule> parseSplitXml(Context context, int i5) {
        String name;
        SplitPlaceholderRule plus$window_release;
        ActivityRule plus$window_release2;
        SplitPairRule splitPairRule;
        try {
            XmlResourceParser xml = context.getResources().getXml(i5);
            i.d(xml, "resources.getXml(splitResourceId)");
            HashSet hashSet = new HashSet();
            int depth = xml.getDepth();
            int next = xml.next();
            ActivityRule activityRule = null;
            SplitPairRule splitPairRule2 = null;
            SplitPlaceholderRule splitPlaceholderRule = null;
            while (next != 1 && (next != 3 || xml.getDepth() > depth)) {
                if (xml.getEventType() == 2 && !i.a("split-config", xml.getName()) && (name = xml.getName()) != null) {
                    switch (name.hashCode()) {
                        case 511422343:
                            if (!name.equals("ActivityFilter")) {
                                continue;
                            } else if (activityRule != null || splitPlaceholderRule != null) {
                                ActivityFilter parseActivityFilter = parseActivityFilter(context, xml);
                                if (activityRule == null) {
                                    if (splitPlaceholderRule == null) {
                                        break;
                                    } else {
                                        hashSet.remove(splitPlaceholderRule);
                                        plus$window_release = splitPlaceholderRule.plus$window_release(parseActivityFilter);
                                        hashSet.add(plus$window_release);
                                        splitPlaceholderRule = plus$window_release;
                                        break;
                                    }
                                } else {
                                    hashSet.remove(activityRule);
                                    plus$window_release2 = activityRule.plus$window_release(parseActivityFilter);
                                    hashSet.add(plus$window_release2);
                                    activityRule = plus$window_release2;
                                    break;
                                }
                            } else {
                                throw new IllegalArgumentException("Found orphaned ActivityFilter");
                            }
                        case 520447504:
                            if (name.equals("SplitPairRule")) {
                                splitPairRule = parseSplitPairRule(context, xml);
                                hashSet.add(splitPairRule);
                                activityRule = null;
                                splitPlaceholderRule = null;
                                splitPairRule2 = splitPairRule;
                                break;
                            } else {
                                break;
                            }
                        case 1579230604:
                            if (!name.equals("SplitPairFilter")) {
                                continue;
                            } else if (splitPairRule2 != null) {
                                SplitPairFilter parseSplitPairFilter = parseSplitPairFilter(context, xml);
                                hashSet.remove(splitPairRule2);
                                splitPairRule = splitPairRule2.plus$window_release(parseSplitPairFilter);
                                hashSet.add(splitPairRule);
                                splitPairRule2 = splitPairRule;
                                break;
                            } else {
                                throw new IllegalArgumentException("Found orphaned SplitPairFilter outside of SplitPairRule");
                            }
                        case 1793077963:
                            if (name.equals("ActivityRule")) {
                                plus$window_release2 = parseSplitActivityRule(context, xml);
                                hashSet.add(plus$window_release2);
                                splitPairRule2 = null;
                                splitPlaceholderRule = null;
                                activityRule = plus$window_release2;
                                break;
                            } else {
                                break;
                            }
                        case 2050988213:
                            if (name.equals("SplitPlaceholderRule")) {
                                plus$window_release = parseSplitPlaceholderRule(context, xml);
                                hashSet.add(plus$window_release);
                                activityRule = null;
                                splitPairRule2 = null;
                                splitPlaceholderRule = plus$window_release;
                                break;
                            } else {
                                break;
                            }
                    }
                }
                next = xml.next();
            }
            return hashSet;
        } catch (Resources.NotFoundException unused) {
            return null;
        }
    }

    public final Set<EmbeddingRule> parseSplitRules$window_release(Context context, int i5) {
        i.e(context, "context");
        return parseSplitXml(context, i5);
    }
}
