package com.luck.picture.lib;

import android.content.Context;
import android.content.Intent;
import android.content.res.Configuration;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.View;
import android.widget.TextView;
import androidx.appcompat.app.d;
import com.luck.picture.lib.app.PictureAppMaster;
import com.luck.picture.lib.compress.Luban;
import com.luck.picture.lib.compress.OnCompressListener;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.dialog.PictureCustomDialog;
import com.luck.picture.lib.dialog.PictureLoadingDialog;
import com.luck.picture.lib.engine.CompressEngine;
import com.luck.picture.lib.engine.PictureSelectorEngine;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.immersive.ImmersiveManage;
import com.luck.picture.lib.immersive.NavBarUtils;
import com.luck.picture.lib.io.ArrayPoolProvide;
import com.luck.picture.lib.language.PictureLanguageUtils;
import com.luck.picture.lib.listener.OnCallbackListener;
import com.luck.picture.lib.listener.OnChooseLimitCallback;
import com.luck.picture.lib.listener.OnResultCallbackListener;
import com.luck.picture.lib.model.IBridgeMediaLoader;
import com.luck.picture.lib.model.LocalMediaLoader;
import com.luck.picture.lib.model.LocalMediaPageLoader;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.style.PictureSelectorUIStyle;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.AndroidQTransformUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.CameraFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.VoiceUtils;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public abstract class PictureBaseActivity extends d {
    protected int colorPrimary;
    protected int colorPrimaryDark;
    protected PictureSelectionConfig config;
    protected View container;
    protected boolean isHasMore = true;
    protected boolean isOnSaveInstanceState;
    protected Handler mHandler = new Handler(Looper.getMainLooper());
    protected IBridgeMediaLoader mLoader;
    protected PictureLoadingDialog mLoadingDialog;
    protected int mPage = 1;
    protected boolean numComplete;
    protected boolean openWhiteStatusBar;
    protected List<LocalMedia> selectionMedias = new ArrayList();

    private void compressToLuban(final List<LocalMedia> list) {
        if (this.config.synOrAsy) {
            PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<LocalMedia>>() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass2 */

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public List<LocalMedia> doInBackground() {
                    return Luban.with(PictureBaseActivity.this.getContext()).loadMediaData(list).isCamera(PictureBaseActivity.this.config.camera).setTargetDir(PictureBaseActivity.this.config.compressSavePath).setCompressQuality(PictureBaseActivity.this.config.compressQuality).isAutoRotating(PictureBaseActivity.this.config.isAutoRotating).setFocusAlpha(PictureBaseActivity.this.config.focusAlpha).setNewCompressFileName(PictureBaseActivity.this.config.renameCompressFileName).ignoreBy(PictureBaseActivity.this.config.minimumCompressSize).get();
                }

                public void onSuccess(List<LocalMedia> list) {
                    PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                    PictureBaseActivity.this.onResult(list);
                }
            });
        } else {
            Luban.with(this).loadMediaData(list).ignoreBy(this.config.minimumCompressSize).isCamera(this.config.camera).setCompressQuality(this.config.compressQuality).setTargetDir(this.config.compressSavePath).isAutoRotating(this.config.isAutoRotating).setFocusAlpha(this.config.focusAlpha).setNewCompressFileName(this.config.renameCompressFileName).setCompressListener(new OnCompressListener() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass3 */

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onError(Throwable th) {
                    PictureBaseActivity.this.onResult(list);
                }

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onStart() {
                }

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onSuccess(List<LocalMedia> list) {
                    PictureBaseActivity.this.onResult(list);
                }
            }).launch();
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:40:0x00a4  */
    /* JADX WARNING: Removed duplicated region for block: B:42:? A[RETURN, SYNTHETIC] */
    private void initConfig() {
        PictureSelectionConfig pictureSelectionConfig;
        boolean z4;
        if (this.config.selectionMedias != null) {
            this.selectionMedias.clear();
            this.selectionMedias.addAll(this.config.selectionMedias);
        }
        PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
        if (pictureSelectorUIStyle != null) {
            this.openWhiteStatusBar = pictureSelectorUIStyle.picture_statusBarChangeTextColor;
            int i5 = pictureSelectorUIStyle.picture_top_titleBarBackgroundColor;
            if (i5 != 0) {
                this.colorPrimary = i5;
            }
            int i6 = pictureSelectorUIStyle.picture_statusBarBackgroundColor;
            if (i6 != 0) {
                this.colorPrimaryDark = i6;
            }
            this.numComplete = pictureSelectorUIStyle.picture_switchSelectTotalStyle;
            pictureSelectionConfig = this.config;
            z4 = pictureSelectorUIStyle.picture_switchSelectNumberStyle;
        } else {
            PictureParameterStyle pictureParameterStyle = PictureSelectionConfig.style;
            if (pictureParameterStyle != null) {
                this.openWhiteStatusBar = pictureParameterStyle.isChangeStatusBarFontColor;
                int i7 = pictureParameterStyle.pictureTitleBarBackgroundColor;
                if (i7 != 0) {
                    this.colorPrimary = i7;
                }
                int i8 = pictureParameterStyle.pictureStatusBarColor;
                if (i8 != 0) {
                    this.colorPrimaryDark = i8;
                }
                this.numComplete = pictureParameterStyle.isOpenCompletedNumStyle;
                pictureSelectionConfig = this.config;
                z4 = pictureParameterStyle.isOpenCheckNumStyle;
            } else {
                boolean z5 = this.config.isChangeStatusBarFontColor;
                this.openWhiteStatusBar = z5;
                if (!z5) {
                    this.openWhiteStatusBar = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_statusFontColor);
                }
                boolean z6 = this.config.isOpenStyleNumComplete;
                this.numComplete = z6;
                if (!z6) {
                    this.numComplete = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_style_numComplete);
                }
                PictureSelectionConfig pictureSelectionConfig2 = this.config;
                boolean z7 = pictureSelectionConfig2.isOpenStyleCheckNumMode;
                pictureSelectionConfig2.checkNumMode = z7;
                if (!z7) {
                    pictureSelectionConfig2.checkNumMode = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_style_checkNumMode);
                }
                int i9 = this.config.titleBarBackgroundColor;
                if (i9 == 0) {
                    i9 = AttrsUtils.getTypeValueColor(this, R.attr.colorPrimary);
                }
                this.colorPrimary = i9;
                int i10 = this.config.pictureStatusBarColor;
                if (i10 == 0) {
                    i10 = AttrsUtils.getTypeValueColor(this, R.attr.colorPrimaryDark);
                }
                this.colorPrimaryDark = i10;
                if (!this.config.openClickSound) {
                    VoiceUtils.getInstance().init(getContext());
                    return;
                }
                return;
            }
        }
        pictureSelectionConfig.checkNumMode = z4;
        if (!this.config.openClickSound) {
        }
    }

    /* access modifiers changed from: private */
    public static /* synthetic */ int lambda$sortFolder$0(LocalMediaFolder localMediaFolder, LocalMediaFolder localMediaFolder2) {
        if (localMediaFolder.getData() == null || localMediaFolder2.getData() == null) {
            return 0;
        }
        return Integer.compare(localMediaFolder2.getImageNum(), localMediaFolder.getImageNum());
    }

    private void newCreateEngine() {
        PictureSelectorEngine pictureSelectorEngine;
        if (PictureSelectionConfig.imageEngine == null && (pictureSelectorEngine = PictureAppMaster.getInstance().getPictureSelectorEngine()) != null) {
            PictureSelectionConfig.imageEngine = pictureSelectorEngine.createEngine();
        }
    }

    private void newCreateResultCallbackListener() {
        PictureSelectorEngine pictureSelectorEngine;
        if (this.config.isCallbackMode && PictureSelectionConfig.listener == null && (pictureSelectorEngine = PictureAppMaster.getInstance().getPictureSelectorEngine()) != null) {
            PictureSelectionConfig.listener = pictureSelectorEngine.getResultCallbackListener();
        }
    }

    private void normalResult(List<LocalMedia> list) {
        int size = list.size();
        int i5 = 0;
        for (int i6 = 0; i6 < size; i6++) {
            LocalMedia localMedia = list.get(i6);
            if (localMedia != null && !TextUtils.isEmpty(localMedia.getPath())) {
                if (localMedia.isCut() && localMedia.isCompressed()) {
                    localMedia.setAndroidQToPath(localMedia.getCompressPath());
                }
                if (this.config.isCheckOriginalImage) {
                    localMedia.setOriginal(true);
                    localMedia.setOriginalPath(localMedia.getAndroidQToPath());
                }
            }
        }
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.camera && pictureSelectionConfig.selectionMode == 2) {
            if (list.size() > 0) {
                i5 = list.size() - 1;
            }
            list.addAll(i5, this.selectionMedias);
        }
        OnResultCallbackListener<LocalMedia> onResultCallbackListener = PictureSelectionConfig.listener;
        if (onResultCallbackListener != null) {
            onResultCallbackListener.onResult(list);
        } else {
            setResult(-1, PictureSelector.putIntentResult(list));
        }
        exit();
    }

    private void onResultToAndroidAsy(List<LocalMedia> list) {
        int size = list.size();
        boolean z4 = false;
        int i5 = 0;
        while (true) {
            if (i5 >= size) {
                break;
            }
            LocalMedia localMedia = list.get(i5);
            if (localMedia == null || TextUtils.isEmpty(localMedia.getPath()) || (!this.config.isCheckOriginalImage && (localMedia.isCut() || localMedia.isCompressed() || localMedia.isToSandboxPath()))) {
                i5++;
            }
        }
        z4 = true;
        if (z4) {
            startThreadCopySandbox(list);
        } else {
            normalResult(list);
        }
    }

    private void releaseResultListener() {
        if (this.config != null) {
            PictureSelectionConfig.destroy();
            PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
            ArrayPoolProvide.getInstance().clearMemory();
        }
    }

    private void startCustomCamera() {
        startActivityForResult(new Intent(this, PictureCustomCameraActivity.class), PictureConfig.REQUEST_CAMERA);
        overridePendingTransition(PictureSelectionConfig.windowAnimationStyle.activityEnterAnimation, R.anim.picture_anim_fade_in);
    }

    private void startThreadCopySandbox(final List<LocalMedia> list) {
        showPleaseDialog();
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<LocalMedia>>() {
            /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass4 */

            /* JADX WARNING: Removed duplicated region for block: B:28:0x0091  */
            /* JADX WARNING: Removed duplicated region for block: B:39:0x00c2 A[SYNTHETIC] */
            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public List<LocalMedia> doInBackground() {
                boolean z4;
                int size = list.size();
                for (int i5 = 0; i5 < size; i5++) {
                    LocalMedia localMedia = (LocalMedia) list.get(i5);
                    if (localMedia != null && !TextUtils.isEmpty(localMedia.getPath())) {
                        if (!(!localMedia.isCut() && !localMedia.isCompressed() && !localMedia.isToSandboxPath()) || !PictureMimeType.isContent(localMedia.getPath())) {
                            if (localMedia.isCut() && localMedia.isCompressed()) {
                                localMedia.setAndroidQToPath(localMedia.getCompressPath());
                            }
                        } else if (!PictureMimeType.isHasHttp(localMedia.getPath())) {
                            localMedia.setAndroidQToPath(AndroidQTransformUtils.copyPathToAndroidQ(PictureBaseActivity.this.getContext(), localMedia.getId(), localMedia.getPath(), localMedia.getWidth(), localMedia.getHeight(), localMedia.getMimeType(), PictureBaseActivity.this.config.cameraFileName));
                            z4 = true;
                            if (!PictureBaseActivity.this.config.isCheckOriginalImage) {
                                localMedia.setOriginal(true);
                                localMedia.setOriginalPath(z4 ? localMedia.getAndroidQToPath() : AndroidQTransformUtils.copyPathToAndroidQ(PictureBaseActivity.this.getContext(), localMedia.getId(), localMedia.getPath(), localMedia.getWidth(), localMedia.getHeight(), localMedia.getMimeType(), PictureBaseActivity.this.config.cameraFileName));
                            }
                        }
                        z4 = false;
                        if (!PictureBaseActivity.this.config.isCheckOriginalImage) {
                        }
                    }
                }
                return list;
            }

            public void onSuccess(List<LocalMedia> list) {
                PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                PictureBaseActivity.this.dismissDialog();
                if (list != null) {
                    PictureSelectionConfig pictureSelectionConfig = PictureBaseActivity.this.config;
                    if (pictureSelectionConfig.camera && pictureSelectionConfig.selectionMode == 2) {
                        list.addAll(list.size() > 0 ? list.size() - 1 : 0, PictureBaseActivity.this.selectionMedias);
                    }
                    OnResultCallbackListener<LocalMedia> onResultCallbackListener = PictureSelectionConfig.listener;
                    if (onResultCallbackListener != null) {
                        onResultCallbackListener.onResult(list);
                    } else {
                        PictureBaseActivity.this.setResult(-1, PictureSelector.putIntentResult(list));
                    }
                    PictureBaseActivity.this.exit();
                }
            }
        });
    }

    /* access modifiers changed from: protected */
    @Override // androidx.appcompat.app.d
    public void attachBaseContext(Context context) {
        int i5;
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (!(pictureSelectionConfig == null || (i5 = pictureSelectionConfig.language) == -2)) {
            context = PictureContextWrapper.wrap(context, i5);
        }
        super.attachBaseContext(context);
    }

    /* access modifiers changed from: protected */
    public void compressImage(List<LocalMedia> list) {
        CompressEngine compressEngine = PictureSelectionConfig.compressEngine;
        if (compressEngine != null) {
            compressEngine.onCompress(getContext(), list, new OnCallbackListener<List<LocalMedia>>() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass1 */

                public void onCall(List<LocalMedia> list) {
                    PictureBaseActivity.this.onResult(list);
                }
            });
            return;
        }
        showPleaseDialog();
        compressToLuban(list);
    }

    /* access modifiers changed from: protected */
    public void createNewFolder(List<LocalMediaFolder> list) {
        if (list.size() == 0) {
            LocalMediaFolder localMediaFolder = new LocalMediaFolder();
            localMediaFolder.setName(getString(this.config.chooseMode == PictureMimeType.ofAudio() ? R.string.picture_all_audio : R.string.picture_camera_roll));
            localMediaFolder.setFirstImagePath("");
            localMediaFolder.setCameraFolder(true);
            localMediaFolder.setBucketId(-1);
            localMediaFolder.setChecked(true);
            list.add(localMediaFolder);
        }
    }

    /* access modifiers changed from: protected */
    public void dismissDialog() {
        if (!isFinishing()) {
            try {
                PictureLoadingDialog pictureLoadingDialog = this.mLoadingDialog;
                if (pictureLoadingDialog != null && pictureLoadingDialog.isShowing()) {
                    this.mLoadingDialog.dismiss();
                }
            } catch (Exception e5) {
                this.mLoadingDialog = null;
                e5.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: protected */
    public void exit() {
        finish();
        if (this.config.camera) {
            overridePendingTransition(0, R.anim.picture_anim_fade_out);
            if ((getContext() instanceof PictureSelectorCameraEmptyActivity) || (getContext() instanceof PictureCustomCameraActivity)) {
                releaseResultListener();
                return;
            }
            return;
        }
        overridePendingTransition(0, PictureSelectionConfig.windowAnimationStyle.activityExitAnimation);
        if (getContext() instanceof PictureSelectorActivity) {
            releaseResultListener();
            if (this.config.openClickSound) {
                VoiceUtils.getInstance().releaseSoundPool();
            }
        }
    }

    /* access modifiers changed from: protected */
    public String getAudioPath(Intent intent) {
        try {
            Uri data = intent.getData();
            return data == null ? "" : PictureMimeType.isContent(data.toString()) ? data.toString() : data.getPath();
        } catch (Exception e5) {
            e5.printStackTrace();
            return "";
        }
    }

    /* access modifiers changed from: protected */
    public Context getContext() {
        return this;
    }

    /* access modifiers changed from: protected */
    public LocalMediaFolder getImageFolder(String str, String str2, String str3, List<LocalMediaFolder> list) {
        if (!PictureMimeType.isContent(str)) {
            str2 = str;
        }
        File parentFile = new File(str2).getParentFile();
        for (LocalMediaFolder localMediaFolder : list) {
            if (parentFile != null && localMediaFolder.getName().equals(parentFile.getName())) {
                return localMediaFolder;
            }
        }
        LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
        localMediaFolder2.setName(parentFile != null ? parentFile.getName() : "");
        localMediaFolder2.setFirstImagePath(str);
        localMediaFolder2.setFirstMimeType(str3);
        list.add(localMediaFolder2);
        return localMediaFolder2;
    }

    public abstract int getResourceId();

    /* access modifiers changed from: protected */
    public void handlerResult(List<LocalMedia> list) {
        if (this.config.isCompress) {
            compressImage(list);
        } else {
            onResult(list);
        }
    }

    public void immersive() {
        ImmersiveManage.immersiveAboveAPI23(this, this.colorPrimaryDark, this.colorPrimary, this.openWhiteStatusBar);
    }

    /* access modifiers changed from: protected */
    public void initCompleteText(int i5) {
    }

    /* access modifiers changed from: protected */
    public void initCompleteText(List<LocalMedia> list) {
    }

    /* access modifiers changed from: protected */
    public void initLoader() {
        this.mLoader = this.config.isPageStrategy ? new LocalMediaPageLoader(getContext(), this.config) : new LocalMediaLoader(getContext(), this.config);
    }

    /* access modifiers changed from: protected */
    public void initPictureSelectorStyle() {
    }

    /* access modifiers changed from: protected */
    public void initWidgets() {
    }

    public boolean isImmersive() {
        return true;
    }

    public boolean isRequestedOrientation() {
        return true;
    }

    @Override // androidx.fragment.app.e, androidx.appcompat.app.d
    public void onConfigurationChanged(Configuration configuration) {
        super.onConfigurationChanged(configuration);
        if (this.config.language != -2) {
            PictureLanguageUtils.setAppLanguage(getContext(), this.config.language);
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.e, androidx.core.app.e
    public void onCreate(Bundle bundle) {
        PictureParameterStyle pictureParameterStyle;
        int i5;
        PictureSelectionConfig instance = PictureSelectionConfig.getInstance();
        this.config = instance;
        if (instance.language != -2) {
            PictureLanguageUtils.setAppLanguage(getContext(), this.config.language);
        }
        int i6 = this.config.themeStyleId;
        if (i6 == 0) {
            i6 = R.style.picture_default_style;
        }
        setTheme(i6);
        super.onCreate(bundle);
        newCreateEngine();
        newCreateResultCallbackListener();
        if (isRequestedOrientation()) {
            setNewRequestedOrientation();
        }
        initConfig();
        if (isImmersive()) {
            immersive();
        }
        PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
        if (pictureSelectorUIStyle == null ? !((pictureParameterStyle = PictureSelectionConfig.style) == null || (i5 = pictureParameterStyle.pictureNavBarColor) == 0) : (i5 = pictureSelectorUIStyle.picture_navBarColor) != 0) {
            NavBarUtils.setNavBarColor(this, i5);
        }
        int resourceId = getResourceId();
        if (resourceId != 0) {
            setContentView(resourceId);
        }
        initLoader();
        initWidgets();
        initPictureSelectorStyle();
        this.isOnSaveInstanceState = false;
    }

    /* access modifiers changed from: protected */
    @Override // androidx.fragment.app.e, androidx.appcompat.app.d
    public void onDestroy() {
        PictureLoadingDialog pictureLoadingDialog = this.mLoadingDialog;
        if (pictureLoadingDialog != null) {
            pictureLoadingDialog.dismiss();
            this.mLoadingDialog = null;
        }
        super.onDestroy();
        this.mHandler.removeCallbacksAndMessages(null);
    }

    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.e, androidx.core.app.a.c
    public void onRequestPermissionsResult(int i5, String[] strArr, int[] iArr) {
        super.onRequestPermissionsResult(i5, strArr, iArr);
        if (i5 != 3) {
            return;
        }
        if (iArr[0] == 0) {
            Intent intent = new Intent("android.provider.MediaStore.RECORD_SOUND");
            if (intent.resolveActivity(getPackageManager()) != null) {
                startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                return;
            }
            return;
        }
        ToastUtils.s(getContext(), getString(R.string.picture_audio));
    }

    /* access modifiers changed from: protected */
    public void onResult(List<LocalMedia> list) {
        if (!SdkVersionUtils.isQ() || !this.config.isAndroidQTransform) {
            dismissDialog();
            PictureSelectionConfig pictureSelectionConfig = this.config;
            if (pictureSelectionConfig.camera && pictureSelectionConfig.selectionMode == 2) {
                list.addAll(list.size() > 0 ? list.size() - 1 : 0, this.selectionMedias);
            }
            if (this.config.isCheckOriginalImage) {
                int size = list.size();
                for (int i5 = 0; i5 < size; i5++) {
                    LocalMedia localMedia = list.get(i5);
                    localMedia.setOriginal(true);
                    localMedia.setOriginalPath(localMedia.getPath());
                }
            }
            OnResultCallbackListener<LocalMedia> onResultCallbackListener = PictureSelectionConfig.listener;
            if (onResultCallbackListener != null) {
                onResultCallbackListener.onResult(list);
            } else {
                setResult(-1, PictureSelector.putIntentResult(list));
            }
            exit();
            return;
        }
        onResultToAndroidAsy(list);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.core.app.e
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        this.isOnSaveInstanceState = true;
        bundle.putParcelable(PictureConfig.EXTRA_CONFIG, this.config);
    }

    /* access modifiers changed from: protected */
    public void setNewRequestedOrientation() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig != null && !pictureSelectionConfig.camera) {
            setRequestedOrientation(pictureSelectionConfig.requestedOrientation);
        }
    }

    /* access modifiers changed from: protected */
    public void showPermissionsDialog(boolean z4, String[] strArr, String str) {
    }

    /* access modifiers changed from: protected */
    public void showPleaseDialog() {
        try {
            if (!isFinishing()) {
                if (this.mLoadingDialog == null) {
                    this.mLoadingDialog = new PictureLoadingDialog(getContext());
                }
                if (this.mLoadingDialog.isShowing()) {
                    this.mLoadingDialog.dismiss();
                }
                this.mLoadingDialog.show();
            }
        } catch (Exception e5) {
            e5.printStackTrace();
        }
    }

    /* access modifiers changed from: protected */
    public void showPromptDialog(String str) {
        if (!isFinishing()) {
            OnChooseLimitCallback onChooseLimitCallback = PictureSelectionConfig.onChooseLimitCallback;
            if (onChooseLimitCallback != null) {
                onChooseLimitCallback.onChooseLimit(getContext(), str);
                return;
            }
            final PictureCustomDialog pictureCustomDialog = new PictureCustomDialog(getContext(), R.layout.picture_prompt_dialog);
            ((TextView) pictureCustomDialog.findViewById(R.id.tv_content)).setText(str);
            ((TextView) pictureCustomDialog.findViewById(R.id.btnOk)).setOnClickListener(new View.OnClickListener() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass5 */

                public void onClick(View view) {
                    if (!PictureBaseActivity.this.isFinishing()) {
                        pictureCustomDialog.dismiss();
                    }
                }
            });
            pictureCustomDialog.show();
        }
    }

    /* access modifiers changed from: protected */
    public void sortFolder(List<LocalMediaFolder> list) {
        Collections.sort(list, a.f3905e);
    }

    public void startOpenCameraAudio() {
        try {
            if (PermissionChecker.checkSelfPermission(this, "android.permission.RECORD_AUDIO")) {
                Intent intent = new Intent("android.provider.MediaStore.RECORD_SOUND");
                if (intent.resolveActivity(getPackageManager()) != null) {
                    Uri createCameraOutAudioUri = CameraFileUtils.createCameraOutAudioUri(getContext(), this.config);
                    if (createCameraOutAudioUri != null) {
                        intent.putExtra("output", createCameraOutAudioUri);
                        startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                        return;
                    }
                    ToastUtils.s(getContext(), "open is audio error，the uri is empty ");
                    if (this.config.camera) {
                        exit();
                        return;
                    }
                    return;
                }
                ToastUtils.s(getContext(), "System recording is not supported");
                return;
            }
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.RECORD_AUDIO"}, 3);
        } catch (Exception e5) {
            e5.printStackTrace();
            ToastUtils.s(getContext(), e5.getMessage());
        }
    }

    /* access modifiers changed from: protected */
    public void startOpenCameraImage() {
        if (this.config.isUseCustomCamera) {
            startCustomCamera();
            return;
        }
        Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
        if (intent.resolveActivity(getPackageManager()) != null) {
            Uri createCameraOutImageUri = CameraFileUtils.createCameraOutImageUri(getContext(), this.config);
            if (createCameraOutImageUri != null) {
                if (this.config.isCameraAroundState) {
                    intent.putExtra(PictureConfig.CAMERA_FACING, 1);
                }
                intent.putExtra("output", createCameraOutImageUri);
                startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                return;
            }
            ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
            if (this.config.camera) {
                exit();
            }
        }
    }

    /* access modifiers changed from: protected */
    public void startOpenCameraVideo() {
        if (this.config.isUseCustomCamera) {
            startCustomCamera();
            return;
        }
        Intent intent = new Intent("android.media.action.VIDEO_CAPTURE");
        if (intent.resolveActivity(getPackageManager()) != null) {
            Uri createCameraOutVideoUri = CameraFileUtils.createCameraOutVideoUri(getContext(), this.config);
            if (createCameraOutVideoUri != null) {
                intent.putExtra("output", createCameraOutVideoUri);
                if (this.config.isCameraAroundState) {
                    intent.putExtra(PictureConfig.CAMERA_FACING, 1);
                }
                intent.putExtra(PictureConfig.EXTRA_QUICK_CAPTURE, this.config.isQuickCapture);
                intent.putExtra("android.intent.extra.durationLimit", this.config.recordVideoSecond);
                intent.putExtra("android.intent.extra.videoQuality", this.config.videoQuality);
                startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                return;
            }
            ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
            if (this.config.camera) {
                exit();
            }
        }
    }
}
