package com.luck.picture.lib;

import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;
import com.luck.picture.lib.camera.CustomCameraView;
import com.luck.picture.lib.camera.listener.CameraListener;
import com.luck.picture.lib.camera.listener.ClickListener;
import com.luck.picture.lib.camera.view.CaptureLayout;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.dialog.PictureCustomDialog;
import com.luck.picture.lib.engine.ImageEngine;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.listener.OnPermissionDialogOptionCallback;
import com.luck.picture.lib.listener.OnPermissionsObtainCallback;
import com.luck.picture.lib.listener.OnResultCallbackListener;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.tools.PictureFileUtils;

public class PictureCustomCameraActivity extends PictureSelectorCameraEmptyActivity {
    private static final String TAG = "PictureCustomCameraActivity";
    protected boolean isEnterSetting;
    private CustomCameraView mCameraView;

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$initView$0(String str, ImageView imageView) {
        ImageEngine imageEngine;
        if (this.config != null && (imageEngine = PictureSelectionConfig.imageEngine) != null) {
            imageEngine.loadImage(getContext(), str, imageView);
        }
    }

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$showPermissionsDialog$1(PictureCustomDialog pictureCustomDialog, View view) {
        if (!isFinishing()) {
            pictureCustomDialog.dismiss();
        }
        OnResultCallbackListener<LocalMedia> onResultCallbackListener = PictureSelectionConfig.listener;
        if (onResultCallbackListener != null) {
            onResultCallbackListener.onCancel();
        }
        exit();
    }

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$showPermissionsDialog$2(PictureCustomDialog pictureCustomDialog, View view) {
        if (!isFinishing()) {
            pictureCustomDialog.dismiss();
        }
        PermissionChecker.launchAppDetailsSettings(getContext());
        this.isEnterSetting = true;
    }

    private void requestCamera() {
        if (!PermissionChecker.checkSelfPermission(this, "android.permission.WRITE_EXTERNAL_STORAGE")) {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.WRITE_EXTERNAL_STORAGE"}, 1);
        } else if (!PermissionChecker.checkSelfPermission(this, "android.permission.CAMERA")) {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
        } else if (this.config.buttonFeatures != 257 && !PermissionChecker.checkSelfPermission(this, "android.permission.RECORD_AUDIO")) {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.RECORD_AUDIO"}, 4);
        } else {
            this.mCameraView.initCamera();
        }
    }

    /* access modifiers changed from: protected */
    public void initView() {
        int i5 = this.config.recordVideoSecond;
        if (i5 > 0) {
            this.mCameraView.setRecordVideoMaxTime(i5);
        }
        int i6 = this.config.recordVideoMinSecond;
        if (i6 > 0) {
            this.mCameraView.setRecordVideoMinTime(i6);
        }
        this.mCameraView.setCaptureLoadingColor(this.config.captureLoadingColor);
        CaptureLayout captureLayout = this.mCameraView.getCaptureLayout();
        if (captureLayout != null) {
            captureLayout.setButtonFeatures(this.config.buttonFeatures);
        }
        this.mCameraView.setImageCallbackListener(new d(this));
        this.mCameraView.setCameraListener(new CameraListener() {
            /* class com.luck.picture.lib.PictureCustomCameraActivity.AnonymousClass1 */

            @Override // com.luck.picture.lib.camera.listener.CameraListener
            public void onError(int i5, String str, Throwable th) {
                String str2 = PictureCustomCameraActivity.TAG;
                Log.i(str2, "onError: " + str);
            }

            @Override // com.luck.picture.lib.camera.listener.CameraListener
            public void onPictureSuccess(String str) {
                PictureCustomCameraActivity.this.config.cameraMimeType = PictureMimeType.ofImage();
                Intent intent = new Intent();
                intent.putExtra(PictureConfig.EXTRA_MEDIA_PATH, str);
                intent.putExtra(PictureConfig.EXTRA_CONFIG, PictureCustomCameraActivity.this.config);
                PictureCustomCameraActivity pictureCustomCameraActivity = PictureCustomCameraActivity.this;
                if (pictureCustomCameraActivity.config.camera) {
                    pictureCustomCameraActivity.dispatchHandleCamera(intent);
                    return;
                }
                pictureCustomCameraActivity.setResult(-1, intent);
                PictureCustomCameraActivity.this.onBackPressed();
            }

            @Override // com.luck.picture.lib.camera.listener.CameraListener
            public void onRecordSuccess(String str) {
                PictureCustomCameraActivity.this.config.cameraMimeType = PictureMimeType.ofVideo();
                Intent intent = new Intent();
                intent.putExtra(PictureConfig.EXTRA_MEDIA_PATH, str);
                intent.putExtra(PictureConfig.EXTRA_CONFIG, PictureCustomCameraActivity.this.config);
                PictureCustomCameraActivity pictureCustomCameraActivity = PictureCustomCameraActivity.this;
                if (pictureCustomCameraActivity.config.camera) {
                    pictureCustomCameraActivity.dispatchHandleCamera(intent);
                    return;
                }
                pictureCustomCameraActivity.setResult(-1, intent);
                PictureCustomCameraActivity.this.onBackPressed();
            }
        });
        this.mCameraView.setOnClickListener(new ClickListener() {
            /* class com.luck.picture.lib.PictureCustomCameraActivity.AnonymousClass2 */

            @Override // com.luck.picture.lib.camera.listener.ClickListener
            public void onClick() {
                PictureCustomCameraActivity.this.onBackPressed();
            }
        });
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public boolean isImmersive() {
        return false;
    }

    @Override // androidx.activity.ComponentActivity, com.luck.picture.lib.PictureSelectorCameraEmptyActivity
    public void onBackPressed() {
        OnResultCallbackListener<LocalMedia> onResultCallbackListener;
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (!(pictureSelectionConfig == null || !pictureSelectionConfig.camera || (onResultCallbackListener = PictureSelectionConfig.listener) == null)) {
            onResultCallbackListener.onCancel();
        }
        exit();
    }

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.e, androidx.core.app.e, com.luck.picture.lib.PictureBaseActivity, com.luck.picture.lib.PictureSelectorCameraEmptyActivity
    public void onCreate(Bundle bundle) {
        getWindow().setFlags(PictureFileUtils.KB, PictureFileUtils.KB);
        getWindow().setFlags(67108864, 67108864);
        getWindow().setFlags(134217728, 134217728);
        if (Build.VERSION.SDK_INT >= 28) {
            WindowManager.LayoutParams attributes = getWindow().getAttributes();
            attributes.layoutInDisplayCutoutMode = 1;
            getWindow().setAttributes(attributes);
        }
        getWindow().addFlags(128);
        super.onCreate(bundle);
        setContentView(R.layout.picture_custom_camera);
        this.mCameraView = (CustomCameraView) findViewById(R.id.cameraView);
        initView();
        requestCamera();
    }

    @Override // androidx.appcompat.app.d
    public boolean onKeyDown(int i5, KeyEvent keyEvent) {
        if (i5 == 4) {
            this.mCameraView.onCancelMedia();
        }
        return super.onKeyDown(i5, keyEvent);
    }

    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.e, com.luck.picture.lib.PictureBaseActivity, com.luck.picture.lib.PictureSelectorCameraEmptyActivity, androidx.core.app.a.c
    public void onRequestPermissionsResult(int i5, String[] strArr, int[] iArr) {
        if (i5 != 1) {
            if (i5 != 2) {
                if (i5 == 4) {
                    if (iArr.length <= 0 || iArr[0] != 0) {
                        showPermissionsDialog(false, new String[]{"android.permission.RECORD_AUDIO"}, getString(R.string.picture_audio));
                        return;
                    }
                } else {
                    return;
                }
            } else if (iArr.length <= 0 || iArr[0] != 0) {
                showPermissionsDialog(true, new String[]{"android.permission.CAMERA"}, getString(R.string.picture_camera));
                return;
            } else if (!PermissionChecker.checkSelfPermission(this, "android.permission.RECORD_AUDIO")) {
                PermissionChecker.requestPermissions(this, new String[]{"android.permission.RECORD_AUDIO"}, 4);
                return;
            }
            this.mCameraView.initCamera();
        } else if (iArr.length <= 0 || iArr[0] != 0) {
            showPermissionsDialog(true, new String[]{"android.permission.WRITE_EXTERNAL_STORAGE"}, getString(R.string.picture_jurisdiction));
        } else {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.fragment.app.e
    public void onResume() {
        super.onResume();
        if (this.isEnterSetting) {
            if (!PermissionChecker.checkSelfPermission(this, "android.permission.WRITE_EXTERNAL_STORAGE")) {
                showPermissionsDialog(false, new String[]{"android.permission.WRITE_EXTERNAL_STORAGE"}, getString(R.string.picture_jurisdiction));
            } else if (!PermissionChecker.checkSelfPermission(this, "android.permission.CAMERA")) {
                showPermissionsDialog(false, new String[]{"android.permission.CAMERA"}, getString(R.string.picture_camera));
            } else if (this.config.buttonFeatures != 257 && !PermissionChecker.checkSelfPermission(this, "android.permission.RECORD_AUDIO")) {
                PermissionChecker.requestPermissions(this, new String[]{"android.permission.RECORD_AUDIO"}, 4);
            } else {
                this.mCameraView.initCamera();
            }
            this.isEnterSetting = false;
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.luck.picture.lib.PictureBaseActivity
    public void showPermissionsDialog(boolean z4, String[] strArr, String str) {
        if (!isFinishing()) {
            OnPermissionsObtainCallback onPermissionsObtainCallback = PictureSelectionConfig.onPermissionsObtainCallback;
            if (onPermissionsObtainCallback != null) {
                onPermissionsObtainCallback.onPermissionsIntercept(getContext(), z4, strArr, str, new OnPermissionDialogOptionCallback() {
                    /* class com.luck.picture.lib.PictureCustomCameraActivity.AnonymousClass3 */

                    @Override // com.luck.picture.lib.listener.OnPermissionDialogOptionCallback
                    public void onCancel() {
                        OnResultCallbackListener<LocalMedia> onResultCallbackListener = PictureSelectionConfig.listener;
                        if (onResultCallbackListener != null) {
                            onResultCallbackListener.onCancel();
                        }
                        PictureCustomCameraActivity.this.exit();
                    }

                    @Override // com.luck.picture.lib.listener.OnPermissionDialogOptionCallback
                    public void onSetting() {
                        PictureCustomCameraActivity.this.isEnterSetting = true;
                    }
                });
                return;
            }
            PictureCustomDialog pictureCustomDialog = new PictureCustomDialog(getContext(), R.layout.picture_wind_base_dialog);
            pictureCustomDialog.setCancelable(false);
            pictureCustomDialog.setCanceledOnTouchOutside(false);
            Button button = (Button) pictureCustomDialog.findViewById(R.id.btn_commit);
            button.setText(getString(R.string.picture_go_setting));
            ((TextView) pictureCustomDialog.findViewById(R.id.tvTitle)).setText(getString(R.string.picture_prompt));
            ((TextView) pictureCustomDialog.findViewById(R.id.tv_content)).setText(str);
            ((Button) pictureCustomDialog.findViewById(R.id.btn_cancel)).setOnClickListener(new c(this, pictureCustomDialog));
            button.setOnClickListener(new b(this, pictureCustomDialog));
            pictureCustomDialog.show();
        }
    }
}
