package com.luck.picture.lib;

import android.content.ContentValues;
import android.content.Context;
import android.content.Intent;
import android.graphics.PointF;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.SparseArray;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.viewpager.widget.a;
import androidx.viewpager.widget.b;
import com.luck.picture.lib.broadcast.BroadcastAction;
import com.luck.picture.lib.broadcast.BroadcastManager;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.dialog.PictureCustomDialog;
import com.luck.picture.lib.engine.ImageEngine;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.listener.OnImageCompleteCallback;
import com.luck.picture.lib.listener.OnVideoSelectedPlayCallback;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.photoview.PhotoView;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.CameraFileUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.JumpUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.ScreenUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.ValueOf;
import com.luck.picture.lib.widget.PreviewViewPager;
import com.luck.picture.lib.widget.longimage.ImageSource;
import com.luck.picture.lib.widget.longimage.ImageViewState;
import com.luck.picture.lib.widget.longimage.SubsamplingScaleImageView;
import com.yalantis.ucrop.view.CropImageView;
import java.io.File;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

public class PictureExternalPreviewActivity extends PictureBaseActivity implements View.OnClickListener {
    private SimpleFragmentAdapter adapter;
    private String downloadPath;
    private ImageButton ibDelete;
    private ImageButton ibLeftBack;
    private final List<LocalMedia> images = new ArrayList();
    private String mMimeType;
    private int mScreenHeight;
    private int mScreenWidth;
    private View mTitleBar;
    private int position = 0;
    private TextView tvTitle;
    private PreviewViewPager viewPager;

    public class SimpleFragmentAdapter extends a {
        private static final int MAX_CACHE_SIZE = 20;
        private final SparseArray<View> mCacheView = new SparseArray<>();

        public SimpleFragmentAdapter() {
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void clear() {
            this.mCacheView.clear();
        }

        /* access modifiers changed from: private */
        public /* synthetic */ void lambda$instantiateItem$0(View view, float f5, float f6) {
            PictureExternalPreviewActivity.this.finish();
            PictureExternalPreviewActivity.this.exitAnimation();
        }

        /* access modifiers changed from: private */
        public /* synthetic */ void lambda$instantiateItem$1(View view) {
            PictureExternalPreviewActivity.this.finish();
            PictureExternalPreviewActivity.this.exitAnimation();
        }

        /* access modifiers changed from: private */
        public /* synthetic */ boolean lambda$instantiateItem$2(String str, LocalMedia localMedia, View view) {
            PictureExternalPreviewActivity pictureExternalPreviewActivity = PictureExternalPreviewActivity.this;
            if (pictureExternalPreviewActivity.config.isNotPreviewDownload) {
                if (PermissionChecker.checkSelfPermission(pictureExternalPreviewActivity.getContext(), "android.permission.WRITE_EXTERNAL_STORAGE")) {
                    PictureExternalPreviewActivity.this.downloadPath = str;
                    String mimeType = (!PictureMimeType.isHasHttp(str) || !TextUtils.isEmpty(localMedia.getMimeType())) ? localMedia.getMimeType() : PictureMimeType.getImageMimeType(localMedia.getPath());
                    PictureExternalPreviewActivity pictureExternalPreviewActivity2 = PictureExternalPreviewActivity.this;
                    if (PictureMimeType.isJPG(mimeType)) {
                        mimeType = "image/jpeg";
                    }
                    pictureExternalPreviewActivity2.mMimeType = mimeType;
                    PictureExternalPreviewActivity.this.showDownLoadDialog();
                } else {
                    PermissionChecker.requestPermissions(PictureExternalPreviewActivity.this, new String[]{"android.permission.WRITE_EXTERNAL_STORAGE"}, 1);
                }
            }
            return true;
        }

        /* access modifiers changed from: private */
        public /* synthetic */ boolean lambda$instantiateItem$3(String str, LocalMedia localMedia, View view) {
            PictureExternalPreviewActivity pictureExternalPreviewActivity = PictureExternalPreviewActivity.this;
            if (pictureExternalPreviewActivity.config.isNotPreviewDownload) {
                if (PermissionChecker.checkSelfPermission(pictureExternalPreviewActivity.getContext(), "android.permission.WRITE_EXTERNAL_STORAGE")) {
                    PictureExternalPreviewActivity.this.downloadPath = str;
                    String mimeType = (!PictureMimeType.isHasHttp(str) || !TextUtils.isEmpty(localMedia.getMimeType())) ? localMedia.getMimeType() : PictureMimeType.getImageMimeType(localMedia.getPath());
                    PictureExternalPreviewActivity pictureExternalPreviewActivity2 = PictureExternalPreviewActivity.this;
                    if (PictureMimeType.isJPG(mimeType)) {
                        mimeType = "image/jpeg";
                    }
                    pictureExternalPreviewActivity2.mMimeType = mimeType;
                    PictureExternalPreviewActivity.this.showDownLoadDialog();
                } else {
                    PermissionChecker.requestPermissions(PictureExternalPreviewActivity.this, new String[]{"android.permission.WRITE_EXTERNAL_STORAGE"}, 1);
                }
            }
            return true;
        }

        /* access modifiers changed from: private */
        public static /* synthetic */ void lambda$instantiateItem$4(LocalMedia localMedia, String str, ViewGroup viewGroup, View view) {
            OnVideoSelectedPlayCallback<LocalMedia> onVideoSelectedPlayCallback = PictureSelectionConfig.customVideoPlayCallback;
            if (onVideoSelectedPlayCallback != null) {
                onVideoSelectedPlayCallback.startPlayVideo(localMedia);
                return;
            }
            Intent intent = new Intent();
            Bundle bundle = new Bundle();
            bundle.putString(PictureConfig.EXTRA_VIDEO_PATH, str);
            intent.putExtras(bundle);
            JumpUtils.startPictureVideoPlayActivity(viewGroup.getContext(), bundle, PictureConfig.PREVIEW_VIDEO_CODE);
        }

        @Override // androidx.viewpager.widget.a
        public void destroyItem(ViewGroup viewGroup, int i5, Object obj) {
            viewGroup.removeView((View) obj);
            if (this.mCacheView.size() > 20) {
                this.mCacheView.remove(i5);
            }
        }

        @Override // androidx.viewpager.widget.a
        public int getCount() {
            return PictureExternalPreviewActivity.this.images.size();
        }

        @Override // androidx.viewpager.widget.a
        public int getItemPosition(Object obj) {
            return -2;
        }

        @Override // androidx.viewpager.widget.a
        public Object instantiateItem(ViewGroup viewGroup, int i5) {
            View view = this.mCacheView.get(i5);
            if (view == null) {
                view = LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.picture_image_preview, viewGroup, false);
                this.mCacheView.put(i5, view);
            }
            PhotoView photoView = (PhotoView) view.findViewById(R.id.preview_image);
            SubsamplingScaleImageView subsamplingScaleImageView = (SubsamplingScaleImageView) view.findViewById(R.id.longImg);
            ImageView imageView = (ImageView) view.findViewById(R.id.iv_play);
            LocalMedia localMedia = (LocalMedia) PictureExternalPreviewActivity.this.images.get(i5);
            if (PictureExternalPreviewActivity.this.config.isAutoScalePreviewImage) {
                float min = (float) Math.min(localMedia.getWidth(), localMedia.getHeight());
                float max = (float) Math.max(localMedia.getHeight(), localMedia.getWidth());
                if (min > CropImageView.DEFAULT_ASPECT_RATIO && max > CropImageView.DEFAULT_ASPECT_RATIO) {
                    int ceil = (int) Math.ceil((double) ((max * min) / min));
                    FrameLayout.LayoutParams layoutParams = (FrameLayout.LayoutParams) photoView.getLayoutParams();
                    layoutParams.width = PictureExternalPreviewActivity.this.mScreenWidth;
                    if (ceil < PictureExternalPreviewActivity.this.mScreenHeight) {
                        ceil += PictureExternalPreviewActivity.this.mScreenHeight;
                    }
                    layoutParams.height = ceil;
                    layoutParams.gravity = 17;
                }
            }
            final String compressPath = (!localMedia.isCut() || localMedia.isCompressed()) ? (localMedia.isCompressed() || (localMedia.isCut() && localMedia.isCompressed())) ? localMedia.getCompressPath() : localMedia.isToSandboxPath() ? localMedia.getAndroidQToPath() : localMedia.getPath() : localMedia.getCutPath();
            boolean isHasHttp = PictureMimeType.isHasHttp(compressPath);
            String mimeType = (!isHasHttp || !TextUtils.isEmpty(localMedia.getMimeType())) ? localMedia.getMimeType() : PictureMimeType.getImageMimeType(localMedia.getPath());
            boolean isHasVideo = PictureMimeType.isHasVideo(mimeType);
            int i6 = 8;
            imageView.setVisibility(isHasVideo ? 0 : 8);
            boolean isGif = PictureMimeType.isGif(mimeType);
            boolean isLongImg = MediaUtils.isLongImg(localMedia);
            photoView.setVisibility((!isLongImg || isGif) ? 0 : 8);
            if (isLongImg && !isGif) {
                i6 = 0;
            }
            subsamplingScaleImageView.setVisibility(i6);
            ImageEngine imageEngine = PictureSelectionConfig.imageEngine;
            if (imageEngine != null) {
                if (isHasHttp) {
                    imageEngine.loadImage(view.getContext(), compressPath, photoView, subsamplingScaleImageView, new OnImageCompleteCallback() {
                        /* class com.luck.picture.lib.PictureExternalPreviewActivity.SimpleFragmentAdapter.AnonymousClass1 */

                        @Override // com.luck.picture.lib.listener.OnImageCompleteCallback
                        public void onHideLoading() {
                            PictureExternalPreviewActivity.this.dismissDialog();
                        }

                        @Override // com.luck.picture.lib.listener.OnImageCompleteCallback
                        public void onShowLoading() {
                            if (TextUtils.equals(compressPath, ((LocalMedia) PictureExternalPreviewActivity.this.images.get(PictureExternalPreviewActivity.this.viewPager.getCurrentItem())).getPath())) {
                                PictureExternalPreviewActivity.this.showPleaseDialog();
                            }
                        }
                    });
                } else if (isLongImg) {
                    PictureExternalPreviewActivity.this.displayLongPic(PictureMimeType.isContent(compressPath) ? Uri.parse(compressPath) : Uri.fromFile(new File(compressPath)), subsamplingScaleImageView);
                } else {
                    imageEngine.loadImage(view.getContext(), compressPath, photoView);
                }
            }
            photoView.setOnViewTapListener(new k(this));
            subsamplingScaleImageView.setOnClickListener(new g(this));
            if (!isHasVideo) {
                subsamplingScaleImageView.setOnLongClickListener(new i(this, compressPath, localMedia));
            }
            if (!isHasVideo) {
                photoView.setOnLongClickListener(new j(this, compressPath, localMedia));
            }
            imageView.setOnClickListener(new h(localMedia, compressPath, viewGroup));
            viewGroup.addView(view, 0);
            return view;
        }

        @Override // androidx.viewpager.widget.a
        public boolean isViewFromObject(View view, Object obj) {
            return view == obj;
        }

        public void removeCacheView(int i5) {
            if (i5 < this.mCacheView.size()) {
                this.mCacheView.removeAt(i5);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void displayLongPic(Uri uri, SubsamplingScaleImageView subsamplingScaleImageView) {
        subsamplingScaleImageView.setQuickScaleEnabled(true);
        subsamplingScaleImageView.setZoomEnabled(true);
        subsamplingScaleImageView.setDoubleTapZoomDuration(100);
        subsamplingScaleImageView.setMinimumScaleType(2);
        subsamplingScaleImageView.setDoubleTapZoomDpi(2);
        subsamplingScaleImageView.setImage(ImageSource.uri(uri), new ImageViewState(CropImageView.DEFAULT_ASPECT_RATIO, new PointF(CropImageView.DEFAULT_ASPECT_RATIO, CropImageView.DEFAULT_ASPECT_RATIO), 0));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void exitAnimation() {
        overridePendingTransition(R.anim.picture_anim_fade_in, PictureSelectionConfig.windowAnimationStyle.activityPreviewExitAnimation);
    }

    private void initViewPageAdapterData() {
        this.tvTitle.setText(getString(R.string.picture_preview_image_num, new Object[]{Integer.valueOf(this.position + 1), Integer.valueOf(this.images.size())}));
        SimpleFragmentAdapter simpleFragmentAdapter = new SimpleFragmentAdapter();
        this.adapter = simpleFragmentAdapter;
        this.viewPager.setAdapter(simpleFragmentAdapter);
        this.viewPager.setCurrentItem(this.position);
        this.viewPager.addOnPageChangeListener(new b.j() {
            /* class com.luck.picture.lib.PictureExternalPreviewActivity.AnonymousClass1 */

            @Override // androidx.viewpager.widget.b.j
            public void onPageScrollStateChanged(int i5) {
            }

            @Override // androidx.viewpager.widget.b.j
            public void onPageScrolled(int i5, float f5, int i6) {
            }

            @Override // androidx.viewpager.widget.b.j
            public void onPageSelected(int i5) {
                PictureExternalPreviewActivity.this.tvTitle.setText(PictureExternalPreviewActivity.this.getString(R.string.picture_preview_image_num, new Object[]{Integer.valueOf(i5 + 1), Integer.valueOf(PictureExternalPreviewActivity.this.images.size())}));
                PictureExternalPreviewActivity.this.position = i5;
            }
        });
    }

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$showDownLoadDialog$0(PictureCustomDialog pictureCustomDialog, View view) {
        if (!isFinishing()) {
            pictureCustomDialog.dismiss();
        }
    }

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$showDownLoadDialog$1(PictureCustomDialog pictureCustomDialog, View view) {
        if (PictureMimeType.isHasHttp(this.downloadPath)) {
            showPleaseDialog();
            PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<String>() {
                /* class com.luck.picture.lib.PictureExternalPreviewActivity.AnonymousClass2 */

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public String doInBackground() {
                    PictureExternalPreviewActivity pictureExternalPreviewActivity = PictureExternalPreviewActivity.this;
                    return pictureExternalPreviewActivity.showLoadingImage(pictureExternalPreviewActivity.downloadPath);
                }

                public void onSuccess(String str) {
                    PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                    PictureExternalPreviewActivity.this.onSuccessful(str);
                    PictureExternalPreviewActivity.this.dismissDialog();
                }
            });
        } else if (SdkVersionUtils.isQ()) {
            savePictureAlbumAndroidQ(PictureMimeType.isContent(this.downloadPath) ? Uri.parse(this.downloadPath) : Uri.fromFile(new File(this.downloadPath)));
        } else {
            savePictureAlbum();
        }
        if (!isFinishing()) {
            pictureCustomDialog.dismiss();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onSuccessful(String str) {
        if (TextUtils.isEmpty(str)) {
            ToastUtils.s(getContext(), getString(R.string.picture_save_error));
            return;
        }
        new PictureMediaScannerConnection(getContext(), str, null);
        Context context = getContext();
        ToastUtils.s(context, getString(R.string.picture_save_success) + "\n" + str);
    }

    private void savePictureAlbum() {
        String str;
        String lastImgSuffix = PictureMimeType.getLastImgSuffix(this.mMimeType);
        String externalStorageState = Environment.getExternalStorageState();
        File externalStoragePublicDirectory = externalStorageState.equals("mounted") ? Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DCIM) : getContext().getExternalFilesDir(Environment.DIRECTORY_PICTURES);
        if (externalStoragePublicDirectory != null && !externalStoragePublicDirectory.exists()) {
            externalStoragePublicDirectory.mkdirs();
        }
        if (SdkVersionUtils.isQ() || !externalStorageState.equals("mounted")) {
            str = externalStoragePublicDirectory.getAbsolutePath();
        } else {
            StringBuilder sb = new StringBuilder();
            sb.append(externalStoragePublicDirectory.getAbsolutePath());
            String str2 = File.separator;
            sb.append(str2);
            sb.append(PictureMimeType.CAMERA);
            sb.append(str2);
            str = sb.toString();
        }
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
        File file2 = new File(file, DateUtils.getCreateFileName("IMG_") + lastImgSuffix);
        PictureFileUtils.copyFile(this.downloadPath, file2.getAbsolutePath());
        onSuccessful(file2.getAbsolutePath());
    }

    private void savePictureAlbumAndroidQ(final Uri uri) {
        ContentValues contentValues = new ContentValues();
        contentValues.put("_display_name", DateUtils.getCreateFileName("IMG_"));
        contentValues.put("datetaken", ValueOf.toString(Long.valueOf(System.currentTimeMillis())));
        contentValues.put("mime_type", this.mMimeType);
        contentValues.put("relative_path", PictureMimeType.DCIM);
        final Uri insert = getContentResolver().insert(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, contentValues);
        if (insert == null) {
            ToastUtils.s(getContext(), getString(R.string.picture_save_error));
        } else {
            PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<String>() {
                /* class com.luck.picture.lib.PictureExternalPreviewActivity.AnonymousClass3 */

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public String doInBackground() {
                    try {
                        return PictureFileUtils.writeFileFromIS(PictureContentResolver.getContentResolverOpenInputStream(PictureExternalPreviewActivity.this.getContext(), uri), PictureContentResolver.getContentResolverOpenOutputStream(PictureExternalPreviewActivity.this.getContext(), insert)) ? PictureFileUtils.getPath(PictureExternalPreviewActivity.this.getContext(), insert) : "";
                    } catch (Exception e5) {
                        e5.printStackTrace();
                        return "";
                    }
                }

                public void onSuccess(String str) {
                    PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                    PictureExternalPreviewActivity.this.onSuccessful(str);
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void showDownLoadDialog() {
        if (!isFinishing() && !TextUtils.isEmpty(this.downloadPath)) {
            PictureCustomDialog pictureCustomDialog = new PictureCustomDialog(getContext(), R.layout.picture_wind_base_dialog);
            ((TextView) pictureCustomDialog.findViewById(R.id.tvTitle)).setText(getString(R.string.picture_prompt));
            ((TextView) pictureCustomDialog.findViewById(R.id.tv_content)).setText(getString(R.string.picture_prompt_content));
            ((Button) pictureCustomDialog.findViewById(R.id.btn_cancel)).setOnClickListener(new f(this, pictureCustomDialog));
            ((Button) pictureCustomDialog.findViewById(R.id.btn_commit)).setOnClickListener(new e(this, pictureCustomDialog));
            pictureCustomDialog.show();
        }
    }

    public void finish() {
        super.finish();
        SimpleFragmentAdapter simpleFragmentAdapter = this.adapter;
        if (simpleFragmentAdapter != null) {
            simpleFragmentAdapter.clear();
        }
        PictureSelectionConfig.destroy();
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public int getResourceId() {
        return R.layout.picture_activity_external_preview;
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public void initPictureSelectorStyle() {
        PictureParameterStyle pictureParameterStyle = PictureSelectionConfig.style;
        if (pictureParameterStyle != null) {
            int i5 = pictureParameterStyle.pictureTitleTextColor;
            if (i5 != 0) {
                this.tvTitle.setTextColor(i5);
            }
            int i6 = PictureSelectionConfig.style.pictureTitleTextSize;
            if (i6 != 0) {
                this.tvTitle.setTextSize((float) i6);
            }
            int i7 = PictureSelectionConfig.style.pictureLeftBackIcon;
            if (i7 != 0) {
                this.ibLeftBack.setImageResource(i7);
            }
            int i8 = PictureSelectionConfig.style.pictureExternalPreviewDeleteStyle;
            if (i8 != 0) {
                this.ibDelete.setImageResource(i8);
            }
            if (PictureSelectionConfig.style.pictureTitleBarBackgroundColor == 0) {
                return;
            }
        } else {
            int typeValueColor = AttrsUtils.getTypeValueColor(getContext(), R.attr.picture_ac_preview_title_bg);
            if (typeValueColor != 0) {
                this.mTitleBar.setBackgroundColor(typeValueColor);
                return;
            }
        }
        this.mTitleBar.setBackgroundColor(this.colorPrimary);
    }

    /* access modifiers changed from: protected */
    @Override // com.luck.picture.lib.PictureBaseActivity
    public void initWidgets() {
        super.initWidgets();
        this.mTitleBar = findViewById(R.id.titleBar);
        this.tvTitle = (TextView) findViewById(R.id.picture_title);
        this.ibLeftBack = (ImageButton) findViewById(R.id.left_back);
        this.ibDelete = (ImageButton) findViewById(R.id.ib_delete);
        this.viewPager = (PreviewViewPager) findViewById(R.id.preview_pager);
        int i5 = 0;
        this.position = getIntent().getIntExtra("position", 0);
        this.mScreenWidth = ScreenUtils.getScreenWidth(getContext());
        this.mScreenHeight = ScreenUtils.getScreenHeight(getContext());
        ArrayList parcelableArrayListExtra = getIntent().getParcelableArrayListExtra(PictureConfig.EXTRA_PREVIEW_SELECT_LIST);
        if (parcelableArrayListExtra != null && parcelableArrayListExtra.size() > 0) {
            this.images.addAll(parcelableArrayListExtra);
        }
        this.ibLeftBack.setOnClickListener(this);
        this.ibDelete.setOnClickListener(this);
        ImageButton imageButton = this.ibDelete;
        PictureParameterStyle pictureParameterStyle = PictureSelectionConfig.style;
        if (pictureParameterStyle == null || !pictureParameterStyle.pictureExternalPreviewGonePreviewDelete) {
            i5 = 8;
        }
        imageButton.setVisibility(i5);
        initViewPageAdapterData();
    }

    @Override // androidx.activity.ComponentActivity
    public void onBackPressed() {
        if (SdkVersionUtils.isQ()) {
            finishAfterTransition();
        } else {
            super.onBackPressed();
        }
        finish();
        exitAnimation();
    }

    public void onClick(View view) {
        int id = view.getId();
        if (id == R.id.left_back) {
            finish();
            exitAnimation();
        } else if (id == R.id.ib_delete && this.images.size() > 0) {
            int currentItem = this.viewPager.getCurrentItem();
            this.images.remove(currentItem);
            this.adapter.removeCacheView(currentItem);
            Bundle bundle = new Bundle();
            bundle.putInt("position", currentItem);
            BroadcastManager.getInstance(getContext()).action(BroadcastAction.ACTION_DELETE_PREVIEW_POSITION).extras(bundle).broadcast();
            if (this.images.size() == 0) {
                onBackPressed();
                return;
            }
            this.tvTitle.setText(getString(R.string.picture_preview_image_num, new Object[]{Integer.valueOf(this.position + 1), Integer.valueOf(this.images.size())}));
            this.position = currentItem;
            this.adapter.notifyDataSetChanged();
        }
    }

    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.e, com.luck.picture.lib.PictureBaseActivity, androidx.core.app.a.c
    public void onRequestPermissionsResult(int i5, String[] strArr, int[] iArr) {
        super.onRequestPermissionsResult(i5, strArr, iArr);
        if (i5 == 1) {
            for (int i6 : iArr) {
                if (i6 == 0) {
                    showDownLoadDialog();
                } else {
                    ToastUtils.s(getContext(), getString(R.string.picture_jurisdiction));
                }
            }
        }
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(3:39|40|(1:42)) */
    /* JADX WARNING: Code restructure failed: missing block: B:35:0x00be, code lost:
        r7 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:36:0x00bf, code lost:
        r2 = null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:37:0x00c1, code lost:
        r7 = null;
        r0 = null;
        r2 = null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:0x00c8, code lost:
        if (com.luck.picture.lib.tools.SdkVersionUtils.isQ() != false) goto L_0x00ca;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x00ca, code lost:
        com.luck.picture.lib.tools.MediaUtils.deleteUri(getContext(), r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:45:0x00d8, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:46:0x00d9, code lost:
        r1 = r7;
        r7 = r0;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:39:0x00c4 */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00be A[ExcHandler: all (th java.lang.Throwable), Splitter:B:1:0x0003] */
    public String showLoadingImage(String str) {
        OutputStream outputStream;
        InputStream inputStream;
        Uri uri;
        String str2;
        InputStream inputStream2 = null;
        try {
            if (SdkVersionUtils.isQ()) {
                uri = CameraFileUtils.createImageUri(getContext(), "", this.mMimeType);
            } else {
                String lastImgSuffix = PictureMimeType.getLastImgSuffix(this.mMimeType);
                String externalStorageState = Environment.getExternalStorageState();
                File externalStoragePublicDirectory = externalStorageState.equals("mounted") ? Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DCIM) : getContext().getExternalFilesDir(Environment.DIRECTORY_PICTURES);
                if (!externalStoragePublicDirectory.exists()) {
                    externalStoragePublicDirectory.mkdirs();
                }
                if (!externalStorageState.equals("mounted")) {
                    str2 = externalStoragePublicDirectory.getAbsolutePath();
                } else {
                    StringBuilder sb = new StringBuilder();
                    sb.append(externalStoragePublicDirectory.getAbsolutePath());
                    String str3 = File.separator;
                    sb.append(str3);
                    sb.append(PictureMimeType.CAMERA);
                    sb.append(str3);
                    str2 = sb.toString();
                }
                File file = new File(str2);
                if (!file.exists()) {
                    file.mkdirs();
                }
                uri = Uri.fromFile(new File(file, DateUtils.getCreateFileName("IMG_") + lastImgSuffix));
            }
            outputStream = PictureContentResolver.getContentResolverOpenOutputStream(getContext(), uri);
            try {
                inputStream = new URL(str).openStream();
                if (PictureFileUtils.writeFileFromIS(inputStream, outputStream)) {
                    String path = PictureFileUtils.getPath(this, uri);
                    PictureFileUtils.close(inputStream);
                    PictureFileUtils.close(outputStream);
                    return path;
                }
            } catch (Exception unused) {
                inputStream = null;
            } catch (Throwable th) {
                Throwable th2 = th;
                PictureFileUtils.close(inputStream2);
                PictureFileUtils.close(outputStream);
                throw th2;
            }
        } catch (Exception unused2) {
            inputStream = null;
            outputStream = null;
        } catch (Throwable th3) {
        }
        PictureFileUtils.close(inputStream);
        PictureFileUtils.close(outputStream);
        return null;
    }
}
