package com.luck.picture.lib;

import android.app.Activity;
import android.content.Intent;
import android.os.Build;
import android.text.TextUtils;
import androidx.activity.result.c;
import androidx.fragment.app.Fragment;
import com.luck.picture.lib.camera.CustomCameraType;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.engine.CompressEngine;
import com.luck.picture.lib.engine.ImageEngine;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.listener.OnChooseLimitCallback;
import com.luck.picture.lib.listener.OnCustomCameraInterfaceListener;
import com.luck.picture.lib.listener.OnCustomImagePreviewCallback;
import com.luck.picture.lib.listener.OnPermissionsObtainCallback;
import com.luck.picture.lib.listener.OnResultCallbackListener;
import com.luck.picture.lib.listener.OnVideoSelectedPlayCallback;
import com.luck.picture.lib.style.PictureCropParameterStyle;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.style.PictureSelectorUIStyle;
import com.luck.picture.lib.style.PictureWindowAnimationStyle;
import com.luck.picture.lib.tools.DoubleUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.yalantis.ucrop.UCrop;
import java.lang.ref.WeakReference;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Objects;

public class PictureSelectionModel {
    private final PictureSelectionConfig selectionConfig;
    private final PictureSelector selector;

    public PictureSelectionModel(PictureSelector pictureSelector, int i5) {
        this.selector = pictureSelector;
        PictureSelectionConfig cleanInstance = PictureSelectionConfig.getCleanInstance();
        this.selectionConfig = cleanInstance;
        cleanInstance.chooseMode = i5;
        initCustomCameraFeatures();
    }

    public PictureSelectionModel(PictureSelector pictureSelector, int i5, boolean z4) {
        this.selector = pictureSelector;
        PictureSelectionConfig cleanInstance = PictureSelectionConfig.getCleanInstance();
        this.selectionConfig = cleanInstance;
        cleanInstance.camera = z4;
        cleanInstance.chooseMode = i5;
        initCustomCameraFeatures();
    }

    private PictureSelectionModel initCustomCameraFeatures() {
        if (this.selectionConfig.chooseMode != PictureMimeType.ofImage()) {
            if (this.selectionConfig.chooseMode != PictureMimeType.ofVideo()) {
                if (this.selectionConfig.ofAllCameraType != PictureMimeType.ofImage()) {
                    if (this.selectionConfig.ofAllCameraType != PictureMimeType.ofVideo()) {
                        this.selectionConfig.buttonFeatures = CustomCameraType.BUTTON_STATE_BOTH;
                        return this;
                    }
                }
            }
            this.selectionConfig.buttonFeatures = CustomCameraType.BUTTON_STATE_ONLY_RECORDER;
            return this;
        }
        this.selectionConfig.buttonFeatures = CustomCameraType.BUTTON_STATE_ONLY_CAPTURE;
        return this;
    }

    public PictureSelectionModel basicUCropConfig(UCrop.Options options) {
        this.selectionConfig.uCropOptions = options;
        return this;
    }

    public PictureSelectionModel bindCustomCameraInterfaceListener(OnCustomCameraInterfaceListener onCustomCameraInterfaceListener) {
        PictureSelectionConfig.onCustomCameraInterfaceListener = (OnCustomCameraInterfaceListener) new WeakReference(onCustomCameraInterfaceListener).get();
        return this;
    }

    public PictureSelectionModel bindCustomChooseLimitListener(OnChooseLimitCallback onChooseLimitCallback) {
        PictureSelectionConfig.onChooseLimitCallback = (OnChooseLimitCallback) new WeakReference(onChooseLimitCallback).get();
        return this;
    }

    public PictureSelectionModel bindCustomPermissionsObtainListener(OnPermissionsObtainCallback onPermissionsObtainCallback) {
        PictureSelectionConfig.onPermissionsObtainCallback = (OnPermissionsObtainCallback) new WeakReference(onPermissionsObtainCallback).get();
        return this;
    }

    public PictureSelectionModel bindCustomPlayVideoCallback(OnVideoSelectedPlayCallback<LocalMedia> onVideoSelectedPlayCallback) {
        PictureSelectionConfig.customVideoPlayCallback = (OnVideoSelectedPlayCallback) new WeakReference(onVideoSelectedPlayCallback).get();
        return this;
    }

    public PictureSelectionModel bindCustomPreviewCallback(OnCustomImagePreviewCallback<LocalMedia> onCustomImagePreviewCallback) {
        PictureSelectionConfig.onCustomImagePreviewCallback = (OnCustomImagePreviewCallback) new WeakReference(onCustomImagePreviewCallback).get();
        return this;
    }

    @Deprecated
    public PictureSelectionModel bindPictureSelectorInterfaceListener(OnCustomCameraInterfaceListener onCustomCameraInterfaceListener) {
        PictureSelectionConfig.onCustomCameraInterfaceListener = (OnCustomCameraInterfaceListener) new WeakReference(onCustomCameraInterfaceListener).get();
        return this;
    }

    public PictureSelectionModel cameraFileName(String str) {
        this.selectionConfig.cameraFileName = str;
        return this;
    }

    public PictureSelectionModel circleDimmedLayer(boolean z4) {
        this.selectionConfig.circleDimmedLayer = z4;
        return this;
    }

    @Deprecated
    public PictureSelectionModel compress(boolean z4) {
        this.selectionConfig.isCompress = z4;
        return this;
    }

    public PictureSelectionModel compressEngine(CompressEngine compressEngine) {
        if (PictureSelectionConfig.compressEngine != compressEngine) {
            PictureSelectionConfig.compressEngine = compressEngine;
        }
        return this;
    }

    @Deprecated
    public PictureSelectionModel compressFocusAlpha(boolean z4) {
        this.selectionConfig.focusAlpha = z4;
        return this;
    }

    public PictureSelectionModel compressQuality(int i5) {
        this.selectionConfig.compressQuality = i5;
        return this;
    }

    public PictureSelectionModel compressSavePath(String str) {
        this.selectionConfig.compressSavePath = str;
        return this;
    }

    @Deprecated
    public PictureSelectionModel cropCompressQuality(int i5) {
        this.selectionConfig.cropCompressQuality = i5;
        return this;
    }

    public PictureSelectionModel cropImageWideHigh(int i5, int i6) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.cropWidth = i5;
        pictureSelectionConfig.cropHeight = i6;
        return this;
    }

    @Deprecated
    public PictureSelectionModel cropWH(int i5, int i6) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.cropWidth = i5;
        pictureSelectionConfig.cropHeight = i6;
        return this;
    }

    public PictureSelectionModel cutCompressFormat(String str) {
        this.selectionConfig.cropCompressFormat = str;
        return this;
    }

    public PictureSelectionModel cutOutQuality(int i5) {
        this.selectionConfig.cropCompressQuality = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel enableCrop(boolean z4) {
        this.selectionConfig.enableCrop = z4;
        return this;
    }

    @Deprecated
    public PictureSelectionModel enablePreviewAudio(boolean z4) {
        this.selectionConfig.enablePreviewAudio = z4;
        return this;
    }

    public void externalPictureVideo(String str) {
        PictureSelector pictureSelector = this.selector;
        Objects.requireNonNull(pictureSelector, "This PictureSelector is Null");
        pictureSelector.externalPictureVideo(str);
    }

    public PictureSelectionModel filterMaxFileSize(long j5) {
        int i5 = (j5 > PictureConfig.MB ? 1 : (j5 == PictureConfig.MB ? 0 : -1));
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        if (i5 < 0) {
            j5 *= 1024;
        }
        pictureSelectionConfig.filterMaxFileSize = j5;
        return this;
    }

    public PictureSelectionModel filterMinFileSize(long j5) {
        int i5 = (j5 > PictureConfig.MB ? 1 : (j5 == PictureConfig.MB ? 0 : -1));
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        if (i5 < 0) {
            j5 *= 1024;
        }
        pictureSelectionConfig.filterMinFileSize = j5;
        return this;
    }

    public void forResult(int i5) {
        Activity activity;
        PictureSelectionConfig pictureSelectionConfig;
        Intent intent;
        if (!DoubleUtils.isFastDoubleClick() && (activity = this.selector.getActivity()) != null && (pictureSelectionConfig = this.selectionConfig) != null) {
            Objects.requireNonNull(PictureSelectionConfig.imageEngine, "api imageEngine is null,Please implement ImageEngine");
            if (!pictureSelectionConfig.camera || !pictureSelectionConfig.isUseCustomCamera) {
                PictureSelectionConfig pictureSelectionConfig2 = this.selectionConfig;
                intent = new Intent(activity, pictureSelectionConfig2.camera ? PictureSelectorCameraEmptyActivity.class : pictureSelectionConfig2.isWeChatStyle ? PictureSelectorWeChatStyleActivity.class : PictureSelectorActivity.class);
            } else {
                intent = new Intent(activity, PictureCustomCameraActivity.class);
            }
            this.selectionConfig.isCallbackMode = false;
            Fragment fragment = this.selector.getFragment();
            if (fragment != null) {
                fragment.startActivityForResult(intent, i5);
            } else {
                activity.startActivityForResult(intent, i5);
            }
            activity.overridePendingTransition(PictureSelectionConfig.windowAnimationStyle.activityEnterAnimation, R.anim.picture_anim_fade_in);
        }
    }

    @Deprecated
    public void forResult(int i5, int i6, int i7) {
        Activity activity;
        if (!DoubleUtils.isFastDoubleClick() && (activity = this.selector.getActivity()) != null && this.selectionConfig != null) {
            Objects.requireNonNull(PictureSelectionConfig.imageEngine, "api imageEngine is null,Please implement ImageEngine");
            PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
            Intent intent = new Intent(activity, pictureSelectionConfig.camera ? PictureSelectorCameraEmptyActivity.class : pictureSelectionConfig.isWeChatStyle ? PictureSelectorWeChatStyleActivity.class : PictureSelectorActivity.class);
            this.selectionConfig.isCallbackMode = false;
            Fragment fragment = this.selector.getFragment();
            if (fragment != null) {
                fragment.startActivityForResult(intent, i5);
            } else {
                activity.startActivityForResult(intent, i5);
            }
            activity.overridePendingTransition(i6, i7);
        }
    }

    public void forResult(int i5, OnResultCallbackListener<LocalMedia> onResultCallbackListener) {
        Activity activity;
        Intent intent;
        if (!DoubleUtils.isFastDoubleClick() && (activity = this.selector.getActivity()) != null && this.selectionConfig != null) {
            Objects.requireNonNull(PictureSelectionConfig.imageEngine, "api imageEngine is null,Please implement ImageEngine");
            PictureSelectionConfig.listener = (OnResultCallbackListener) new WeakReference(onResultCallbackListener).get();
            PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
            pictureSelectionConfig.isCallbackMode = true;
            if (!pictureSelectionConfig.camera || !pictureSelectionConfig.isUseCustomCamera) {
                PictureSelectionConfig pictureSelectionConfig2 = this.selectionConfig;
                intent = new Intent(activity, pictureSelectionConfig2.camera ? PictureSelectorCameraEmptyActivity.class : pictureSelectionConfig2.isWeChatStyle ? PictureSelectorWeChatStyleActivity.class : PictureSelectorActivity.class);
            } else {
                intent = new Intent(activity, PictureCustomCameraActivity.class);
            }
            Fragment fragment = this.selector.getFragment();
            if (fragment != null) {
                fragment.startActivityForResult(intent, i5);
            } else {
                activity.startActivityForResult(intent, i5);
            }
            activity.overridePendingTransition(PictureSelectionConfig.windowAnimationStyle.activityEnterAnimation, R.anim.picture_anim_fade_in);
        }
    }

    public void forResult(c<Intent> cVar) {
        PictureSelectionConfig pictureSelectionConfig;
        Intent intent;
        if (!DoubleUtils.isFastDoubleClick()) {
            Activity activity = this.selector.getActivity();
            if (cVar != null && activity != null && (pictureSelectionConfig = this.selectionConfig) != null) {
                Objects.requireNonNull(PictureSelectionConfig.imageEngine, "api imageEngine is null,Please implement ImageEngine");
                if (!pictureSelectionConfig.camera || !pictureSelectionConfig.isUseCustomCamera) {
                    PictureSelectionConfig pictureSelectionConfig2 = this.selectionConfig;
                    intent = new Intent(activity, pictureSelectionConfig2.camera ? PictureSelectorCameraEmptyActivity.class : pictureSelectionConfig2.isWeChatStyle ? PictureSelectorWeChatStyleActivity.class : PictureSelectorActivity.class);
                } else {
                    intent = new Intent(activity, PictureCustomCameraActivity.class);
                }
                this.selectionConfig.isCallbackMode = false;
                cVar.a(intent);
                activity.overridePendingTransition(PictureSelectionConfig.windowAnimationStyle.activityEnterAnimation, R.anim.picture_anim_fade_in);
            }
        }
    }

    public void forResult(OnResultCallbackListener<LocalMedia> onResultCallbackListener) {
        Activity activity;
        Intent intent;
        if (!DoubleUtils.isFastDoubleClick() && (activity = this.selector.getActivity()) != null && this.selectionConfig != null) {
            Objects.requireNonNull(PictureSelectionConfig.imageEngine, "api imageEngine is null,Please implement ImageEngine");
            PictureSelectionConfig.listener = (OnResultCallbackListener) new WeakReference(onResultCallbackListener).get();
            PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
            pictureSelectionConfig.isCallbackMode = true;
            if (!pictureSelectionConfig.camera || !pictureSelectionConfig.isUseCustomCamera) {
                PictureSelectionConfig pictureSelectionConfig2 = this.selectionConfig;
                intent = new Intent(activity, pictureSelectionConfig2.camera ? PictureSelectorCameraEmptyActivity.class : pictureSelectionConfig2.isWeChatStyle ? PictureSelectorWeChatStyleActivity.class : PictureSelectorActivity.class);
            } else {
                intent = new Intent(activity, PictureCustomCameraActivity.class);
            }
            Fragment fragment = this.selector.getFragment();
            if (fragment != null) {
                fragment.startActivity(intent);
            } else {
                activity.startActivity(intent);
            }
            activity.overridePendingTransition(PictureSelectionConfig.windowAnimationStyle.activityEnterAnimation, R.anim.picture_anim_fade_in);
        }
    }

    @Deprecated
    public PictureSelectionModel freeStyleCropEnabled(boolean z4) {
        this.selectionConfig.freeStyleCropEnabled = z4;
        return this;
    }

    public PictureSelectionModel freeStyleCropMode(int i5) {
        this.selectionConfig.freeStyleCropMode = i5;
        return this;
    }

    public PictureSelectionModel hideBottomControls(boolean z4) {
        this.selectionConfig.hideBottomControls = z4;
        return this;
    }

    public PictureSelectionModel imageEngine(ImageEngine imageEngine) {
        if (PictureSelectionConfig.imageEngine != imageEngine) {
            PictureSelectionConfig.imageEngine = imageEngine;
        }
        return this;
    }

    @Deprecated
    public PictureSelectionModel imageFormat(String str) {
        this.selectionConfig.suffixType = str;
        return this;
    }

    public PictureSelectionModel imageSpanCount(int i5) {
        this.selectionConfig.imageSpanCount = i5;
        return this;
    }

    public PictureSelectionModel isAndroidQTransform(boolean z4) {
        this.selectionConfig.isAndroidQTransform = z4;
        return this;
    }

    public PictureSelectionModel isAutoRotating(boolean z4) {
        this.selectionConfig.isAutoRotating = z4;
        return this;
    }

    public PictureSelectionModel isAutoScalePreviewImage(boolean z4) {
        this.selectionConfig.isAutoScalePreviewImage = z4;
        return this;
    }

    public PictureSelectionModel isAutomaticTitleRecyclerTop(boolean z4) {
        this.selectionConfig.isAutomaticTitleRecyclerTop = z4;
        return this;
    }

    public PictureSelectionModel isBmp(boolean z4) {
        this.selectionConfig.isBmp = z4;
        return this;
    }

    public PictureSelectionModel isCamera(boolean z4) {
        this.selectionConfig.isCamera = z4;
        return this;
    }

    public PictureSelectionModel isCameraAroundState(boolean z4) {
        this.selectionConfig.isCameraAroundState = z4;
        return this;
    }

    public PictureSelectionModel isCameraRotateImage(boolean z4) {
        this.selectionConfig.isCameraRotateImage = z4;
        return this;
    }

    @Deprecated
    public PictureSelectionModel isChangeStatusBarFontColor(boolean z4) {
        this.selectionConfig.isChangeStatusBarFontColor = z4;
        return this;
    }

    public PictureSelectionModel isCompress(boolean z4) {
        this.selectionConfig.isCompress = z4;
        return this;
    }

    public PictureSelectionModel isCropDragSmoothToCenter(boolean z4) {
        this.selectionConfig.isDragCenter = z4;
        return this;
    }

    public PictureSelectionModel isDisplayOriginalSize(boolean z4) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.isDisplayOriginalSize = !pictureSelectionConfig.camera && z4;
        return this;
    }

    public PictureSelectionModel isDragFrame(boolean z4) {
        this.selectionConfig.isDragFrame = z4;
        return this;
    }

    public PictureSelectionModel isEditorImage(boolean z4) {
        this.selectionConfig.isEditorImage = z4;
        return this;
    }

    public PictureSelectionModel isEnableCrop(boolean z4) {
        this.selectionConfig.enableCrop = z4;
        return this;
    }

    public PictureSelectionModel isEnablePreviewAudio(boolean z4) {
        this.selectionConfig.enablePreviewAudio = z4;
        return this;
    }

    public PictureSelectionModel isFallbackVersion(boolean z4) {
        this.selectionConfig.isFallbackVersion = z4;
        return this;
    }

    public PictureSelectionModel isFallbackVersion2(boolean z4) {
        this.selectionConfig.isFallbackVersion2 = z4;
        return this;
    }

    public PictureSelectionModel isFallbackVersion3(boolean z4) {
        this.selectionConfig.isFallbackVersion3 = z4;
        return this;
    }

    public PictureSelectionModel isGetOnlySandboxDirectory(boolean z4) {
        this.selectionConfig.isOnlySandboxDir = z4;
        return this;
    }

    public PictureSelectionModel isGif(boolean z4) {
        this.selectionConfig.isGif = z4;
        return this;
    }

    public PictureSelectionModel isMaxSelectEnabledMask(boolean z4) {
        this.selectionConfig.isMaxSelectEnabledMask = z4;
        return this;
    }

    public PictureSelectionModel isMultipleRecyclerAnimation(boolean z4) {
        this.selectionConfig.isMultipleRecyclerAnimation = z4;
        return this;
    }

    public PictureSelectionModel isMultipleSkipCrop(boolean z4) {
        this.selectionConfig.isMultipleSkipCrop = z4;
        return this;
    }

    public PictureSelectionModel isNotPreviewDownload(boolean z4) {
        this.selectionConfig.isNotPreviewDownload = z4;
        return this;
    }

    public PictureSelectionModel isOpenClickSound(boolean z4) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.openClickSound = !pictureSelectionConfig.camera && z4;
        return this;
    }

    @Deprecated
    public PictureSelectionModel isOpenStyleCheckNumMode(boolean z4) {
        this.selectionConfig.isOpenStyleCheckNumMode = z4;
        return this;
    }

    @Deprecated
    public PictureSelectionModel isOpenStyleNumComplete(boolean z4) {
        this.selectionConfig.isOpenStyleNumComplete = z4;
        return this;
    }

    public PictureSelectionModel isOriginalImageControl(boolean z4) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.isOriginalControl = !pictureSelectionConfig.camera && pictureSelectionConfig.chooseMode != PictureMimeType.ofVideo() && this.selectionConfig.chooseMode != PictureMimeType.ofAudio() && z4;
        return this;
    }

    public PictureSelectionModel isPageStrategy(boolean z4) {
        this.selectionConfig.isPageStrategy = z4;
        return this;
    }

    public PictureSelectionModel isPageStrategy(boolean z4, int i5) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.isPageStrategy = z4;
        if (i5 < 10) {
            i5 = 60;
        }
        pictureSelectionConfig.pageSize = i5;
        return this;
    }

    public PictureSelectionModel isPageStrategy(boolean z4, int i5, boolean z5) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.isPageStrategy = z4;
        if (i5 < 10) {
            i5 = 60;
        }
        pictureSelectionConfig.pageSize = i5;
        pictureSelectionConfig.isFilterInvalidFile = z5;
        return this;
    }

    public PictureSelectionModel isPageStrategy(boolean z4, boolean z5) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.isPageStrategy = z4;
        pictureSelectionConfig.isFilterInvalidFile = z5;
        return this;
    }

    public PictureSelectionModel isPreviewEggs(boolean z4) {
        this.selectionConfig.previewEggs = z4;
        return this;
    }

    public PictureSelectionModel isPreviewImage(boolean z4) {
        this.selectionConfig.enablePreview = z4;
        return this;
    }

    public PictureSelectionModel isPreviewVideo(boolean z4) {
        this.selectionConfig.enPreviewVideo = z4;
        return this;
    }

    public PictureSelectionModel isQuickCapture(boolean z4) {
        this.selectionConfig.isQuickCapture = z4;
        return this;
    }

    public PictureSelectionModel isReturnEmpty(boolean z4) {
        this.selectionConfig.returnEmpty = z4;
        return this;
    }

    public PictureSelectionModel isSingleDirectReturn(boolean z4) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        int i5 = pictureSelectionConfig.selectionMode;
        boolean z5 = false;
        pictureSelectionConfig.isSingleDirectReturn = i5 == 1 && z4;
        if ((i5 != 1 || !z4) && pictureSelectionConfig.isOriginalControl) {
            z5 = true;
        }
        pictureSelectionConfig.isOriginalControl = z5;
        return this;
    }

    public PictureSelectionModel isSyncCover(boolean z4) {
        this.selectionConfig.isSyncCover = z4;
        return this;
    }

    public PictureSelectionModel isUseCustomCamera(boolean z4) {
        this.selectionConfig.isUseCustomCamera = Build.VERSION.SDK_INT > 19 && z4;
        return this;
    }

    public PictureSelectionModel isWeChatStyle(boolean z4) {
        this.selectionConfig.isWeChatStyle = z4;
        return this;
    }

    public PictureSelectionModel isWebp(boolean z4) {
        this.selectionConfig.isWebp = z4;
        return this;
    }

    public PictureSelectionModel isWithVideoImage(boolean z4) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        boolean z5 = true;
        if (pictureSelectionConfig.selectionMode == 1 || pictureSelectionConfig.chooseMode != PictureMimeType.ofAll() || !z4) {
            z5 = false;
        }
        pictureSelectionConfig.isWithVideoImage = z5;
        return this;
    }

    public PictureSelectionModel isZoomAnim(boolean z4) {
        this.selectionConfig.zoomAnim = z4;
        return this;
    }

    @Deprecated
    public PictureSelectionModel loadImageEngine(ImageEngine imageEngine) {
        if (PictureSelectionConfig.imageEngine != imageEngine) {
            PictureSelectionConfig.imageEngine = imageEngine;
        }
        return this;
    }

    public PictureSelectionModel maxSelectNum(int i5) {
        this.selectionConfig.maxSelectNum = i5;
        return this;
    }

    public PictureSelectionModel maxVideoSelectNum(int i5) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        if (pictureSelectionConfig.chooseMode == PictureMimeType.ofVideo()) {
            i5 = 0;
        }
        pictureSelectionConfig.maxVideoSelectNum = i5;
        return this;
    }

    public PictureSelectionModel minSelectNum(int i5) {
        this.selectionConfig.minSelectNum = i5;
        return this;
    }

    public PictureSelectionModel minVideoSelectNum(int i5) {
        this.selectionConfig.minVideoSelectNum = i5;
        return this;
    }

    public PictureSelectionModel minimumCompressSize(int i5) {
        this.selectionConfig.minimumCompressSize = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel openClickSound(boolean z4) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.openClickSound = !pictureSelectionConfig.camera && z4;
        return this;
    }

    @Deprecated
    public void openExternalPreview(int i5, String str, List<LocalMedia> list) {
        PictureSelector pictureSelector = this.selector;
        Objects.requireNonNull(pictureSelector, "This PictureSelector is Null");
        pictureSelector.externalPicturePreview(i5, str, list, PictureSelectionConfig.windowAnimationStyle.activityPreviewEnterAnimation);
    }

    public void openExternalPreview(int i5, List<LocalMedia> list) {
        PictureSelector pictureSelector = this.selector;
        Objects.requireNonNull(pictureSelector, "This PictureSelector is Null");
        pictureSelector.externalPicturePreview(i5, list, PictureSelectionConfig.windowAnimationStyle.activityPreviewEnterAnimation);
    }

    @Deprecated
    public PictureSelectionModel previewEggs(boolean z4) {
        this.selectionConfig.previewEggs = z4;
        return this;
    }

    @Deprecated
    public PictureSelectionModel previewImage(boolean z4) {
        this.selectionConfig.enablePreview = z4;
        return this;
    }

    @Deprecated
    public PictureSelectionModel previewVideo(boolean z4) {
        this.selectionConfig.enPreviewVideo = z4;
        return this;
    }

    @Deprecated
    public PictureSelectionModel queryFileSize(float f5) {
        this.selectionConfig.filterFileSize = f5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel queryMaxFileSize(float f5) {
        this.selectionConfig.filterFileSize = f5;
        return this;
    }

    public PictureSelectionModel queryMimeTypeConditions(String... strArr) {
        if (strArr == null || strArr.length <= 0) {
            this.selectionConfig.queryMimeTypeHashSet = null;
        } else {
            this.selectionConfig.queryMimeTypeHashSet = new HashSet<>(Arrays.asList(strArr));
        }
        return this;
    }

    @Deprecated
    public PictureSelectionModel querySpecifiedFormatSuffix(String str) {
        this.selectionConfig.specifiedFormat = str;
        return this;
    }

    public PictureSelectionModel recordVideoMinSecond(int i5) {
        this.selectionConfig.recordVideoMinSecond = i5;
        return this;
    }

    public PictureSelectionModel recordVideoSecond(int i5) {
        this.selectionConfig.recordVideoSecond = i5;
        return this;
    }

    public PictureSelectionModel renameCompressFile(String str) {
        this.selectionConfig.renameCompressFileName = str;
        return this;
    }

    public PictureSelectionModel renameCropFileName(String str) {
        this.selectionConfig.renameCropFileName = str;
        return this;
    }

    public PictureSelectionModel rotateEnabled(boolean z4) {
        this.selectionConfig.rotateEnabled = z4;
        return this;
    }

    public PictureSelectionModel scaleEnabled(boolean z4) {
        this.selectionConfig.scaleEnabled = z4;
        return this;
    }

    public PictureSelectionModel selectionData(List<LocalMedia> list) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        if (pictureSelectionConfig.selectionMode == 1 && pictureSelectionConfig.isSingleDirectReturn) {
            list = null;
        }
        pictureSelectionConfig.selectionMedias = list;
        return this;
    }

    @Deprecated
    public PictureSelectionModel selectionMedia(List<LocalMedia> list) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        if (pictureSelectionConfig.selectionMode == 1 && pictureSelectionConfig.isSingleDirectReturn) {
            list = null;
        }
        pictureSelectionConfig.selectionMedias = list;
        return this;
    }

    public PictureSelectionModel selectionMode(int i5) {
        this.selectionConfig.selectionMode = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setButtonFeatures(int i5) {
        this.selectionConfig.buttonFeatures = i5;
        return this;
    }

    public PictureSelectionModel setCameraAudioFormat(String str) {
        this.selectionConfig.cameraAudioFormat = str;
        if (SdkVersionUtils.isQ() || SdkVersionUtils.isR()) {
            if (TextUtils.equals(str, ".amr")) {
                this.selectionConfig.cameraAudioFormatForQ = "audio/amr";
            }
            if (TextUtils.equals(str, PictureMimeType.WAV)) {
                this.selectionConfig.cameraAudioFormatForQ = PictureMimeType.WAV_Q;
            }
            if (TextUtils.equals(str, PictureMimeType.MP3)) {
                this.selectionConfig.cameraAudioFormatForQ = "audio/mpeg";
            }
        }
        return this;
    }

    public PictureSelectionModel setCameraImageFormat(String str) {
        this.selectionConfig.cameraImageFormat = str;
        if (SdkVersionUtils.isQ() || SdkVersionUtils.isR()) {
            if (TextUtils.equals(str, PictureMimeType.PNG)) {
                this.selectionConfig.cameraImageFormatForQ = PictureMimeType.PNG_Q;
            }
            if (TextUtils.equals(str, PictureMimeType.JPG) || TextUtils.equals(str, ".jpeg")) {
                this.selectionConfig.cameraImageFormatForQ = "image/jpeg";
            }
        }
        return this;
    }

    public PictureSelectionModel setCameraVideoFormat(String str) {
        this.selectionConfig.cameraVideoFormat = str;
        if (SdkVersionUtils.isQ() || SdkVersionUtils.isR()) {
            if (TextUtils.equals(str, ".mp4")) {
                this.selectionConfig.cameraVideoFormatForQ = "video/mp4";
            }
            if (TextUtils.equals(str, PictureMimeType.AVI)) {
                this.selectionConfig.cameraVideoFormatForQ = PictureMimeType.AVI_Q;
            }
        }
        return this;
    }

    public PictureSelectionModel setCaptureLoadingColor(int i5) {
        this.selectionConfig.captureLoadingColor = i5;
        return this;
    }

    public PictureSelectionModel setCircleDimmedBorderColor(int i5) {
        this.selectionConfig.circleDimmedBorderColor = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setCircleDimmedColor(int i5) {
        this.selectionConfig.circleDimmedColor = i5;
        return this;
    }

    public PictureSelectionModel setCircleStrokeWidth(int i5) {
        this.selectionConfig.circleStrokeWidth = i5;
        return this;
    }

    public PictureSelectionModel setCropDimmedColor(int i5) {
        this.selectionConfig.circleDimmedColor = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setCropStatusBarColorPrimaryDark(int i5) {
        this.selectionConfig.cropStatusBarColorPrimaryDark = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setCropTitleBarBackgroundColor(int i5) {
        this.selectionConfig.cropTitleBarBackgroundColor = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setCropTitleColor(int i5) {
        this.selectionConfig.cropTitleColor = i5;
        return this;
    }

    public PictureSelectionModel setCustomCameraFeatures(int i5) {
        if (this.selectionConfig.chooseMode != PictureMimeType.ofImage()) {
            if (this.selectionConfig.chooseMode != PictureMimeType.ofVideo()) {
                if (this.selectionConfig.ofAllCameraType != PictureMimeType.ofImage()) {
                    if (this.selectionConfig.ofAllCameraType != PictureMimeType.ofVideo()) {
                        this.selectionConfig.buttonFeatures = i5;
                        return this;
                    }
                }
            }
            this.selectionConfig.buttonFeatures = CustomCameraType.BUTTON_STATE_ONLY_RECORDER;
            return this;
        }
        this.selectionConfig.buttonFeatures = CustomCameraType.BUTTON_STATE_ONLY_CAPTURE;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setDownArrowDrawable(int i5) {
        this.selectionConfig.downResId = i5;
        return this;
    }

    public PictureSelectionModel setLanguage(int i5) {
        this.selectionConfig.language = i5;
        return this;
    }

    public PictureSelectionModel setOfAllCameraType(int i5) {
        this.selectionConfig.ofAllCameraType = i5;
        return this;
    }

    public PictureSelectionModel setOutputCameraPath(String str) {
        this.selectionConfig.outPutCameraPath = str;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setPictureCropStyle(PictureCropParameterStyle pictureCropParameterStyle) {
        if (pictureCropParameterStyle == null) {
            pictureCropParameterStyle = PictureCropParameterStyle.ofDefaultCropStyle();
        }
        PictureSelectionConfig.cropStyle = pictureCropParameterStyle;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setPictureStyle(PictureParameterStyle pictureParameterStyle) {
        if (pictureParameterStyle != null) {
            PictureSelectionConfig.style = pictureParameterStyle;
            PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
            if (!pictureSelectionConfig.isWeChatStyle) {
                pictureSelectionConfig.isWeChatStyle = pictureParameterStyle.isNewSelectStyle;
            }
        } else {
            PictureSelectionConfig.style = PictureParameterStyle.ofDefaultStyle();
        }
        return this;
    }

    public PictureSelectionModel setPictureUIStyle(PictureSelectorUIStyle pictureSelectorUIStyle) {
        if (pictureSelectorUIStyle != null) {
            PictureSelectionConfig.uiStyle = pictureSelectorUIStyle;
            PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
            if (!pictureSelectionConfig.isWeChatStyle) {
                pictureSelectionConfig.isWeChatStyle = pictureSelectorUIStyle.isNewSelectStyle;
            }
        }
        return this;
    }

    public PictureSelectionModel setPictureWindowAnimationStyle(PictureWindowAnimationStyle pictureWindowAnimationStyle) {
        if (pictureWindowAnimationStyle == null) {
            pictureWindowAnimationStyle = PictureWindowAnimationStyle.ofDefaultWindowAnimationStyle();
        }
        PictureSelectionConfig.windowAnimationStyle = pictureWindowAnimationStyle;
        return this;
    }

    public PictureSelectionModel setQuerySandboxDirectory(String str) {
        this.selectionConfig.sandboxFolderPath = str;
        return this;
    }

    public PictureSelectionModel setRecyclerAnimationMode(int i5) {
        this.selectionConfig.animationMode = i5;
        return this;
    }

    public PictureSelectionModel setRequestedOrientation(int i5) {
        this.selectionConfig.requestedOrientation = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setStatusBarColorPrimaryDark(int i5) {
        this.selectionConfig.pictureStatusBarColor = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setTitleBarBackgroundColor(int i5) {
        this.selectionConfig.titleBarBackgroundColor = i5;
        return this;
    }

    @Deprecated
    public PictureSelectionModel setUpArrowDrawable(int i5) {
        this.selectionConfig.upResId = i5;
        return this;
    }

    public PictureSelectionModel showCropFrame(boolean z4) {
        this.selectionConfig.showCropFrame = z4;
        return this;
    }

    public PictureSelectionModel showCropGrid(boolean z4) {
        this.selectionConfig.showCropGrid = z4;
        return this;
    }

    public PictureSelectionModel synOrAsy(boolean z4) {
        this.selectionConfig.synOrAsy = z4;
        return this;
    }

    public PictureSelectionModel theme(int i5) {
        this.selectionConfig.themeStyleId = i5;
        return this;
    }

    public PictureSelectionModel videoMaxSecond(int i5) {
        this.selectionConfig.videoMaxSecond = i5 * 1000;
        return this;
    }

    public PictureSelectionModel videoMinSecond(int i5) {
        this.selectionConfig.videoMinSecond = i5 * 1000;
        return this;
    }

    public PictureSelectionModel videoQuality(int i5) {
        this.selectionConfig.videoQuality = i5;
        return this;
    }

    public PictureSelectionModel withAspectRatio(int i5, int i6) {
        PictureSelectionConfig pictureSelectionConfig = this.selectionConfig;
        pictureSelectionConfig.aspect_ratio_x = i5;
        pictureSelectionConfig.aspect_ratio_y = i6;
        return this;
    }
}
