package com.luck.picture.lib;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.Window;
import android.view.WindowManager;
import androidx.core.content.a;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.MediaExtraInfo;
import com.luck.picture.lib.immersive.ImmersiveManage;
import com.luck.picture.lib.listener.OnCustomCameraInterfaceListener;
import com.luck.picture.lib.listener.OnResultCallbackListener;
import com.luck.picture.lib.manager.UCropManager;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.tools.AlbumUtils;
import com.luck.picture.lib.tools.BitmapUtils;
import com.luck.picture.lib.tools.CameraFileUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.ValueOf;
import com.yalantis.ucrop.UCrop;
import com.yalantis.ucrop.view.CropImageView;
import java.io.File;
import java.util.ArrayList;

public class PictureSelectorCameraEmptyActivity extends PictureBaseActivity {
    private void dispatchCameraHandleResult(LocalMedia localMedia) {
        boolean isHasImage = PictureMimeType.isHasImage(localMedia.getMimeType());
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.enableCrop && !pictureSelectionConfig.isCheckOriginalImage && isHasImage) {
            String str = pictureSelectionConfig.cameraPath;
            pictureSelectionConfig.originalPath = str;
            UCropManager.ofCrop(this, str, localMedia.getMimeType(), localMedia.getWidth(), localMedia.getHeight());
        } else if (!pictureSelectionConfig.isCompress || !isHasImage) {
            ArrayList arrayList = new ArrayList();
            arrayList.add(localMedia);
            onResult(arrayList);
        } else {
            ArrayList arrayList2 = new ArrayList();
            arrayList2.add(localMedia);
            compressImage(arrayList2);
        }
    }

    private void onTakePhoto() {
        if (PermissionChecker.checkSelfPermission(this, "android.permission.CAMERA")) {
            startCamera();
        } else {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
        }
    }

    private void setActivitySize() {
        Window window = getWindow();
        window.setGravity(51);
        WindowManager.LayoutParams attributes = window.getAttributes();
        attributes.x = 0;
        attributes.y = 0;
        attributes.height = 1;
        attributes.width = 1;
        window.setAttributes(attributes);
    }

    private void startCamera() {
        int i5 = this.config.chooseMode;
        if (i5 == 0 || i5 == 1) {
            startOpenCameraImage();
        } else if (i5 == 2) {
            startOpenCameraVideo();
        } else if (i5 == 3) {
            startOpenCameraAudio();
        }
    }

    /* access modifiers changed from: protected */
    public void dispatchHandleCamera(Intent intent) {
        String imageMimeType;
        long lastModified;
        long duration;
        int dCIMLastImageId;
        long duration2;
        try {
            if (this.config.chooseMode == PictureMimeType.ofAudio()) {
                this.config.cameraMimeType = PictureMimeType.ofAudio();
                this.config.cameraPath = getAudioPath(intent);
                if (!TextUtils.isEmpty(this.config.cameraPath)) {
                    if (SdkVersionUtils.isR()) {
                        try {
                            Uri createAudioUri = CameraFileUtils.createAudioUri(getContext(), TextUtils.isEmpty(this.config.cameraAudioFormatForQ) ? this.config.suffixType : this.config.cameraAudioFormatForQ);
                            if (createAudioUri != null) {
                                PictureFileUtils.writeFileFromIS(PictureContentResolver.getContentResolverOpenInputStream(this, Uri.parse(this.config.cameraPath)), PictureContentResolver.getContentResolverOpenOutputStream(this, createAudioUri));
                                this.config.cameraPath = createAudioUri.toString();
                            }
                        } catch (Exception e5) {
                            e5.printStackTrace();
                        }
                    }
                } else {
                    return;
                }
            }
            if (!TextUtils.isEmpty(this.config.cameraPath)) {
                LocalMedia localMedia = new LocalMedia();
                String str = null;
                if (PictureMimeType.isContent(this.config.cameraPath)) {
                    String path = PictureFileUtils.getPath(getContext(), Uri.parse(this.config.cameraPath));
                    File file = new File(path);
                    imageMimeType = PictureMimeType.getImageMimeType(path, this.config.cameraMimeType);
                    localMedia.setSize(file.length());
                    localMedia.setFileName(file.getName());
                    if (PictureMimeType.isHasImage(imageMimeType)) {
                        MediaExtraInfo imageSize = MediaUtils.getImageSize(getContext(), this.config.cameraPath);
                        localMedia.setWidth(imageSize.getWidth());
                        localMedia.setHeight(imageSize.getHeight());
                    } else {
                        if (PictureMimeType.isHasVideo(imageMimeType)) {
                            MediaExtraInfo videoSize = MediaUtils.getVideoSize(getContext(), this.config.cameraPath);
                            localMedia.setWidth(videoSize.getWidth());
                            localMedia.setHeight(videoSize.getHeight());
                            duration2 = videoSize.getDuration();
                        } else if (PictureMimeType.isHasAudio(imageMimeType)) {
                            duration2 = MediaUtils.getAudioSize(getContext(), this.config.cameraPath).getDuration();
                        }
                        localMedia.setDuration(duration2);
                    }
                    int lastIndexOf = TextUtils.isEmpty(this.config.cameraPath) ? 0 : this.config.cameraPath.lastIndexOf("/") + 1;
                    localMedia.setId(lastIndexOf > 0 ? ValueOf.toLong(this.config.cameraPath.substring(lastIndexOf)) : System.currentTimeMillis());
                    localMedia.setRealPath(path);
                    String stringExtra = intent != null ? intent.getStringExtra(PictureConfig.EXTRA_MEDIA_PATH) : null;
                    if (!PictureMimeType.isContent(stringExtra)) {
                        str = stringExtra;
                    }
                    localMedia.setAndroidQToPath(str);
                    localMedia.setBucketId(AlbumUtils.generateCameraBucketId(getContext(), file, ""));
                    lastModified = file.lastModified() / 1000;
                } else {
                    File file2 = new File(this.config.cameraPath);
                    PictureSelectionConfig pictureSelectionConfig = this.config;
                    imageMimeType = PictureMimeType.getImageMimeType(pictureSelectionConfig.cameraPath, pictureSelectionConfig.cameraMimeType);
                    localMedia.setSize(file2.length());
                    localMedia.setFileName(file2.getName());
                    if (PictureMimeType.isHasImage(imageMimeType)) {
                        Context context = getContext();
                        PictureSelectionConfig pictureSelectionConfig2 = this.config;
                        BitmapUtils.rotateImage(context, pictureSelectionConfig2.isCameraRotateImage, pictureSelectionConfig2.cameraPath);
                        MediaExtraInfo imageSize2 = MediaUtils.getImageSize(getContext(), this.config.cameraPath);
                        localMedia.setWidth(imageSize2.getWidth());
                        localMedia.setHeight(imageSize2.getHeight());
                    } else {
                        if (PictureMimeType.isHasVideo(imageMimeType)) {
                            MediaExtraInfo videoSize2 = MediaUtils.getVideoSize(getContext(), this.config.cameraPath);
                            localMedia.setWidth(videoSize2.getWidth());
                            localMedia.setHeight(videoSize2.getHeight());
                            duration = videoSize2.getDuration();
                        } else if (PictureMimeType.isHasAudio(imageMimeType)) {
                            duration = MediaUtils.getAudioSize(getContext(), this.config.cameraPath).getDuration();
                        }
                        localMedia.setDuration(duration);
                    }
                    localMedia.setId(System.currentTimeMillis());
                    localMedia.setRealPath(this.config.cameraPath);
                    if (intent != null) {
                        str = intent.getStringExtra(PictureConfig.EXTRA_MEDIA_PATH);
                    }
                    if (SdkVersionUtils.isQ()) {
                        if (TextUtils.isEmpty(str) || PictureMimeType.isContent(str)) {
                            localMedia.setAndroidQToPath(this.config.cameraPath);
                        } else {
                            localMedia.setAndroidQToPath(str);
                        }
                    }
                    localMedia.setBucketId(AlbumUtils.generateCameraBucketId(getContext(), file2, this.config.outPutCameraPath));
                    lastModified = file2.lastModified() / 1000;
                }
                localMedia.setDateAddedTime(lastModified);
                localMedia.setPath(this.config.cameraPath);
                localMedia.setMimeType(imageMimeType);
                PictureSelectionConfig pictureSelectionConfig3 = this.config;
                localMedia.setParentFolderName(AlbumUtils.generateCameraFolderName(pictureSelectionConfig3.cameraPath, imageMimeType, pictureSelectionConfig3.outPutCameraPath));
                localMedia.setChooseModel(this.config.chooseMode);
                dispatchCameraHandleResult(localMedia);
                if (!SdkVersionUtils.isQ()) {
                    if (this.config.isFallbackVersion3) {
                        new PictureMediaScannerConnection(getContext(), this.config.cameraPath);
                    } else {
                        sendBroadcast(new Intent("android.intent.action.MEDIA_SCANNER_SCAN_FILE", Uri.fromFile(new File(this.config.cameraPath))));
                    }
                    if (PictureMimeType.isHasImage(localMedia.getMimeType()) && (dCIMLastImageId = MediaUtils.getDCIMLastImageId(getContext())) != -1) {
                        MediaUtils.removeMedia(getContext(), dCIMLastImageId);
                    }
                } else if (PictureMimeType.isHasVideo(localMedia.getMimeType()) && PictureMimeType.isContent(this.config.cameraPath)) {
                    if (this.config.isFallbackVersion3) {
                        new PictureMediaScannerConnection(getContext(), localMedia.getRealPath());
                    } else {
                        sendBroadcast(new Intent("android.intent.action.MEDIA_SCANNER_SCAN_FILE", Uri.fromFile(new File(localMedia.getRealPath()))));
                    }
                }
            }
        } catch (Exception e6) {
            e6.printStackTrace();
        }
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public int getResourceId() {
        return R.layout.picture_empty;
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public void immersive() {
        int i5 = R.color.picture_color_transparent;
        ImmersiveManage.immersiveAboveAPI23(this, a.b(this, i5), a.b(this, i5), this.openWhiteStatusBar);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.e
    public void onActivityResult(int i5, int i6, Intent intent) {
        Throwable th;
        super.onActivityResult(i5, i6, intent);
        if (i6 == -1) {
            if (i5 == 69) {
                singleCropHandleResult(intent);
            } else if (i5 == 909) {
                dispatchHandleCamera(intent);
            }
        } else if (i6 == 0) {
            OnResultCallbackListener<LocalMedia> onResultCallbackListener = PictureSelectionConfig.listener;
            if (onResultCallbackListener != null) {
                onResultCallbackListener.onCancel();
            }
            if (i5 == 909) {
                MediaUtils.deleteCamera(this, this.config.cameraPath);
            }
            exit();
        } else if (i6 == 96 && intent != null && (th = (Throwable) intent.getSerializableExtra(UCrop.EXTRA_ERROR)) != null) {
            ToastUtils.s(getContext(), th.getMessage());
        }
    }

    @Override // androidx.activity.ComponentActivity
    public void onBackPressed() {
        if (SdkVersionUtils.isQ()) {
            finishAfterTransition();
        } else {
            super.onBackPressed();
        }
        exit();
    }

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.e, androidx.core.app.e, com.luck.picture.lib.PictureBaseActivity
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig == null) {
            exit();
        } else if (!pictureSelectionConfig.isUseCustomCamera) {
            setActivitySize();
            if (bundle != null) {
                return;
            }
            if (PermissionChecker.checkSelfPermission(this, "android.permission.WRITE_EXTERNAL_STORAGE")) {
                OnCustomCameraInterfaceListener onCustomCameraInterfaceListener = PictureSelectionConfig.onCustomCameraInterfaceListener;
                if (onCustomCameraInterfaceListener == null) {
                    onTakePhoto();
                } else if (this.config.chooseMode == 2) {
                    onCustomCameraInterfaceListener.onCameraClick(getContext(), this.config, 2);
                } else {
                    onCustomCameraInterfaceListener.onCameraClick(getContext(), this.config, 1);
                }
            } else {
                PermissionChecker.requestPermissions(this, new String[]{"android.permission.WRITE_EXTERNAL_STORAGE"}, 1);
            }
        }
    }

    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.e, com.luck.picture.lib.PictureBaseActivity, androidx.core.app.a.c
    public void onRequestPermissionsResult(int i5, String[] strArr, int[] iArr) {
        super.onRequestPermissionsResult(i5, strArr, iArr);
        if (i5 != 1) {
            if (i5 == 2) {
                if (iArr.length <= 0 || iArr[0] != 0) {
                    exit();
                    ToastUtils.s(getContext(), getString(R.string.picture_camera));
                    return;
                }
                onTakePhoto();
            }
        } else if (iArr.length <= 0 || iArr[0] != 0) {
            ToastUtils.s(getContext(), getString(R.string.picture_jurisdiction));
            exit();
        } else {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
        }
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x00d9, code lost:
        if (com.luck.picture.lib.config.PictureMimeType.isHasImage(r3.getMimeType()) != false) goto L_0x0112;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x0110, code lost:
        if (com.luck.picture.lib.config.PictureMimeType.isHasImage(r3.getMimeType()) != false) goto L_0x0112;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0112, code lost:
        r9 = com.luck.picture.lib.tools.MediaUtils.getImageSize(getContext(), r3.getPath());
     */
    public void singleCropHandleResult(Intent intent) {
        if (intent != null) {
            ArrayList arrayList = new ArrayList();
            Uri output = UCrop.getOutput(intent);
            if (output != null) {
                String path = output.getPath();
                boolean isEmpty = TextUtils.isEmpty(path);
                PictureSelectionConfig pictureSelectionConfig = this.config;
                LocalMedia parseLocalMedia = LocalMedia.parseLocalMedia(pictureSelectionConfig.cameraPath, pictureSelectionConfig.isCamera ? 1 : 0, pictureSelectionConfig.chooseMode);
                if (SdkVersionUtils.isQ()) {
                    int lastIndexOf = TextUtils.isEmpty(this.config.cameraPath) ? 0 : this.config.cameraPath.lastIndexOf("/") + 1;
                    parseLocalMedia.setId(lastIndexOf > 0 ? ValueOf.toLong(this.config.cameraPath.substring(lastIndexOf)) : System.currentTimeMillis());
                    parseLocalMedia.setAndroidQToPath(path);
                } else {
                    parseLocalMedia.setId(System.currentTimeMillis());
                }
                parseLocalMedia.setCut(!isEmpty);
                parseLocalMedia.setCutPath(path);
                parseLocalMedia.setMimeType(PictureMimeType.getImageMimeType(path));
                parseLocalMedia.setCropImageWidth(intent.getIntExtra(UCrop.EXTRA_OUTPUT_IMAGE_WIDTH, 0));
                parseLocalMedia.setCropImageHeight(intent.getIntExtra(UCrop.EXTRA_OUTPUT_IMAGE_HEIGHT, 0));
                parseLocalMedia.setCropOffsetX(intent.getIntExtra(UCrop.EXTRA_OUTPUT_OFFSET_X, 0));
                parseLocalMedia.setCropOffsetY(intent.getIntExtra(UCrop.EXTRA_OUTPUT_OFFSET_Y, 0));
                parseLocalMedia.setCropResultAspectRatio(intent.getFloatExtra(UCrop.EXTRA_OUTPUT_CROP_ASPECT_RATIO, CropImageView.DEFAULT_ASPECT_RATIO));
                parseLocalMedia.setEditorImage(intent.getBooleanExtra("com.yalantis.ucrop.EditorImage", false));
                if (PictureMimeType.isContent(parseLocalMedia.getPath())) {
                    parseLocalMedia.setRealPath(PictureFileUtils.getPath(getContext(), Uri.parse(parseLocalMedia.getPath())));
                    if (!PictureMimeType.isHasVideo(parseLocalMedia.getMimeType())) {
                    }
                } else {
                    parseLocalMedia.setRealPath(parseLocalMedia.getPath());
                    if (!PictureMimeType.isHasVideo(parseLocalMedia.getMimeType())) {
                    }
                }
                MediaExtraInfo imageSize = MediaUtils.getVideoSize(getContext(), parseLocalMedia.getPath());
                parseLocalMedia.setWidth(imageSize.getWidth());
                parseLocalMedia.setHeight(imageSize.getHeight());
                File file = new File(parseLocalMedia.getRealPath());
                parseLocalMedia.setSize(file.length());
                parseLocalMedia.setFileName(file.getName());
                arrayList.add(parseLocalMedia);
                handlerResult(arrayList);
            }
        }
    }
}
