package com.luck.picture.lib.adapter;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.recyclerview.widget.RecyclerView;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.engine.ImageEngine;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.listener.OnAlbumItemClickListener;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.style.PictureSelectorUIStyle;
import com.luck.picture.lib.tools.AttrsUtils;
import com.yalantis.ucrop.view.CropImageView;
import java.util.ArrayList;
import java.util.List;

public class PictureAlbumDirectoryAdapter extends RecyclerView.h<ViewHolder> {
    private int chooseMode;
    private List<LocalMediaFolder> folders = new ArrayList();
    private OnAlbumItemClickListener onAlbumItemClickListener;

    /* access modifiers changed from: package-private */
    public static class ViewHolder extends RecyclerView.e0 {
        ImageView ivFirstImage;
        TextView tvFolderName;
        TextView tvSign;

        public ViewHolder(View view) {
            super(view);
            int i5;
            this.ivFirstImage = (ImageView) view.findViewById(R.id.first_image);
            this.tvFolderName = (TextView) view.findViewById(R.id.tv_folder_name);
            TextView textView = (TextView) view.findViewById(R.id.tv_sign);
            this.tvSign = textView;
            PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
            if (pictureSelectorUIStyle != null) {
                int i6 = pictureSelectorUIStyle.picture_album_checkDotStyle;
                if (i6 != 0) {
                    textView.setBackgroundResource(i6);
                }
                int i7 = PictureSelectionConfig.uiStyle.picture_album_textColor;
                if (i7 != 0) {
                    this.tvFolderName.setTextColor(i7);
                }
                i5 = PictureSelectionConfig.uiStyle.picture_album_textSize;
                if (i5 <= 0) {
                    return;
                }
            } else {
                PictureParameterStyle pictureParameterStyle = PictureSelectionConfig.style;
                if (pictureParameterStyle != null) {
                    int i8 = pictureParameterStyle.pictureFolderCheckedDotStyle;
                    if (i8 != 0) {
                        textView.setBackgroundResource(i8);
                    }
                    int i9 = PictureSelectionConfig.style.folderTextColor;
                    if (i9 != 0) {
                        this.tvFolderName.setTextColor(i9);
                    }
                    i5 = PictureSelectionConfig.style.folderTextSize;
                    if (i5 <= 0) {
                        return;
                    }
                } else {
                    this.tvSign.setBackground(AttrsUtils.getTypeValueDrawable(view.getContext(), R.attr.picture_folder_checked_dot, R.drawable.picture_orange_oval));
                    int typeValueColor = AttrsUtils.getTypeValueColor(view.getContext(), R.attr.picture_folder_textColor);
                    if (typeValueColor != 0) {
                        this.tvFolderName.setTextColor(typeValueColor);
                    }
                    float typeValueSize = AttrsUtils.getTypeValueSize(view.getContext(), R.attr.picture_folder_textSize);
                    if (typeValueSize > CropImageView.DEFAULT_ASPECT_RATIO) {
                        this.tvFolderName.setTextSize(0, typeValueSize);
                        return;
                    }
                    return;
                }
            }
            this.tvFolderName.setTextSize((float) i5);
        }
    }

    public PictureAlbumDirectoryAdapter(PictureSelectionConfig pictureSelectionConfig) {
        this.chooseMode = pictureSelectionConfig.chooseMode;
    }

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$onBindViewHolder$0(LocalMediaFolder localMediaFolder, int i5, View view) {
        if (this.onAlbumItemClickListener != null) {
            int size = this.folders.size();
            for (int i6 = 0; i6 < size; i6++) {
                this.folders.get(i6).setChecked(false);
            }
            localMediaFolder.setChecked(true);
            notifyDataSetChanged();
            this.onAlbumItemClickListener.onItemClick(i5, localMediaFolder.isCameraFolder(), localMediaFolder.getBucketId(), localMediaFolder.getName(), localMediaFolder.getData());
        }
    }

    public void bindFolderData(List<LocalMediaFolder> list) {
        this.folders = list;
        notifyDataSetChanged();
    }

    public List<LocalMediaFolder> getFolderData() {
        return this.folders;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.h
    public int getItemCount() {
        return this.folders.size();
    }

    public void onBindViewHolder(ViewHolder viewHolder, int i5) {
        PictureParameterStyle pictureParameterStyle;
        int i6;
        LocalMediaFolder localMediaFolder = this.folders.get(i5);
        String name = localMediaFolder.getName();
        int imageNum = localMediaFolder.getImageNum();
        String firstImagePath = localMediaFolder.getFirstImagePath();
        boolean isChecked = localMediaFolder.isChecked();
        viewHolder.tvSign.setVisibility(localMediaFolder.getCheckedNum() > 0 ? 0 : 4);
        viewHolder.itemView.setSelected(isChecked);
        PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
        if (pictureSelectorUIStyle == null ? !((pictureParameterStyle = PictureSelectionConfig.style) == null || (i6 = pictureParameterStyle.pictureAlbumStyle) == 0) : (i6 = pictureSelectorUIStyle.picture_album_backgroundStyle) != 0) {
            viewHolder.itemView.setBackgroundResource(i6);
        }
        if (this.chooseMode == PictureMimeType.ofAudio()) {
            viewHolder.ivFirstImage.setImageResource(R.drawable.picture_audio_placeholder);
        } else {
            ImageEngine imageEngine = PictureSelectionConfig.imageEngine;
            if (imageEngine != null) {
                imageEngine.loadFolderImage(viewHolder.itemView.getContext(), firstImagePath, viewHolder.ivFirstImage);
            }
        }
        Context context = viewHolder.itemView.getContext();
        if (localMediaFolder.getOfAllType() != -1) {
            name = context.getString(localMediaFolder.getOfAllType() == PictureMimeType.ofAudio() ? R.string.picture_all_audio : R.string.picture_camera_roll);
        }
        viewHolder.tvFolderName.setText(context.getString(R.string.picture_camera_roll_num, name, Integer.valueOf(imageNum)));
        viewHolder.itemView.setOnClickListener(new a(this, localMediaFolder, i5));
    }

    @Override // androidx.recyclerview.widget.RecyclerView.h
    public ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i5) {
        return new ViewHolder(LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.picture_album_folder_item, viewGroup, false));
    }

    public void setChooseMode(int i5) {
        this.chooseMode = i5;
    }

    public void setOnAlbumItemClickListener(OnAlbumItemClickListener onAlbumItemClickListener2) {
        this.onAlbumItemClickListener = onAlbumItemClickListener2;
    }
}
