package com.luck.picture.lib.adapter;

import android.content.Context;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.AnimationUtils;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.recyclerview.widget.RecyclerView;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.dialog.PictureCustomDialog;
import com.luck.picture.lib.engine.ImageEngine;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.listener.OnChooseLimitCallback;
import com.luck.picture.lib.listener.OnPhotoSelectChangedListener;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.style.PictureSelectorUIStyle;
import com.luck.picture.lib.tools.AnimUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.StringUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.ValueOf;
import com.luck.picture.lib.tools.VoiceUtils;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import y.a;
import y.b;

public class PictureImageGridAdapter extends RecyclerView.h<RecyclerView.e0> {
    private final PictureSelectionConfig config;
    private final Context context;
    private List<LocalMedia> data = new ArrayList();
    private OnPhotoSelectChangedListener<LocalMedia> imageSelectChangedListener;
    private List<LocalMedia> selectData = new ArrayList();
    private boolean showCamera;

    public class CameraViewHolder extends RecyclerView.e0 {
        TextView tvCamera;

        public CameraViewHolder(View view) {
            super(view);
            TextView textView = (TextView) view.findViewById(R.id.tvCamera);
            this.tvCamera = textView;
            PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
            if (pictureSelectorUIStyle != null) {
                int i5 = pictureSelectorUIStyle.picture_adapter_item_camera_backgroundColor;
                if (i5 != 0) {
                    view.setBackgroundColor(i5);
                }
                int i6 = PictureSelectionConfig.uiStyle.picture_adapter_item_camera_textSize;
                if (i6 != 0) {
                    this.tvCamera.setTextSize((float) i6);
                }
                int i7 = PictureSelectionConfig.uiStyle.picture_adapter_item_camera_textColor;
                if (i7 != 0) {
                    this.tvCamera.setTextColor(i7);
                }
                if (PictureSelectionConfig.uiStyle.picture_adapter_item_camera_text != 0) {
                    this.tvCamera.setText(view.getContext().getString(PictureSelectionConfig.uiStyle.picture_adapter_item_camera_text));
                } else {
                    this.tvCamera.setText(PictureImageGridAdapter.this.context.getString(PictureImageGridAdapter.this.config.chooseMode == PictureMimeType.ofAudio() ? R.string.picture_tape : R.string.picture_take_picture));
                }
                int i8 = PictureSelectionConfig.uiStyle.picture_adapter_item_camera_textTopDrawable;
                if (i8 != 0) {
                    this.tvCamera.setCompoundDrawablesWithIntrinsicBounds(0, i8, 0, 0);
                    return;
                }
                return;
            }
            textView.setText(PictureImageGridAdapter.this.context.getString(PictureImageGridAdapter.this.config.chooseMode == PictureMimeType.ofAudio() ? R.string.picture_tape : R.string.picture_take_picture));
        }
    }

    public static class ViewHolder extends RecyclerView.e0 {
        View btnCheck;
        View contentView;
        ImageView ivEditor;
        ImageView ivPicture;
        TextView tvCheck;
        TextView tvDuration;
        TextView tvImageMimeType;
        TextView tvLongChart;

        public ViewHolder(View view) {
            super(view);
            TextView textView;
            int i5;
            this.contentView = view;
            this.ivPicture = (ImageView) view.findViewById(R.id.ivPicture);
            this.tvCheck = (TextView) view.findViewById(R.id.tvCheck);
            this.btnCheck = view.findViewById(R.id.btnCheck);
            this.tvDuration = (TextView) view.findViewById(R.id.tv_duration);
            this.tvImageMimeType = (TextView) view.findViewById(R.id.tv_image_mime_type);
            this.tvLongChart = (TextView) view.findViewById(R.id.tv_long_chart);
            this.ivEditor = (ImageView) view.findViewById(R.id.ivEditor);
            PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
            if (pictureSelectorUIStyle != null) {
                int i6 = pictureSelectorUIStyle.picture_check_style;
                if (i6 != 0) {
                    this.tvCheck.setBackgroundResource(i6);
                }
                int i7 = PictureSelectionConfig.uiStyle.picture_check_textSize;
                if (i7 != 0) {
                    this.tvCheck.setTextSize((float) i7);
                }
                int i8 = PictureSelectionConfig.uiStyle.picture_check_textColor;
                if (i8 != 0) {
                    this.tvCheck.setTextColor(i8);
                }
                int i9 = PictureSelectionConfig.uiStyle.picture_adapter_item_textSize;
                if (i9 > 0) {
                    this.tvDuration.setTextSize((float) i9);
                }
                int i10 = PictureSelectionConfig.uiStyle.picture_adapter_item_textColor;
                if (i10 != 0) {
                    this.tvDuration.setTextColor(i10);
                }
                if (PictureSelectionConfig.uiStyle.picture_adapter_item_tag_text != 0) {
                    this.tvImageMimeType.setText(view.getContext().getString(PictureSelectionConfig.uiStyle.picture_adapter_item_tag_text));
                }
                if (PictureSelectionConfig.uiStyle.picture_adapter_item_gif_tag_show) {
                    textView = this.tvImageMimeType;
                    i5 = 0;
                } else {
                    textView = this.tvImageMimeType;
                    i5 = 8;
                }
                textView.setVisibility(i5);
                int i11 = PictureSelectionConfig.uiStyle.picture_adapter_item_gif_tag_background;
                if (i11 != 0) {
                    this.tvImageMimeType.setBackgroundResource(i11);
                }
                int i12 = PictureSelectionConfig.uiStyle.picture_adapter_item_editor_tag_icon;
                if (i12 != 0) {
                    this.ivEditor.setImageResource(i12);
                }
                int i13 = PictureSelectionConfig.uiStyle.picture_adapter_item_gif_tag_textColor;
                if (i13 != 0) {
                    this.tvImageMimeType.setTextColor(i13);
                }
                int i14 = PictureSelectionConfig.uiStyle.picture_adapter_item_gif_tag_textSize;
                if (i14 != 0) {
                    this.tvImageMimeType.setTextSize((float) i14);
                    return;
                }
                return;
            }
            PictureParameterStyle pictureParameterStyle = PictureSelectionConfig.style;
            if (pictureParameterStyle != null) {
                int i15 = pictureParameterStyle.pictureCheckedStyle;
                if (i15 != 0) {
                    this.tvCheck.setBackgroundResource(i15);
                }
                int i16 = PictureSelectionConfig.style.picture_adapter_item_editor_tag_icon;
                if (i16 != 0) {
                    this.ivEditor.setImageResource(i16);
                    return;
                }
                return;
            }
            this.tvCheck.setBackground(AttrsUtils.getTypeValueDrawable(view.getContext(), R.attr.picture_checked_style, R.drawable.picture_checkbox_selector));
        }
    }

    public PictureImageGridAdapter(Context context2, PictureSelectionConfig pictureSelectionConfig) {
        this.context = context2;
        this.config = pictureSelectionConfig;
        this.showCamera = pictureSelectionConfig.isCamera;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:113:0x027f, code lost:
        if (getSelectedSize() == (r11.config.maxSelectNum - 1)) goto L_0x02d9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:120:0x0291, code lost:
        if (getSelectedSize() == 0) goto L_0x02d9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:131:0x02bc, code lost:
        if (getSelectedSize() == (r11.config.maxVideoSelectNum - 1)) goto L_0x02d9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:138:0x02d7, code lost:
        if (getSelectedSize() == (r11.config.maxSelectNum - 1)) goto L_0x02d9;
     */
    /* JADX WARNING: Removed duplicated region for block: B:102:0x0257  */
    /* JADX WARNING: Removed duplicated region for block: B:141:0x02dc  */
    /* JADX WARNING: Removed duplicated region for block: B:142:0x02e0  */
    /* JADX WARNING: Removed duplicated region for block: B:145:0x02f0  */
    /* JADX WARNING: Removed duplicated region for block: B:156:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x01d6  */
    /* JADX WARNING: Removed duplicated region for block: B:96:0x021d  */
    private void changeCheckboxState(ViewHolder viewHolder, LocalMedia localMedia) {
        PictureSelectionConfig pictureSelectionConfig;
        OnPhotoSelectChangedListener<LocalMedia> onPhotoSelectChangedListener;
        LocalMedia localMedia2;
        String string;
        PictureSelectionConfig pictureSelectionConfig2;
        int i5;
        boolean isSelected = viewHolder.tvCheck.isSelected();
        int size = this.selectData.size();
        boolean z4 = false;
        String mimeType = size > 0 ? this.selectData.get(0).getMimeType() : "";
        if (this.config.isWithVideoImage) {
            int i6 = 0;
            for (int i7 = 0; i7 < size; i7++) {
                if (PictureMimeType.isHasVideo(this.selectData.get(i7).getMimeType())) {
                    i6++;
                }
            }
            if (PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                PictureSelectionConfig pictureSelectionConfig3 = this.config;
                int i8 = pictureSelectionConfig3.maxVideoSelectNum;
                if (i8 > 0) {
                    int i9 = pictureSelectionConfig3.maxSelectNum;
                    if (size >= i9 && !isSelected) {
                        string = this.context.getString(R.string.picture_message_max_num, Integer.valueOf(i9));
                        showPromptDialog(string);
                    } else if (i6 < i8 || isSelected) {
                        if (!isSelected && pictureSelectionConfig3.videoMinSecond > 0) {
                            long duration = localMedia.getDuration();
                            int i10 = this.config.videoMinSecond;
                            if (duration < ((long) i10)) {
                                string = this.context.getString(R.string.picture_choose_min_seconds, Integer.valueOf(i10 / 1000));
                                showPromptDialog(string);
                            }
                        }
                        if (!isSelected && this.config.videoMaxSecond > 0) {
                            long duration2 = localMedia.getDuration();
                            int i11 = this.config.videoMaxSecond;
                            if (duration2 > ((long) i11)) {
                                string = this.context.getString(R.string.picture_choose_max_seconds, Integer.valueOf(i11 / 1000));
                                showPromptDialog(string);
                            }
                        }
                        if (!isSelected) {
                            int i12 = 0;
                            while (true) {
                                if (i12 >= size) {
                                    break;
                                }
                                localMedia2 = this.selectData.get(i12);
                                if (localMedia2 == null || TextUtils.isEmpty(localMedia2.getPath()) || (!localMedia2.getPath().equals(localMedia.getPath()) && localMedia2.getId() != localMedia.getId())) {
                                    i12++;
                                }
                            }
                            this.selectData.remove(localMedia2);
                            subSelectPosition();
                            AnimUtils.disZoom(viewHolder.ivPicture, this.config.zoomAnim);
                        } else {
                            if (this.config.selectionMode == 1) {
                                singleRadioMediaImage();
                            }
                            this.selectData.add(localMedia);
                            localMedia.setNum(this.selectData.size());
                            VoiceUtils.getInstance().play();
                            AnimUtils.zoom(viewHolder.ivPicture, this.config.zoomAnim);
                            viewHolder.tvCheck.startAnimation(AnimationUtils.loadAnimation(this.context, R.anim.picture_anim_modal_in));
                        }
                        pictureSelectionConfig = this.config;
                        if (pictureSelectionConfig.isMaxSelectEnabledMask) {
                            if (pictureSelectionConfig.chooseMode == PictureMimeType.ofAll()) {
                                PictureSelectionConfig pictureSelectionConfig4 = this.config;
                                if (!pictureSelectionConfig4.isWithVideoImage || pictureSelectionConfig4.maxVideoSelectNum <= 0) {
                                    if (!isSelected && getSelectedSize() == 1) {
                                        z4 = true;
                                    }
                                    if (isSelected) {
                                    }
                                } else {
                                    if (getSelectedSize() >= this.config.maxSelectNum) {
                                        z4 = true;
                                    }
                                    if (isSelected) {
                                    }
                                }
                            } else if (this.config.chooseMode != PictureMimeType.ofVideo() || this.config.maxVideoSelectNum <= 0) {
                                if (!isSelected && getSelectedSize() == this.config.maxSelectNum) {
                                    z4 = true;
                                }
                                if (isSelected) {
                                }
                            } else {
                                if (!isSelected && getSelectedSize() == this.config.maxVideoSelectNum) {
                                    z4 = true;
                                }
                                if (isSelected) {
                                }
                            }
                            z4 = true;
                        }
                        if (!z4) {
                            notifyDataSetChanged();
                        } else {
                            notifyItemChanged(viewHolder.getAbsoluteAdapterPosition());
                        }
                        selectImage(viewHolder, !isSelected);
                        onPhotoSelectChangedListener = this.imageSelectChangedListener;
                        if (onPhotoSelectChangedListener == null) {
                            onPhotoSelectChangedListener.onChange(this.selectData);
                            return;
                        }
                        return;
                    } else {
                        string = StringUtils.getMsg(this.context, localMedia.getMimeType(), this.config.maxVideoSelectNum);
                        showPromptDialog(string);
                    }
                }
            } else {
                int i13 = this.config.maxSelectNum;
                if (size >= i13 && !isSelected) {
                    string = this.context.getString(R.string.picture_message_max_num, Integer.valueOf(i13));
                    showPromptDialog(string);
                }
                if (!isSelected) {
                }
                pictureSelectionConfig = this.config;
                if (pictureSelectionConfig.isMaxSelectEnabledMask) {
                }
                if (!z4) {
                }
                selectImage(viewHolder, !isSelected);
                onPhotoSelectChangedListener = this.imageSelectChangedListener;
                if (onPhotoSelectChangedListener == null) {
                }
            }
        } else if (TextUtils.isEmpty(mimeType) || PictureMimeType.isMimeTypeSame(mimeType, localMedia.getMimeType())) {
            if (!PictureMimeType.isHasVideo(mimeType) || (i5 = (pictureSelectionConfig2 = this.config).maxVideoSelectNum) <= 0) {
                int i14 = this.config.maxSelectNum;
                if (size < i14 || isSelected) {
                    if (PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                        if (!isSelected && this.config.videoMinSecond > 0) {
                            long duration3 = localMedia.getDuration();
                            int i15 = this.config.videoMinSecond;
                            if (duration3 < ((long) i15)) {
                                string = this.context.getString(R.string.picture_choose_min_seconds, Integer.valueOf(i15 / 1000));
                                showPromptDialog(string);
                            }
                        }
                        if (!isSelected && this.config.videoMaxSecond > 0) {
                            long duration4 = localMedia.getDuration();
                            int i16 = this.config.videoMaxSecond;
                            if (duration4 > ((long) i16)) {
                                string = this.context.getString(R.string.picture_choose_max_seconds, Integer.valueOf(i16 / 1000));
                                showPromptDialog(string);
                            }
                        }
                    }
                    if (!isSelected) {
                    }
                    pictureSelectionConfig = this.config;
                    if (pictureSelectionConfig.isMaxSelectEnabledMask) {
                    }
                    if (!z4) {
                    }
                    selectImage(viewHolder, !isSelected);
                    onPhotoSelectChangedListener = this.imageSelectChangedListener;
                    if (onPhotoSelectChangedListener == null) {
                    }
                } else {
                    string = StringUtils.getMsg(this.context, mimeType, i14);
                    showPromptDialog(string);
                }
            } else if (size < i5 || isSelected) {
                if (!isSelected && pictureSelectionConfig2.videoMinSecond > 0) {
                    long duration5 = localMedia.getDuration();
                    int i17 = this.config.videoMinSecond;
                    if (duration5 < ((long) i17)) {
                        string = this.context.getString(R.string.picture_choose_min_seconds, Integer.valueOf(i17 / 1000));
                        showPromptDialog(string);
                    }
                }
                if (!isSelected && this.config.videoMaxSecond > 0) {
                    long duration6 = localMedia.getDuration();
                    int i18 = this.config.videoMaxSecond;
                    if (duration6 > ((long) i18)) {
                        string = this.context.getString(R.string.picture_choose_max_seconds, Integer.valueOf(i18 / 1000));
                        showPromptDialog(string);
                    }
                }
                if (!isSelected) {
                }
                pictureSelectionConfig = this.config;
                if (pictureSelectionConfig.isMaxSelectEnabledMask) {
                }
                if (!z4) {
                }
                selectImage(viewHolder, !isSelected);
                onPhotoSelectChangedListener = this.imageSelectChangedListener;
                if (onPhotoSelectChangedListener == null) {
                }
            } else {
                string = StringUtils.getMsg(this.context, mimeType, i5);
                showPromptDialog(string);
            }
        }
        string = this.context.getString(R.string.picture_rule);
        showPromptDialog(string);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:52:0x011c, code lost:
        if (getSelectedSize() == r6.config.maxVideoSelectNum) goto L_0x014c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:59:0x0148, code lost:
        if (getSelectedSize() == r6.config.maxSelectNum) goto L_0x014c;
     */
    private void dispatchHandleMask(ViewHolder viewHolder, LocalMedia localMedia) {
        boolean isHasImage;
        PictureSelectionConfig pictureSelectionConfig = this.config;
        boolean z4 = true;
        if (!pictureSelectionConfig.isWithVideoImage || pictureSelectionConfig.maxVideoSelectNum <= 0) {
            LocalMedia localMedia2 = this.selectData.size() > 0 ? this.selectData.get(0) : null;
            if (localMedia2 != null) {
                boolean isSelected = viewHolder.tvCheck.isSelected();
                if (this.config.chooseMode != PictureMimeType.ofAll()) {
                    if (this.config.chooseMode != PictureMimeType.ofVideo() || this.config.maxVideoSelectNum <= 0) {
                        if (!isSelected && getSelectedSize() == this.config.maxSelectNum) {
                            viewHolder.ivPicture.setColorFilter(a.a(androidx.core.content.a.b(this.context, R.color.picture_color_half_white), b.SRC_ATOP));
                        }
                        if (!isSelected) {
                        }
                    } else {
                        if (!isSelected && getSelectedSize() == this.config.maxVideoSelectNum) {
                            viewHolder.ivPicture.setColorFilter(a.a(androidx.core.content.a.b(this.context, R.color.picture_color_half_white), b.SRC_ATOP));
                        }
                        if (!isSelected) {
                        }
                    }
                    z4 = false;
                    localMedia.setMaxSelectEnabledMask(z4);
                    return;
                } else if (PictureMimeType.isHasImage(localMedia2.getMimeType())) {
                    if (!isSelected && !PictureMimeType.isHasImage(localMedia.getMimeType())) {
                        viewHolder.ivPicture.setColorFilter(a.a(androidx.core.content.a.b(this.context, PictureMimeType.isHasVideo(localMedia.getMimeType()) ? R.color.picture_color_half_white : R.color.picture_color_20), b.SRC_ATOP));
                    }
                    isHasImage = PictureMimeType.isHasVideo(localMedia.getMimeType());
                } else if (PictureMimeType.isHasVideo(localMedia2.getMimeType())) {
                    if (!isSelected && !PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                        viewHolder.ivPicture.setColorFilter(a.a(androidx.core.content.a.b(this.context, PictureMimeType.isHasImage(localMedia.getMimeType()) ? R.color.picture_color_half_white : R.color.picture_color_20), b.SRC_ATOP));
                    }
                    isHasImage = PictureMimeType.isHasImage(localMedia.getMimeType());
                } else {
                    return;
                }
            }
            localMedia.setMaxSelectEnabledMask(false);
            return;
        }
        if (getSelectedSize() >= this.config.maxSelectNum) {
            boolean isSelected2 = viewHolder.tvCheck.isSelected();
            viewHolder.ivPicture.setColorFilter(a.a(androidx.core.content.a.b(this.context, isSelected2 ? R.color.picture_color_80 : R.color.picture_color_half_white), b.SRC_ATOP));
            isHasImage = !isSelected2;
        }
        localMedia.setMaxSelectEnabledMask(false);
        return;
        localMedia.setMaxSelectEnabledMask(isHasImage);
    }

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$onBindViewHolder$0(View view) {
        OnPhotoSelectChangedListener<LocalMedia> onPhotoSelectChangedListener = this.imageSelectChangedListener;
        if (onPhotoSelectChangedListener != null) {
            onPhotoSelectChangedListener.onTakePhoto();
        }
    }

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$onBindViewHolder$1(LocalMedia localMedia, ViewHolder viewHolder, String str, View view) {
        Context context2;
        int i5;
        String str2;
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.isMaxSelectEnabledMask) {
            if (pictureSelectionConfig.isWithVideoImage) {
                int selectedSize = getSelectedSize();
                boolean z4 = false;
                int i6 = 0;
                for (int i7 = 0; i7 < selectedSize; i7++) {
                    if (PictureMimeType.isHasVideo(this.selectData.get(i7).getMimeType())) {
                        i6++;
                    }
                }
                if (PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                    if (!viewHolder.tvCheck.isSelected() && i6 >= this.config.maxVideoSelectNum) {
                        z4 = true;
                    }
                    context2 = this.context;
                    str2 = localMedia.getMimeType();
                    i5 = this.config.maxVideoSelectNum;
                } else {
                    if (!viewHolder.tvCheck.isSelected() && selectedSize >= this.config.maxSelectNum) {
                        z4 = true;
                    }
                    context2 = this.context;
                    str2 = localMedia.getMimeType();
                    i5 = this.config.maxSelectNum;
                }
                String msg = StringUtils.getMsg(context2, str2, i5);
                if (z4) {
                    showPromptDialog(msg);
                    return;
                }
            } else if (!viewHolder.tvCheck.isSelected() && getSelectedSize() >= this.config.maxSelectNum) {
                showPromptDialog(StringUtils.getMsg(this.context, localMedia.getMimeType(), this.config.maxSelectNum));
                return;
            }
        }
        String realPath = localMedia.getRealPath();
        if (TextUtils.isEmpty(realPath) || new File(realPath).exists()) {
            changeCheckboxState(viewHolder, localMedia);
            return;
        }
        Context context3 = this.context;
        ToastUtils.s(context3, PictureMimeType.s(context3, str));
    }

    /* access modifiers changed from: private */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0058, code lost:
        if (r10.selectionMode != 1) goto L_0x005a;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:0x0068, code lost:
        if (r7.selectionMode != 1) goto L_0x006b;
     */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x0070  */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x00d2  */
    public /* synthetic */ void lambda$onBindViewHolder$2(LocalMedia localMedia, String str, int i5, ViewHolder viewHolder, View view) {
        boolean z4;
        if (!this.config.isMaxSelectEnabledMask || !localMedia.isMaxSelectEnabledMask()) {
            String realPath = localMedia.getRealPath();
            if (TextUtils.isEmpty(realPath) || new File(realPath).exists()) {
                if (this.showCamera) {
                    i5--;
                }
                if (i5 != -1) {
                    if ((!PictureMimeType.isHasImage(str) || !this.config.enablePreview) && !this.config.isSingleDirectReturn) {
                        if (PictureMimeType.isHasVideo(str)) {
                            PictureSelectionConfig pictureSelectionConfig = this.config;
                            if (!pictureSelectionConfig.enPreviewVideo) {
                            }
                        }
                        if (PictureMimeType.isHasAudio(str)) {
                            PictureSelectionConfig pictureSelectionConfig2 = this.config;
                            if (!pictureSelectionConfig2.enablePreviewAudio) {
                            }
                        }
                        z4 = false;
                        if (!z4) {
                            if (PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                                if (this.config.videoMinSecond > 0) {
                                    long duration = localMedia.getDuration();
                                    int i6 = this.config.videoMinSecond;
                                    if (duration < ((long) i6)) {
                                        showPromptDialog(this.context.getString(R.string.picture_choose_min_seconds, Integer.valueOf(i6 / 1000)));
                                        return;
                                    }
                                }
                                if (this.config.videoMaxSecond > 0) {
                                    long duration2 = localMedia.getDuration();
                                    int i7 = this.config.videoMaxSecond;
                                    if (duration2 > ((long) i7)) {
                                        showPromptDialog(this.context.getString(R.string.picture_choose_max_seconds, Integer.valueOf(i7 / 1000)));
                                        return;
                                    }
                                }
                            }
                            this.imageSelectChangedListener.onPictureClick(localMedia, i5);
                            return;
                        }
                        changeCheckboxState(viewHolder, localMedia);
                        return;
                    }
                    z4 = true;
                    if (!z4) {
                    }
                }
            } else {
                Context context2 = this.context;
                ToastUtils.s(context2, PictureMimeType.s(context2, str));
            }
        }
    }

    private void notifyCheckChanged(ViewHolder viewHolder, LocalMedia localMedia) {
        viewHolder.tvCheck.setText("");
        int size = this.selectData.size();
        for (int i5 = 0; i5 < size; i5++) {
            LocalMedia localMedia2 = this.selectData.get(i5);
            if (localMedia2.getPath().equals(localMedia.getPath()) || localMedia2.getId() == localMedia.getId()) {
                localMedia.setNum(localMedia2.getNum());
                localMedia2.setPosition(localMedia.getPosition());
                viewHolder.tvCheck.setText(ValueOf.toString(Integer.valueOf(localMedia.getNum())));
            }
        }
    }

    private void setLocalMediaCropInfo(LocalMedia localMedia, LocalMedia localMedia2) {
        if (localMedia.isEditorImage() && !localMedia2.isEditorImage()) {
            localMedia2.setCut(localMedia.isCut());
            localMedia2.setCutPath(localMedia.getCutPath());
            localMedia2.setCropImageWidth(localMedia.getCropImageWidth());
            localMedia2.setCropImageHeight(localMedia.getCropImageHeight());
            localMedia2.setCropOffsetX(localMedia.getCropOffsetX());
            localMedia2.setCropOffsetY(localMedia.getCropOffsetY());
            localMedia2.setCropResultAspectRatio(localMedia.getCropResultAspectRatio());
            localMedia2.setAndroidQToPath(localMedia.getAndroidQToPath());
            localMedia2.setEditorImage(localMedia.isEditorImage());
        }
    }

    private void showPromptDialog(String str) {
        OnChooseLimitCallback onChooseLimitCallback = PictureSelectionConfig.onChooseLimitCallback;
        if (onChooseLimitCallback != null) {
            onChooseLimitCallback.onChooseLimit(this.context, str);
            return;
        }
        final PictureCustomDialog pictureCustomDialog = new PictureCustomDialog(this.context, R.layout.picture_prompt_dialog);
        ((TextView) pictureCustomDialog.findViewById(R.id.tv_content)).setText(str);
        ((TextView) pictureCustomDialog.findViewById(R.id.btnOk)).setOnClickListener(new View.OnClickListener() {
            /* class com.luck.picture.lib.adapter.PictureImageGridAdapter.AnonymousClass1 */

            public void onClick(View view) {
                pictureCustomDialog.dismiss();
            }
        });
        pictureCustomDialog.show();
    }

    private void singleRadioMediaImage() {
        List<LocalMedia> list = this.selectData;
        if (list != null && list.size() > 0) {
            notifyItemChanged(this.selectData.get(0).position);
            this.selectData.clear();
        }
    }

    private void subSelectPosition() {
        if (this.config.checkNumMode) {
            int size = this.selectData.size();
            int i5 = 0;
            while (i5 < size) {
                LocalMedia localMedia = this.selectData.get(i5);
                i5++;
                localMedia.setNum(i5);
                notifyItemChanged(localMedia.position);
            }
        }
    }

    public void bindData(List<LocalMedia> list) {
        if (list == null) {
            list = new ArrayList<>();
        }
        this.data = list;
        notifyDataSetChanged();
    }

    public void bindSelectData(List<LocalMedia> list) {
        ArrayList arrayList = new ArrayList();
        int size = list.size();
        for (int i5 = 0; i5 < size; i5++) {
            arrayList.add(list.get(i5));
        }
        this.selectData = arrayList;
        if (!this.config.isSingleDirectReturn) {
            subSelectPosition();
            OnPhotoSelectChangedListener<LocalMedia> onPhotoSelectChangedListener = this.imageSelectChangedListener;
            if (onPhotoSelectChangedListener != null) {
                onPhotoSelectChangedListener.onChange(this.selectData);
            }
        }
    }

    public void clear() {
        if (getSize() > 0) {
            this.data.clear();
        }
    }

    public List<LocalMedia> getData() {
        List<LocalMedia> list = this.data;
        return list == null ? new ArrayList() : list;
    }

    public LocalMedia getItem(int i5) {
        if (getSize() > 0) {
            return this.data.get(i5);
        }
        return null;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.h
    public int getItemCount() {
        return this.showCamera ? this.data.size() + 1 : this.data.size();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.h
    public int getItemViewType(int i5) {
        return (!this.showCamera || i5 != 0) ? 2 : 1;
    }

    public List<LocalMedia> getSelectedData() {
        List<LocalMedia> list = this.selectData;
        return list == null ? new ArrayList() : list;
    }

    public int getSelectedSize() {
        List<LocalMedia> list = this.selectData;
        if (list == null) {
            return 0;
        }
        return list.size();
    }

    public int getSize() {
        List<LocalMedia> list = this.data;
        if (list == null) {
            return 0;
        }
        return list.size();
    }

    public boolean isDataEmpty() {
        List<LocalMedia> list = this.data;
        return list == null || list.size() == 0;
    }

    public boolean isSelected(LocalMedia localMedia) {
        int size = this.selectData.size();
        for (int i5 = 0; i5 < size; i5++) {
            LocalMedia localMedia2 = this.selectData.get(i5);
            if (localMedia2 != null && !TextUtils.isEmpty(localMedia2.getPath()) && (TextUtils.equals(localMedia2.getPath(), localMedia.getPath()) || localMedia2.getId() == localMedia.getId())) {
                setLocalMediaCropInfo(localMedia2, localMedia);
                return true;
            }
        }
        return false;
    }

    public boolean isShowCamera() {
        return this.showCamera;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:61:0x012c, code lost:
        if (r4 != false) goto L_0x0118;
     */
    @Override // androidx.recyclerview.widget.RecyclerView.h
    public void onBindViewHolder(RecyclerView.e0 e0Var, int i5) {
        int i6;
        TextView textView;
        int i7;
        int i8;
        Context context2;
        if (getItemViewType(i5) == 1) {
            ((CameraViewHolder) e0Var).itemView.setOnClickListener(new b(this));
            return;
        }
        ViewHolder viewHolder = (ViewHolder) e0Var;
        LocalMedia localMedia = this.data.get(this.showCamera ? i5 - 1 : i5);
        localMedia.position = viewHolder.getAbsoluteAdapterPosition();
        String mimeType = localMedia.getMimeType();
        if (this.config.checkNumMode) {
            notifyCheckChanged(viewHolder, localMedia);
        }
        if (this.config.isSingleDirectReturn) {
            viewHolder.tvCheck.setVisibility(8);
            viewHolder.btnCheck.setVisibility(8);
        } else {
            selectImage(viewHolder, isSelected(localMedia));
            viewHolder.tvCheck.setVisibility(0);
            viewHolder.btnCheck.setVisibility(0);
            if (this.config.isMaxSelectEnabledMask) {
                dispatchHandleMask(viewHolder, localMedia);
            }
        }
        String path = localMedia.getPath();
        if (!localMedia.isEditorImage() || TextUtils.isEmpty(localMedia.getCutPath())) {
            viewHolder.ivEditor.setVisibility(8);
        } else {
            viewHolder.ivEditor.setVisibility(0);
            path = localMedia.getCutPath();
        }
        boolean isGif = PictureMimeType.isGif(mimeType);
        boolean isWebp = PictureMimeType.isWebp(mimeType);
        boolean isLongImg = MediaUtils.isLongImg(localMedia);
        if ((isGif || isWebp) && !isLongImg) {
            viewHolder.tvImageMimeType.setVisibility(0);
            TextView textView2 = viewHolder.tvImageMimeType;
            if (isGif) {
                context2 = this.context;
                i8 = R.string.picture_gif_tag;
            } else {
                context2 = this.context;
                i8 = R.string.picture_webp_tag;
            }
            textView2.setText(context2.getString(i8));
        } else {
            viewHolder.tvImageMimeType.setVisibility(8);
        }
        if (PictureMimeType.isHasImage(localMedia.getMimeType())) {
            if (localMedia.loadLongImageStatus == -1) {
                localMedia.isLongImage = isLongImg;
                localMedia.loadLongImageStatus = 0;
            }
            viewHolder.tvLongChart.setVisibility(localMedia.isLongImage ? 0 : 8);
        } else {
            localMedia.loadLongImageStatus = -1;
            viewHolder.tvLongChart.setVisibility(8);
        }
        boolean isHasVideo = PictureMimeType.isHasVideo(mimeType);
        if (isHasVideo || PictureMimeType.isHasAudio(mimeType)) {
            viewHolder.tvDuration.setVisibility(0);
            viewHolder.tvDuration.setText(DateUtils.formatDurationTime(localMedia.getDuration()));
            PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
            if (pictureSelectorUIStyle != null) {
                if (isHasVideo) {
                    i7 = pictureSelectorUIStyle.picture_adapter_item_video_textLeftDrawable;
                    if (i7 == 0) {
                        textView = viewHolder.tvDuration;
                    }
                } else {
                    i7 = pictureSelectorUIStyle.picture_adapter_item_audio_textLeftDrawable;
                    if (i7 == 0) {
                        textView = viewHolder.tvDuration;
                        i6 = R.drawable.picture_icon_audio;
                        textView.setCompoundDrawablesRelativeWithIntrinsicBounds(i6, 0, 0, 0);
                    }
                }
                viewHolder.tvDuration.setCompoundDrawablesRelativeWithIntrinsicBounds(i7, 0, 0, 0);
            } else {
                textView = viewHolder.tvDuration;
            }
            i6 = R.drawable.picture_icon_video;
            textView.setCompoundDrawablesRelativeWithIntrinsicBounds(i6, 0, 0, 0);
        } else {
            viewHolder.tvDuration.setVisibility(8);
        }
        if (this.config.chooseMode == PictureMimeType.ofAudio()) {
            viewHolder.ivPicture.setImageResource(R.drawable.picture_audio_placeholder);
        } else {
            ImageEngine imageEngine = PictureSelectionConfig.imageEngine;
            if (imageEngine != null) {
                imageEngine.loadGridImage(this.context, path, viewHolder.ivPicture);
            }
        }
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.enablePreview || pictureSelectionConfig.enPreviewVideo || pictureSelectionConfig.enablePreviewAudio) {
            viewHolder.btnCheck.setOnClickListener(new c(this, localMedia, viewHolder, mimeType));
        }
        viewHolder.contentView.setOnClickListener(new d(this, localMedia, mimeType, i5, viewHolder));
    }

    @Override // androidx.recyclerview.widget.RecyclerView.h
    public RecyclerView.e0 onCreateViewHolder(ViewGroup viewGroup, int i5) {
        return i5 == 1 ? new CameraViewHolder(LayoutInflater.from(this.context).inflate(R.layout.picture_item_camera, viewGroup, false)) : new ViewHolder(LayoutInflater.from(this.context).inflate(R.layout.picture_image_grid_item, viewGroup, false));
    }

    public void selectImage(ViewHolder viewHolder, boolean z4) {
        Context context2;
        int i5;
        viewHolder.tvCheck.setSelected(z4);
        if (z4) {
            context2 = this.context;
            i5 = R.color.picture_color_80;
        } else {
            context2 = this.context;
            i5 = R.color.picture_color_20;
        }
        viewHolder.ivPicture.setColorFilter(a.a(androidx.core.content.a.b(context2, i5), b.SRC_ATOP));
    }

    public void setOnPhotoSelectChangedListener(OnPhotoSelectChangedListener<LocalMedia> onPhotoSelectChangedListener) {
        this.imageSelectChangedListener = onPhotoSelectChangedListener;
    }

    public void setShowCamera(boolean z4) {
        this.showCamera = z4;
    }
}
