package com.luck.picture.lib.adapter;

import android.graphics.ColorFilter;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import androidx.recyclerview.widget.RecyclerView;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.engine.ImageEngine;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.style.PictureSelectorUIStyle;
import java.util.ArrayList;
import java.util.List;
import y.a;
import y.b;

public class PictureWeChatPreviewGalleryAdapter extends RecyclerView.h<ViewHolder> {
    private final PictureSelectionConfig config;
    private OnItemClickListener listener;
    private List<LocalMedia> mList = new ArrayList();

    public interface OnItemClickListener {
        void onItemClick(int i5, LocalMedia localMedia, View view);
    }

    /* access modifiers changed from: package-private */
    public static class ViewHolder extends RecyclerView.e0 {
        ImageView ivEditor;
        ImageView ivImage;
        ImageView ivPlay;
        View viewBorder;

        public ViewHolder(View view) {
            super(view);
            int i5;
            this.ivImage = (ImageView) view.findViewById(R.id.ivImage);
            this.ivPlay = (ImageView) view.findViewById(R.id.ivPlay);
            this.ivEditor = (ImageView) view.findViewById(R.id.ivEditor);
            View findViewById = view.findViewById(R.id.viewBorder);
            this.viewBorder = findViewById;
            PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
            if (pictureSelectorUIStyle != null) {
                int i6 = pictureSelectorUIStyle.picture_bottom_gallery_frameBackground;
                if (i6 != 0) {
                    findViewById.setBackgroundResource(i6);
                }
                i5 = PictureSelectionConfig.uiStyle.picture_adapter_item_editor_tag_icon;
                if (i5 == 0) {
                    return;
                }
            } else {
                PictureParameterStyle pictureParameterStyle = PictureSelectionConfig.style;
                if (pictureParameterStyle == null || (i5 = pictureParameterStyle.picture_adapter_item_editor_tag_icon) == 0) {
                    return;
                }
            }
            this.ivEditor.setImageResource(i5);
        }
    }

    public PictureWeChatPreviewGalleryAdapter(PictureSelectionConfig pictureSelectionConfig) {
        this.config = pictureSelectionConfig;
    }

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$onBindViewHolder$0(ViewHolder viewHolder, int i5, View view) {
        if (this.listener != null && viewHolder.getAbsoluteAdapterPosition() >= 0) {
            this.listener.onItemClick(viewHolder.getAbsoluteAdapterPosition(), getItem(i5), view);
        }
    }

    public void addSingleMediaToData(LocalMedia localMedia) {
        this.mList.clear();
        this.mList.add(localMedia);
        notifyDataSetChanged();
    }

    public LocalMedia getItem(int i5) {
        if (this.mList.size() > 0) {
            return this.mList.get(i5);
        }
        return null;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.h
    public int getItemCount() {
        return this.mList.size();
    }

    public void onBindViewHolder(ViewHolder viewHolder, int i5) {
        ImageEngine imageEngine;
        LocalMedia item = getItem(i5);
        ColorFilter a5 = a.a(androidx.core.content.a.b(viewHolder.itemView.getContext(), item.isMaxSelectEnabledMask() ? R.color.picture_color_half_white : R.color.picture_color_transparent), b.SRC_ATOP);
        int i6 = 8;
        if (!item.isChecked() || !item.isMaxSelectEnabledMask()) {
            viewHolder.viewBorder.setVisibility(item.isChecked() ? 0 : 8);
        } else {
            viewHolder.viewBorder.setVisibility(0);
        }
        String path = item.getPath();
        if (!item.isEditorImage() || TextUtils.isEmpty(item.getCutPath())) {
            viewHolder.ivEditor.setVisibility(8);
        } else {
            path = item.getCutPath();
            viewHolder.ivEditor.setVisibility(0);
        }
        viewHolder.ivImage.setColorFilter(a5);
        if (!(this.config == null || (imageEngine = PictureSelectionConfig.imageEngine) == null)) {
            imageEngine.loadImage(viewHolder.itemView.getContext(), path, viewHolder.ivImage);
        }
        ImageView imageView = viewHolder.ivPlay;
        if (PictureMimeType.isHasVideo(item.getMimeType())) {
            i6 = 0;
        }
        imageView.setVisibility(i6);
        viewHolder.itemView.setOnClickListener(new h(this, viewHolder, i5));
    }

    @Override // androidx.recyclerview.widget.RecyclerView.h
    public ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i5) {
        return new ViewHolder(LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.picture_wechat_preview_gallery, viewGroup, false));
    }

    public void removeMediaToData(LocalMedia localMedia) {
        if (this.mList.size() > 0) {
            this.mList.remove(localMedia);
            notifyDataSetChanged();
        }
    }

    public void setItemClickListener(OnItemClickListener onItemClickListener) {
        this.listener = onItemClickListener;
    }

    public void setNewData(List<LocalMedia> list, boolean z4) {
        if (list != null) {
            if (z4) {
                this.mList.clear();
                this.mList.addAll(list);
            } else {
                this.mList = list;
            }
            notifyDataSetChanged();
        }
    }
}
