package com.luck.picture.lib.camera;

import android.content.Context;
import android.graphics.SurfaceTexture;
import android.media.MediaPlayer;
import android.net.Uri;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.Surface;
import android.view.TextureView;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import androidx.camera.core.h2;
import androidx.camera.core.j0;
import androidx.camera.core.j1;
import androidx.camera.core.n1;
import androidx.camera.core.n3;
import androidx.camera.core.p;
import androidx.camera.lifecycle.c;
import androidx.camera.view.PreviewView;
import androidx.core.content.a;
import androidx.lifecycle.l;
import com.luck.picture.lib.R;
import com.luck.picture.lib.camera.listener.CameraListener;
import com.luck.picture.lib.camera.listener.CaptureListener;
import com.luck.picture.lib.camera.listener.ClickListener;
import com.luck.picture.lib.camera.listener.ImageCallbackListener;
import com.luck.picture.lib.camera.listener.TypeListener;
import com.luck.picture.lib.camera.view.CaptureLayout;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.tools.CameraFileUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.ScreenUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.StringUtils;
import java.lang.ref.WeakReference;

public class CustomCameraView extends RelativeLayout {
    public static final int DEFAULT_MIN_RECORD_VIDEO = 1500;
    private static final int TYPE_FLASH_AUTO = 33;
    private static final int TYPE_FLASH_OFF = 35;
    private static final int TYPE_FLASH_ON = 34;
    private int lensFacing = 1;
    private CameraListener mCameraListener;
    private PreviewView mCameraPreviewView;
    private c mCameraProvider;
    private CaptureLayout mCaptureLayout;
    private PictureSelectionConfig mConfig;
    private ImageView mFlashLamp;
    private ImageCallbackListener mImageCallbackListener;
    private j1 mImageCapture;
    private ImageView mImagePreview;
    private MediaPlayer mMediaPlayer;
    private ClickListener mOnClickListener;
    private ImageView mSwitchCamera;
    private TextureView mTextureView;
    private n3 mVideoCapture;
    private long recordTime = 0;
    private final TextureView.SurfaceTextureListener surfaceTextureListener = new TextureView.SurfaceTextureListener() {
        /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass6 */

        public void onSurfaceTextureAvailable(SurfaceTexture surfaceTexture, int i5, int i6) {
            CustomCameraView customCameraView = CustomCameraView.this;
            customCameraView.startVideoPlay(customCameraView.mConfig.cameraPath);
        }

        public boolean onSurfaceTextureDestroyed(SurfaceTexture surfaceTexture) {
            return false;
        }

        public void onSurfaceTextureSizeChanged(SurfaceTexture surfaceTexture, int i5, int i6) {
        }

        public void onSurfaceTextureUpdated(SurfaceTexture surfaceTexture) {
        }
    };
    private int type_flash = 35;
    private int useCameraCases = 1;

    private static class MyImageResultCallback implements j1.q {
        private final WeakReference<CameraListener> mCameraListenerReference;
        private final WeakReference<CaptureLayout> mCaptureLayoutReference;
        private final WeakReference<PictureSelectionConfig> mConfigReference;
        private final WeakReference<ImageCallbackListener> mImageCallbackListenerReference;
        private final WeakReference<ImageView> mImagePreviewReference;

        public MyImageResultCallback(ImageView imageView, CaptureLayout captureLayout, ImageCallbackListener imageCallbackListener, CameraListener cameraListener, PictureSelectionConfig pictureSelectionConfig) {
            this.mImagePreviewReference = new WeakReference<>(imageView);
            this.mCaptureLayoutReference = new WeakReference<>(captureLayout);
            this.mImageCallbackListenerReference = new WeakReference<>(imageCallbackListener);
            this.mCameraListenerReference = new WeakReference<>(cameraListener);
            this.mConfigReference = new WeakReference<>(pictureSelectionConfig);
        }

        @Override // androidx.camera.core.j1.q
        public void onError(n1 n1Var) {
            if (this.mCaptureLayoutReference.get() != null) {
                this.mCaptureLayoutReference.get().setButtonCaptureEnabled(true);
            }
            if (this.mCameraListenerReference.get() != null) {
                this.mCameraListenerReference.get().onError(n1Var.a(), n1Var.getMessage(), n1Var.getCause());
            }
        }

        @Override // androidx.camera.core.j1.q
        public void onImageSaved(j1.s sVar) {
            if (sVar.a() != null) {
                Uri a5 = sVar.a();
                String uri = a5.toString();
                if (this.mConfigReference.get() != null) {
                    this.mConfigReference.get().cameraPath = PictureMimeType.isContent(uri) ? uri : a5.getPath();
                }
                if (this.mCaptureLayoutReference.get() != null) {
                    this.mCaptureLayoutReference.get().setButtonCaptureEnabled(true);
                }
                if (!(this.mImageCallbackListenerReference.get() == null || this.mImagePreviewReference.get() == null)) {
                    this.mImageCallbackListenerReference.get().onLoadImage(uri, this.mImagePreviewReference.get());
                }
                if (this.mImagePreviewReference.get() != null) {
                    this.mImagePreviewReference.get().setVisibility(0);
                }
                if (this.mCaptureLayoutReference.get() != null) {
                    this.mCaptureLayoutReference.get().startTypeBtnAnimator();
                }
            }
        }
    }

    public CustomCameraView(Context context) {
        super(context);
        initView();
    }

    public CustomCameraView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        initView();
    }

    public CustomCameraView(Context context, AttributeSet attributeSet, int i5) {
        super(context, attributeSet, i5);
        initView();
    }

    private int aspectRatio(int i5, int i6) {
        double max = (double) (Math.max(i5, i6) / Math.min(i5, i6));
        return Math.abs(max - 1.3333333333333333d) <= Math.abs(max - 1.7777777777777777d) ? 0 : 1;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void bindCameraImageUseCases() {
        try {
            int aspectRatio = aspectRatio(ScreenUtils.getScreenWidth(getContext()), ScreenUtils.getScreenHeight(getContext()));
            p b5 = new p.a().d(this.lensFacing).b();
            h2 c5 = new h2.b().g(aspectRatio).c();
            this.mImageCapture = new j1.j().f(1).h(aspectRatio).c();
            j0 c6 = new j0.c().h(aspectRatio).c();
            this.mCameraProvider.i();
            this.mCameraProvider.c((l) getContext(), b5, c5, this.mImageCapture, c6);
            c5.K(this.mCameraPreviewView.getSurfaceProvider());
            setFlashMode();
        } catch (Exception e5) {
            e5.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void bindCameraUseCases() {
        int i5 = this.mConfig.buttonFeatures;
        if (i5 == 259 || i5 == 257) {
            bindCameraImageUseCases();
        } else {
            bindCameraVideoUseCases();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void bindCameraVideoUseCases() {
        try {
            p b5 = new p.a().d(this.lensFacing).b();
            h2 c5 = new h2.b().c();
            this.mVideoCapture = new n3.d().c();
            this.mCameraProvider.i();
            this.mCameraProvider.c((l) getContext(), b5, c5, this.mVideoCapture);
            c5.K(this.mCameraPreviewView.getSurfaceProvider());
        } catch (Exception e5) {
            e5.printStackTrace();
        }
    }

    private void initView() {
        RelativeLayout.inflate(getContext(), R.layout.picture_camera_view, this);
        setBackgroundColor(a.b(getContext(), R.color.picture_color_black));
        this.mCameraPreviewView = (PreviewView) findViewById(R.id.cameraPreviewView);
        this.mTextureView = (TextureView) findViewById(R.id.video_play_preview);
        this.mImagePreview = (ImageView) findViewById(R.id.image_preview);
        this.mSwitchCamera = (ImageView) findViewById(R.id.image_switch);
        this.mFlashLamp = (ImageView) findViewById(R.id.image_flash);
        this.mCaptureLayout = (CaptureLayout) findViewById(R.id.capture_layout);
        this.mSwitchCamera.setImageResource(R.drawable.picture_ic_camera);
        this.mFlashLamp.setOnClickListener(new a(this));
        this.mCaptureLayout.setDuration(15000);
        this.mSwitchCamera.setOnClickListener(new View.OnClickListener() {
            /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass1 */

            public void onClick(View view) {
                CustomCameraView.this.toggleCamera();
            }
        });
        this.mCaptureLayout.setCaptureListener(new CaptureListener() {
            /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass2 */

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            public void recordEnd(long j5) {
                CustomCameraView.this.recordTime = j5;
                CustomCameraView.this.mVideoCapture.Z();
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            public void recordError() {
                if (CustomCameraView.this.mCameraListener != null) {
                    CustomCameraView.this.mCameraListener.onError(0, "An unknown error", null);
                }
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            public void recordShort(long j5) {
                CustomCameraView.this.recordTime = j5;
                CustomCameraView.this.mSwitchCamera.setVisibility(0);
                CustomCameraView.this.mFlashLamp.setVisibility(0);
                CustomCameraView.this.mCaptureLayout.resetCaptureLayout();
                CustomCameraView.this.mCaptureLayout.setTextWithAnimation(CustomCameraView.this.getContext().getString(R.string.picture_recording_time_is_short));
                CustomCameraView.this.mVideoCapture.Z();
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            public void recordStart() {
                String str;
                if (!CustomCameraView.this.mCameraProvider.e(CustomCameraView.this.mVideoCapture)) {
                    CustomCameraView.this.bindCameraVideoUseCases();
                }
                CustomCameraView.this.useCameraCases = 4;
                CustomCameraView.this.mSwitchCamera.setVisibility(4);
                CustomCameraView.this.mFlashLamp.setVisibility(4);
                if (TextUtils.isEmpty(CustomCameraView.this.mConfig.cameraFileName)) {
                    str = "";
                } else {
                    CustomCameraView.this.mConfig.cameraFileName = PictureMimeType.isSuffixOfImage(CustomCameraView.this.mConfig.cameraFileName) ? StringUtils.renameSuffix(CustomCameraView.this.mConfig.cameraFileName, ".mp4") : CustomCameraView.this.mConfig.cameraFileName;
                    str = CustomCameraView.this.mConfig.camera ? CustomCameraView.this.mConfig.cameraFileName : StringUtils.rename(CustomCameraView.this.mConfig.cameraFileName);
                }
                CustomCameraView.this.mVideoCapture.U(((!SdkVersionUtils.isQ() || !TextUtils.isEmpty(CustomCameraView.this.mConfig.outPutCameraPath)) ? new n3.h.a(PictureFileUtils.createCameraFile(CustomCameraView.this.getContext(), 2, str, CustomCameraView.this.mConfig.cameraVideoFormat, CustomCameraView.this.mConfig.outPutCameraPath)) : new n3.h.a(CustomCameraView.this.getContext().getContentResolver(), MediaStore.Video.Media.EXTERNAL_CONTENT_URI, CameraFileUtils.buildVideoContentValues(str, CustomCameraView.this.mConfig.cameraImageFormatForQ))).a(), a.g(CustomCameraView.this.getContext()), new n3.g() {
                    /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass2.AnonymousClass1 */

                    @Override // androidx.camera.core.n3.g
                    public void onError(int i5, String str, Throwable th) {
                        if (CustomCameraView.this.mCameraListener != null) {
                            CustomCameraView.this.mCameraListener.onError(i5, str, th);
                        }
                    }

                    @Override // androidx.camera.core.n3.g
                    public void onVideoSaved(n3.i iVar) {
                        if (CustomCameraView.this.recordTime >= (CustomCameraView.this.mConfig.recordVideoMinSecond <= 0 ? 1500 : ((long) CustomCameraView.this.mConfig.recordVideoMinSecond) * 1000) && iVar.a() != null) {
                            Uri a5 = iVar.a();
                            String uri = a5.toString();
                            PictureSelectionConfig pictureSelectionConfig = CustomCameraView.this.mConfig;
                            if (!PictureMimeType.isContent(uri)) {
                                uri = a5.getPath();
                            }
                            pictureSelectionConfig.cameraPath = uri;
                            CustomCameraView.this.mTextureView.setVisibility(0);
                            CustomCameraView.this.mCameraPreviewView.setVisibility(4);
                            if (CustomCameraView.this.mTextureView.isAvailable()) {
                                CustomCameraView customCameraView = CustomCameraView.this;
                                customCameraView.startVideoPlay(customCameraView.mConfig.cameraPath);
                                return;
                            }
                            CustomCameraView.this.mTextureView.setSurfaceTextureListener(CustomCameraView.this.surfaceTextureListener);
                        }
                    }
                });
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            public void recordZoom(float f5) {
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            public void takePictures() {
                String str;
                if (!CustomCameraView.this.mCameraProvider.e(CustomCameraView.this.mImageCapture)) {
                    CustomCameraView.this.bindCameraImageUseCases();
                }
                CustomCameraView.this.useCameraCases = 1;
                CustomCameraView.this.mCaptureLayout.setButtonCaptureEnabled(false);
                CustomCameraView.this.mSwitchCamera.setVisibility(4);
                CustomCameraView.this.mFlashLamp.setVisibility(4);
                if (TextUtils.isEmpty(CustomCameraView.this.mConfig.cameraFileName)) {
                    str = "";
                } else {
                    CustomCameraView.this.mConfig.cameraFileName = !PictureMimeType.isSuffixOfImage(CustomCameraView.this.mConfig.cameraFileName) ? StringUtils.renameSuffix(CustomCameraView.this.mConfig.cameraFileName, PictureMimeType.JPG) : CustomCameraView.this.mConfig.cameraFileName;
                    str = CustomCameraView.this.mConfig.camera ? CustomCameraView.this.mConfig.cameraFileName : StringUtils.rename(CustomCameraView.this.mConfig.cameraFileName);
                }
                CustomCameraView.this.mImageCapture.q0(((!SdkVersionUtils.isQ() || !TextUtils.isEmpty(CustomCameraView.this.mConfig.outPutCameraPath)) ? new j1.r.a(PictureFileUtils.createCameraFile(CustomCameraView.this.getContext(), 1, str, CustomCameraView.this.mConfig.cameraImageFormat, CustomCameraView.this.mConfig.outPutCameraPath)) : new j1.r.a(CustomCameraView.this.getContext().getContentResolver(), MediaStore.Images.Media.EXTERNAL_CONTENT_URI, CameraFileUtils.buildImageContentValues(str, CustomCameraView.this.mConfig.cameraImageFormatForQ))).a(), a.g(CustomCameraView.this.getContext()), new MyImageResultCallback(CustomCameraView.this.mImagePreview, CustomCameraView.this.mCaptureLayout, CustomCameraView.this.mImageCallbackListener, CustomCameraView.this.mCameraListener, CustomCameraView.this.mConfig));
            }
        });
        this.mCaptureLayout.setTypeListener(new TypeListener() {
            /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass3 */

            @Override // com.luck.picture.lib.camera.listener.TypeListener
            public void cancel() {
                CustomCameraView.this.onCancelMedia();
            }

            @Override // com.luck.picture.lib.camera.listener.TypeListener
            public void confirm() {
                if (CustomCameraView.this.isImageCaptureEnabled()) {
                    CustomCameraView.this.mImagePreview.setVisibility(4);
                    if (CustomCameraView.this.mCameraListener != null) {
                        CustomCameraView.this.mCameraListener.onPictureSuccess(CustomCameraView.this.mConfig.cameraPath);
                        return;
                    }
                    return;
                }
                CustomCameraView.this.stopVideoPlay();
                if (CustomCameraView.this.mCameraListener != null) {
                    CustomCameraView.this.mCameraListener.onRecordSuccess(CustomCameraView.this.mConfig.cameraPath);
                }
            }
        });
        this.mCaptureLayout.setLeftClickListener(new ClickListener() {
            /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass4 */

            @Override // com.luck.picture.lib.camera.listener.ClickListener
            public void onClick() {
                if (CustomCameraView.this.mOnClickListener != null) {
                    CustomCameraView.this.mOnClickListener.onClick();
                }
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean isImageCaptureEnabled() {
        return this.useCameraCases == 1;
    }

    /* access modifiers changed from: private */
    public /* synthetic */ void lambda$initView$0(View view) {
        int i5 = this.type_flash + 1;
        this.type_flash = i5;
        if (i5 > 35) {
            this.type_flash = 33;
        }
        setFlashMode();
    }

    private void resetState() {
        if (isImageCaptureEnabled()) {
            this.mImagePreview.setVisibility(4);
        } else {
            this.mVideoCapture.Z();
        }
        this.mSwitchCamera.setVisibility(0);
        this.mFlashLamp.setVisibility(0);
        this.mCameraPreviewView.setVisibility(0);
        this.mCaptureLayout.resetCaptureLayout();
    }

    private void setFlashMode() {
        int i5;
        j1 j1Var;
        if (this.mImageCapture != null) {
            switch (this.type_flash) {
                case 33:
                    this.mFlashLamp.setImageResource(R.drawable.picture_ic_flash_auto);
                    j1Var = this.mImageCapture;
                    i5 = 0;
                    break;
                case 34:
                    this.mFlashLamp.setImageResource(R.drawable.picture_ic_flash_on);
                    j1Var = this.mImageCapture;
                    i5 = 1;
                    break;
                case 35:
                    this.mFlashLamp.setImageResource(R.drawable.picture_ic_flash_off);
                    j1Var = this.mImageCapture;
                    i5 = 2;
                    break;
                default:
                    return;
            }
            j1Var.B0(i5);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startVideoPlay(String str) {
        try {
            MediaPlayer mediaPlayer = this.mMediaPlayer;
            if (mediaPlayer == null) {
                this.mMediaPlayer = new MediaPlayer();
            } else {
                mediaPlayer.reset();
            }
            if (PictureMimeType.isContent(str)) {
                this.mMediaPlayer.setDataSource(getContext(), Uri.parse(str));
            } else {
                this.mMediaPlayer.setDataSource(str);
            }
            this.mMediaPlayer.setSurface(new Surface(this.mTextureView.getSurfaceTexture()));
            this.mMediaPlayer.setVideoScalingMode(1);
            this.mMediaPlayer.setAudioStreamType(3);
            this.mMediaPlayer.setOnVideoSizeChangedListener(new MediaPlayer.OnVideoSizeChangedListener() {
                /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass7 */

                public void onVideoSizeChanged(MediaPlayer mediaPlayer, int i5, int i6) {
                    CustomCameraView customCameraView = CustomCameraView.this;
                    customCameraView.updateVideoViewSize((float) customCameraView.mMediaPlayer.getVideoWidth(), (float) CustomCameraView.this.mMediaPlayer.getVideoHeight());
                }
            });
            this.mMediaPlayer.setOnPreparedListener(new MediaPlayer.OnPreparedListener() {
                /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass8 */

                public void onPrepared(MediaPlayer mediaPlayer) {
                    if (CustomCameraView.this.mMediaPlayer != null) {
                        CustomCameraView.this.mMediaPlayer.start();
                    }
                }
            });
            this.mMediaPlayer.setLooping(true);
            this.mMediaPlayer.prepareAsync();
        } catch (Exception e5) {
            e5.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopVideoPlay() {
        MediaPlayer mediaPlayer = this.mMediaPlayer;
        if (mediaPlayer != null && mediaPlayer.isPlaying()) {
            this.mMediaPlayer.stop();
            this.mMediaPlayer.release();
            this.mMediaPlayer = null;
        }
        this.mTextureView.setVisibility(8);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateVideoViewSize(float f5, float f6) {
        if (f5 > f6) {
            FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(-1, (int) ((f6 / f5) * ((float) getWidth())));
            layoutParams.gravity = 17;
            this.mTextureView.setLayoutParams(layoutParams);
        }
    }

    public CaptureLayout getCaptureLayout() {
        return this.mCaptureLayout;
    }

    public void initCamera() {
        PictureSelectionConfig instance = PictureSelectionConfig.getInstance();
        this.mConfig = instance;
        this.lensFacing = !instance.isCameraAroundState ? 1 : 0;
        if (a.a(getContext(), "android.permission.CAMERA") == 0) {
            final c2.a<c> d5 = c.d(getContext());
            d5.a(new Runnable() {
                /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass5 */

                public void run() {
                    try {
                        CustomCameraView.this.mCameraProvider = (c) d5.get();
                        CustomCameraView.this.bindCameraUseCases();
                    } catch (Exception e5) {
                        e5.printStackTrace();
                    }
                }
            }, a.g(getContext()));
        }
    }

    public void onCancelMedia() {
        stopVideoPlay();
        resetState();
    }

    public void setCameraListener(CameraListener cameraListener) {
        this.mCameraListener = cameraListener;
    }

    public void setCaptureLoadingColor(int i5) {
        this.mCaptureLayout.setCaptureLoadingColor(i5);
    }

    public void setImageCallbackListener(ImageCallbackListener imageCallbackListener) {
        this.mImageCallbackListener = imageCallbackListener;
    }

    public void setOnClickListener(ClickListener clickListener) {
        this.mOnClickListener = clickListener;
    }

    public void setRecordVideoMaxTime(int i5) {
        this.mCaptureLayout.setDuration(i5 * 1000);
    }

    public void setRecordVideoMinTime(int i5) {
        this.mCaptureLayout.setMinDuration(i5 * 1000);
    }

    public void toggleCamera() {
        this.lensFacing = this.lensFacing == 0 ? 1 : 0;
        bindCameraUseCases();
    }
}
