package com.luck.picture.lib.compress;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.tools.BitmapUtils;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;

/* access modifiers changed from: package-private */
public class Engine {
    private static final int DEFAULT_QUALITY = 80;
    private int compressQuality;
    private final Context context;
    @Deprecated
    private final boolean focusAlpha;
    private final boolean isAutoRotating;
    private int srcHeight;
    private final InputStreamProvider srcImg;
    private int srcWidth;
    private final File tagImg;

    Engine(Context context2, InputStreamProvider inputStreamProvider, File file, boolean z4, int i5, boolean z5) {
        int i6;
        this.tagImg = file;
        this.srcImg = inputStreamProvider;
        this.context = context2;
        this.focusAlpha = z4;
        this.isAutoRotating = z5;
        this.compressQuality = i5 <= 0 ? 80 : i5;
        if (inputStreamProvider.getMedia().getWidth() <= 0 || inputStreamProvider.getMedia().getHeight() <= 0) {
            BitmapFactory.Options options = new BitmapFactory.Options();
            options.inJustDecodeBounds = true;
            options.inSampleSize = 1;
            BitmapFactory.decodeStream(inputStreamProvider.open(), null, options);
            this.srcWidth = options.outWidth;
            i6 = options.outHeight;
        } else {
            this.srcWidth = inputStreamProvider.getMedia().getWidth();
            i6 = inputStreamProvider.getMedia().getHeight();
        }
        this.srcHeight = i6;
    }

    private int computeSize() {
        int i5 = this.srcWidth;
        if (i5 % 2 == 1) {
            i5++;
        }
        this.srcWidth = i5;
        int i6 = this.srcHeight;
        if (i6 % 2 == 1) {
            i6++;
        }
        this.srcHeight = i6;
        int max = Math.max(i5, i6);
        float min = ((float) Math.min(this.srcWidth, this.srcHeight)) / ((float) max);
        if (min > 1.0f || ((double) min) <= 0.5625d) {
            double d5 = (double) min;
            if (d5 > 0.5625d || d5 <= 0.5d) {
                return (int) Math.ceil(((double) max) / (1280.0d / d5));
            }
            int i7 = max / 1280;
            if (i7 == 0) {
                return 1;
            }
            return i7;
        } else if (max < 1664) {
            return 1;
        } else {
            if (max < 4990) {
                return 2;
            }
            if (max <= 4990 || max >= 10240) {
                return max / 1280;
            }
            return 4;
        }
    }

    /* access modifiers changed from: package-private */
    public File compress() {
        BitmapFactory.Options options = new BitmapFactory.Options();
        options.inSampleSize = computeSize();
        Bitmap decodeStream = BitmapFactory.decodeStream(this.srcImg.open(), null, options);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        if (this.isAutoRotating && Checker.SINGLE.isJPG(this.srcImg.getMedia().getMimeType())) {
            String cutPath = this.srcImg.getMedia().isCut() ? this.srcImg.getMedia().getCutPath() : this.srcImg.getMedia().getPath();
            int readPictureDegree = PictureMimeType.isContent(cutPath) ? BitmapUtils.readPictureDegree(this.srcImg.open()) : BitmapUtils.readPictureDegree(this.context, cutPath);
            if (readPictureDegree > 0) {
                decodeStream = BitmapUtils.rotatingImage(decodeStream, readPictureDegree);
            }
        }
        if (decodeStream == null) {
            return null;
        }
        int i5 = this.compressQuality;
        if (i5 <= 0 || i5 > 100) {
            i5 = 80;
        }
        this.compressQuality = i5;
        decodeStream.compress((this.focusAlpha || decodeStream.hasAlpha()) ? Bitmap.CompressFormat.PNG : Bitmap.CompressFormat.JPEG, this.compressQuality, byteArrayOutputStream);
        decodeStream.recycle();
        FileOutputStream fileOutputStream = new FileOutputStream(this.tagImg);
        fileOutputStream.write(byteArrayOutputStream.toByteArray());
        fileOutputStream.flush();
        fileOutputStream.close();
        byteArrayOutputStream.close();
        return this.tagImg;
    }
}
