package com.luck.picture.lib.compress;

import android.content.Context;
import android.net.Uri;
import android.os.Environment;
import android.text.TextUtils;
import android.util.Log;
import com.luck.picture.lib.PictureContentResolver;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.AndroidQTransformUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.StringUtils;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class Luban {
    private static final String TAG = "Luban";
    private final int compressQuality;
    private final int dataCount;
    private final boolean focusAlpha;
    private int index;
    private final boolean isAutoRotating;
    private final boolean isCamera;
    private final OnCompressListener mCompressListener;
    private final CompressionPredicate mCompressionPredicate;
    private final int mLeastCompressSize;
    private final String mNewFileName;
    private final List<String> mPaths;
    private final OnRenameListener mRenameListener;
    private final List<InputStreamProvider> mStreamProviders;
    private String mTargetDir;
    private final List<LocalMedia> mediaList;

    public static class Builder {
        private int compressQuality;
        private final Context context;
        private int dataCount;
        private boolean focusAlpha;
        private boolean isAutoRotating;
        private boolean isCamera;
        private OnCompressListener mCompressListener;
        private CompressionPredicate mCompressionPredicate;
        private int mLeastCompressSize = 100;
        private String mNewFileName;
        private final List<String> mPaths;
        private OnRenameListener mRenameListener;
        private final List<InputStreamProvider> mStreamProviders;
        private String mTargetDir;
        private List<LocalMedia> mediaList;

        Builder(Context context2) {
            this.context = context2;
            this.mPaths = new ArrayList();
            this.mediaList = new ArrayList();
            this.mStreamProviders = new ArrayList();
        }

        private Luban build() {
            return new Luban(this);
        }

        private Builder load(final LocalMedia localMedia) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass1 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return localMedia;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return localMedia.isCut() ? localMedia.getCutPath() : localMedia.isToSandboxPath() ? localMedia.getAndroidQToPath() : localMedia.getPath();
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    if (PictureMimeType.isContent(localMedia.getPath()) && !localMedia.isCut()) {
                        return localMedia.isToSandboxPath() ? new FileInputStream(localMedia.getAndroidQToPath()) : PictureContentResolver.getContentResolverOpenInputStream(Builder.this.context, Uri.parse(localMedia.getPath()));
                    }
                    if (PictureMimeType.isHasHttp(localMedia.getPath()) && TextUtils.isEmpty(localMedia.getCutPath())) {
                        return null;
                    }
                    return new FileInputStream(localMedia.isCut() ? localMedia.getCutPath() : localMedia.getPath());
                }
            });
            return this;
        }

        public Builder filter(CompressionPredicate compressionPredicate) {
            this.mCompressionPredicate = compressionPredicate;
            return this;
        }

        public File get(final String str) {
            return build().get(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass5 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return str;
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    return new FileInputStream(str);
                }
            }, this.context);
        }

        public List<LocalMedia> get() {
            return build().get(this.context);
        }

        public Builder ignoreBy(int i5) {
            this.mLeastCompressSize = i5;
            return this;
        }

        public Builder isAutoRotating(boolean z4) {
            this.isAutoRotating = z4;
            return this;
        }

        public Builder isCamera(boolean z4) {
            this.isCamera = z4;
            return this;
        }

        public void launch() {
            build().launch(this.context);
        }

        public Builder load(final Uri uri) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass2 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return uri.getPath();
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    return PictureContentResolver.getContentResolverOpenInputStream(Builder.this.context, uri);
                }
            });
            return this;
        }

        public Builder load(InputStreamProvider inputStreamProvider) {
            this.mStreamProviders.add(inputStreamProvider);
            return this;
        }

        public Builder load(final File file) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass3 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return file.getAbsolutePath();
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    return new FileInputStream(file);
                }
            });
            return this;
        }

        public Builder load(final String str) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass4 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return str;
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    return new FileInputStream(str);
                }
            });
            return this;
        }

        public <T> Builder load(List<T> list) {
            for (T t5 : list) {
                if (t5 instanceof String) {
                    load((String) t5);
                } else if (t5 instanceof File) {
                    load((File) t5);
                } else if (t5 instanceof Uri) {
                    load((Uri) t5);
                } else {
                    throw new IllegalArgumentException("Incoming data type exception, it must be String, File, Uri or Bitmap");
                }
            }
            return this;
        }

        public <T> Builder loadMediaData(List<LocalMedia> list) {
            this.mediaList = list;
            this.dataCount = list.size();
            for (LocalMedia localMedia : list) {
                load(localMedia);
            }
            return this;
        }

        public Builder putGear(int i5) {
            return this;
        }

        public Builder setCompressListener(OnCompressListener onCompressListener) {
            this.mCompressListener = onCompressListener;
            return this;
        }

        public Builder setCompressQuality(int i5) {
            this.compressQuality = i5;
            return this;
        }

        @Deprecated
        public Builder setFocusAlpha(boolean z4) {
            this.focusAlpha = z4;
            return this;
        }

        public Builder setNewCompressFileName(String str) {
            this.mNewFileName = str;
            return this;
        }

        @Deprecated
        public Builder setRenameListener(OnRenameListener onRenameListener) {
            this.mRenameListener = onRenameListener;
            return this;
        }

        public Builder setTargetDir(String str) {
            this.mTargetDir = str;
            return this;
        }
    }

    private Luban(Builder builder) {
        this.index = -1;
        this.mPaths = builder.mPaths;
        this.mediaList = builder.mediaList;
        this.dataCount = builder.dataCount;
        this.mTargetDir = builder.mTargetDir;
        this.mNewFileName = builder.mNewFileName;
        this.mRenameListener = builder.mRenameListener;
        this.mStreamProviders = builder.mStreamProviders;
        this.mCompressListener = builder.mCompressListener;
        this.mLeastCompressSize = builder.mLeastCompressSize;
        this.mCompressionPredicate = builder.mCompressionPredicate;
        this.compressQuality = builder.compressQuality;
        this.isAutoRotating = builder.isAutoRotating;
        this.focusAlpha = builder.focusAlpha;
        this.isCamera = builder.isCamera;
    }

    static /* synthetic */ int access$1408(Luban luban) {
        int i5 = luban.index;
        luban.index = i5 + 1;
        return i5;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private File compress(Context context, InputStreamProvider inputStreamProvider) {
        try {
            return compressRealLocalMedia(context, inputStreamProvider);
        } finally {
            inputStreamProvider.close();
        }
    }

    private File compressReal(Context context, InputStreamProvider inputStreamProvider) {
        Engine engine;
        Checker checker = Checker.SINGLE;
        String extSuffix = checker.extSuffix(inputStreamProvider.getMedia() != null ? inputStreamProvider.getMedia().getMimeType() : "");
        File imageCacheFile = getImageCacheFile(context, inputStreamProvider, extSuffix);
        OnRenameListener onRenameListener = this.mRenameListener;
        if (onRenameListener != null) {
            imageCacheFile = getImageCustomFile(context, onRenameListener.rename(inputStreamProvider.getPath()));
        }
        CompressionPredicate compressionPredicate = this.mCompressionPredicate;
        if (compressionPredicate != null) {
            if (!compressionPredicate.apply(inputStreamProvider.getPath()) || !checker.needCompress(this.mLeastCompressSize, inputStreamProvider.getPath())) {
                return new File(inputStreamProvider.getPath());
            }
            engine = new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating);
        } else if (extSuffix.startsWith(PictureMimeType.GIF)) {
            return new File(inputStreamProvider.getPath());
        } else {
            if (!checker.needCompress(this.mLeastCompressSize, inputStreamProvider.getPath())) {
                return new File(inputStreamProvider.getPath());
            }
            engine = new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating);
        }
        return engine.compress();
    }

    private File compressRealLocalMedia(Context context, InputStreamProvider inputStreamProvider) {
        String str;
        File file;
        Engine engine;
        LocalMedia media = inputStreamProvider.getMedia();
        String cutPath = media.isCut() ? media.getCutPath() : media.getRealPath();
        Checker checker = Checker.SINGLE;
        String extSuffix = checker.extSuffix(media.getMimeType());
        File imageCacheFile = getImageCacheFile(context, inputStreamProvider, extSuffix);
        if (!TextUtils.isEmpty(this.mNewFileName)) {
            String rename = (this.isCamera || this.dataCount == 1) ? this.mNewFileName : StringUtils.rename(this.mNewFileName);
            str = rename;
            imageCacheFile = getImageCustomFile(context, rename);
        } else {
            str = "";
        }
        if (imageCacheFile.exists()) {
            return imageCacheFile;
        }
        CompressionPredicate compressionPredicate = this.mCompressionPredicate;
        boolean startsWith = extSuffix.startsWith(PictureMimeType.GIF);
        if (compressionPredicate != null) {
            if (startsWith) {
                return SdkVersionUtils.isQ() ? media.isCut() ? new File(media.getCutPath()) : new File(AndroidQTransformUtils.copyPathToAndroidQ(context, inputStreamProvider.getMedia().getId(), inputStreamProvider.getPath(), media.getWidth(), media.getHeight(), media.getMimeType(), str)) : new File(cutPath);
            }
            boolean needCompressToLocalMedia = checker.needCompressToLocalMedia(this.mLeastCompressSize, cutPath);
            if (this.mCompressionPredicate.apply(cutPath) && needCompressToLocalMedia) {
                engine = new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating);
            } else if (needCompressToLocalMedia) {
                engine = new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating);
            } else if (SdkVersionUtils.isQ()) {
                String cutPath2 = media.isCut() ? media.getCutPath() : AndroidQTransformUtils.copyPathToAndroidQ(context, media.getId(), inputStreamProvider.getPath(), media.getWidth(), media.getHeight(), media.getMimeType(), str);
                if (!TextUtils.isEmpty(cutPath2)) {
                    cutPath = cutPath2;
                }
                return new File(cutPath);
            } else {
                file = new File(cutPath);
                return file;
            }
            file = engine.compress();
            return file;
        } else if (startsWith) {
            if (!SdkVersionUtils.isQ()) {
                return new File(cutPath);
            }
            String cutPath3 = media.isCut() ? media.getCutPath() : AndroidQTransformUtils.copyPathToAndroidQ(context, media.getId(), inputStreamProvider.getPath(), media.getWidth(), media.getHeight(), media.getMimeType(), str);
            if (!TextUtils.isEmpty(cutPath3)) {
                cutPath = cutPath3;
            }
            return new File(cutPath);
        } else if (checker.needCompressToLocalMedia(this.mLeastCompressSize, cutPath)) {
            return new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating).compress();
        } else {
            if (!SdkVersionUtils.isQ()) {
                return new File(cutPath);
            }
            String cutPath4 = media.isCut() ? media.getCutPath() : AndroidQTransformUtils.copyPathToAndroidQ(context, media.getId(), inputStreamProvider.getPath(), media.getWidth(), media.getHeight(), media.getMimeType(), str);
            if (!TextUtils.isEmpty(cutPath4)) {
                cutPath = cutPath4;
            }
            return new File(cutPath);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private File get(InputStreamProvider inputStreamProvider, Context context) {
        try {
            return new Engine(context, inputStreamProvider, getImageCacheFile(context, inputStreamProvider, Checker.SINGLE.extSuffix(inputStreamProvider.getMedia().getMimeType())), this.focusAlpha, this.compressQuality, this.isAutoRotating).compress();
        } finally {
            inputStreamProvider.close();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private List<LocalMedia> get(Context context) {
        ArrayList arrayList = new ArrayList();
        Iterator<InputStreamProvider> it = this.mStreamProviders.iterator();
        while (it.hasNext()) {
            InputStreamProvider next = it.next();
            if (next.getMedia() != null) {
                LocalMedia media = next.getMedia();
                String str = null;
                boolean z4 = false;
                if (media.isCompressed()) {
                    if (!media.isCut() && new File(media.getCompressPath()).exists()) {
                        z4 = true;
                    }
                    String absolutePath = (z4 ? new File(media.getCompressPath()) : compress(context, next)).getAbsolutePath();
                    media.setCompressed(true);
                    media.setCompressPath(absolutePath);
                    if (SdkVersionUtils.isQ()) {
                        str = absolutePath;
                    }
                } else {
                    boolean z5 = PictureMimeType.isHasHttp(media.getPath()) && TextUtils.isEmpty(media.getCutPath());
                    boolean isHasVideo = PictureMimeType.isHasVideo(media.getMimeType());
                    String absolutePath2 = ((z5 || isHasVideo) ? new File(media.getPath()) : compress(context, next)).getAbsolutePath();
                    boolean z6 = !TextUtils.isEmpty(absolutePath2) && PictureMimeType.isHasHttp(absolutePath2);
                    if (!isHasVideo && !z6) {
                        z4 = true;
                    }
                    media.setCompressed(z4);
                    if (isHasVideo || z6) {
                        absolutePath2 = null;
                    }
                    media.setCompressPath(absolutePath2);
                    if (SdkVersionUtils.isQ()) {
                        str = media.getCompressPath();
                    }
                }
                media.setAndroidQToPath(str);
                arrayList.add(media);
                it.remove();
            }
        }
        return arrayList;
    }

    private static File getImageCacheDir(Context context) {
        File externalFilesDir = context.getExternalFilesDir(Environment.DIRECTORY_PICTURES);
        if (externalFilesDir == null) {
            if (Log.isLoggable(TAG, 6)) {
                Log.e(TAG, "default disk cache dir is null");
            }
            return null;
        } else if (externalFilesDir.mkdirs() || (externalFilesDir.exists() && externalFilesDir.isDirectory())) {
            return externalFilesDir;
        } else {
            return null;
        }
    }

    private File getImageCacheFile(Context context, InputStreamProvider inputStreamProvider, String str) {
        String str2;
        File imageCacheDir;
        if (TextUtils.isEmpty(this.mTargetDir) && (imageCacheDir = getImageCacheDir(context)) != null) {
            this.mTargetDir = imageCacheDir.getAbsolutePath();
        }
        try {
            LocalMedia media = inputStreamProvider.getMedia();
            StringBuilder sb = new StringBuilder();
            sb.append(this.mTargetDir);
            if (media.isCut()) {
                String createFileName = DateUtils.getCreateFileName("IMG_CMP_");
                sb.append("/");
                sb.append(createFileName);
                if (TextUtils.isEmpty(str)) {
                    str = PictureMimeType.JPG;
                }
                sb.append(str);
            } else {
                String encryptionValue = StringUtils.getEncryptionValue(media.getId(), media.getWidth(), media.getHeight());
                sb.append("/IMG_CMP_");
                sb.append(encryptionValue);
                if (TextUtils.isEmpty(str)) {
                    str = PictureMimeType.JPG;
                }
                sb.append(str);
            }
            str2 = sb.toString();
        } catch (Exception e5) {
            e5.printStackTrace();
            str2 = "";
        }
        return new File(str2);
    }

    private File getImageCustomFile(Context context, String str) {
        if (TextUtils.isEmpty(this.mTargetDir)) {
            File imageCacheDir = getImageCacheDir(context);
            this.mTargetDir = imageCacheDir != null ? imageCacheDir.getAbsolutePath() : "";
        }
        return new File(this.mTargetDir + "/" + str);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void launch(final Context context) {
        List<InputStreamProvider> list = this.mStreamProviders;
        if (list == null || this.mPaths == null || (list.size() == 0 && this.mCompressListener != null)) {
            this.mCompressListener.onError(new NullPointerException("image file cannot be null"));
            return;
        }
        final Iterator<InputStreamProvider> it = this.mStreamProviders.iterator();
        OnCompressListener onCompressListener = this.mCompressListener;
        if (onCompressListener != null) {
            onCompressListener.onStart();
        }
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<LocalMedia>>() {
            /* class com.luck.picture.lib.compress.Luban.AnonymousClass1 */

            /* JADX WARNING: Removed duplicated region for block: B:42:0x00fb A[Catch:{ Exception -> 0x011f }] */
            /* JADX WARNING: Removed duplicated region for block: B:45:0x0115 A[Catch:{ Exception -> 0x011f }] */
            /* JADX WARNING: Removed duplicated region for block: B:54:0x0118 A[SYNTHETIC] */
            /* JADX WARNING: Removed duplicated region for block: B:58:0x0123 A[SYNTHETIC] */
            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public List<LocalMedia> doInBackground() {
                String str;
                File file;
                Luban.this.index = -1;
                while (true) {
                    String str2 = null;
                    if (!it.hasNext()) {
                        return null;
                    }
                    try {
                        Luban.access$1408(Luban.this);
                        InputStreamProvider inputStreamProvider = (InputStreamProvider) it.next();
                        boolean z4 = false;
                        if (inputStreamProvider.getMedia().isCompressed()) {
                            file = !inputStreamProvider.getMedia().isCut() && new File(inputStreamProvider.getMedia().getCompressPath()).exists() ? new File(inputStreamProvider.getMedia().getCompressPath()) : Luban.this.compress(context, inputStreamProvider);
                        } else if (!PictureMimeType.isHasHttp(inputStreamProvider.getMedia().getPath()) || !TextUtils.isEmpty(inputStreamProvider.getMedia().getCutPath())) {
                            file = PictureMimeType.isHasVideo(inputStreamProvider.getMedia().getMimeType()) ? new File(inputStreamProvider.getPath()) : Luban.this.compress(context, inputStreamProvider);
                        } else {
                            str = inputStreamProvider.getMedia().getPath();
                            if (Luban.this.mediaList != null && Luban.this.mediaList.size() > 0) {
                                LocalMedia localMedia = (LocalMedia) Luban.this.mediaList.get(Luban.this.index);
                                boolean isHasHttp = PictureMimeType.isHasHttp(str);
                                boolean isHasVideo = PictureMimeType.isHasVideo(localMedia.getMimeType());
                                localMedia.setCompressed(isHasHttp && !isHasVideo && !TextUtils.isEmpty(str));
                                if (isHasHttp || isHasVideo) {
                                    str = null;
                                }
                                localMedia.setCompressPath(str);
                                if (SdkVersionUtils.isQ()) {
                                    str2 = localMedia.getCompressPath();
                                }
                                localMedia.setAndroidQToPath(str2);
                                if (Luban.this.index == Luban.this.mediaList.size() - 1) {
                                    z4 = true;
                                }
                                if (!z4) {
                                    return Luban.this.mediaList;
                                }
                            }
                            it.remove();
                        }
                        str = file.getAbsolutePath();
                        LocalMedia localMedia2 = (LocalMedia) Luban.this.mediaList.get(Luban.this.index);
                        boolean isHasHttp2 = PictureMimeType.isHasHttp(str);
                        boolean isHasVideo2 = PictureMimeType.isHasVideo(localMedia2.getMimeType());
                        localMedia2.setCompressed(isHasHttp2 && !isHasVideo2 && !TextUtils.isEmpty(str));
                        str = null;
                        localMedia2.setCompressPath(str);
                        if (SdkVersionUtils.isQ()) {
                        }
                        localMedia2.setAndroidQToPath(str2);
                        if (Luban.this.index == Luban.this.mediaList.size() - 1) {
                        }
                        if (!z4) {
                        }
                    } catch (Exception e5) {
                        e5.printStackTrace();
                    }
                }
            }

            public void onSuccess(List<LocalMedia> list) {
                PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                if (Luban.this.mCompressListener != null) {
                    if (list != null) {
                        Luban.this.mCompressListener.onSuccess(list);
                    } else {
                        Luban.this.mCompressListener.onError(new Throwable("Failed to compress file"));
                    }
                }
            }
        });
    }

    public static Builder with(Context context) {
        return new Builder(context);
    }
}
