package com.luck.picture.lib.io;

import android.content.ContentResolver;
import android.net.Uri;
import android.util.LruCache;
import com.luck.picture.lib.tools.PictureFileUtils;
import java.io.InputStream;
import java.util.HashSet;
import java.util.Iterator;

public class ArrayPoolProvide {
    private static final ArrayPoolProvide mInstance = new ArrayPoolProvide();
    private final LruArrayPool arrayPool = new LruArrayPool(LruArrayPool.DEFAULT_SIZE);
    private final LruCache<String, BufferedInputStreamWrap> bufferedLruCache = new LruCache<>(20);
    private final HashSet<String> keyCache = new HashSet<>();

    public static ArrayPoolProvide getInstance() {
        return mInstance;
    }

    private BufferedInputStreamWrap wrapInputStream(ContentResolver contentResolver, Uri uri) {
        Exception e5;
        BufferedInputStreamWrap bufferedInputStreamWrap = null;
        try {
            BufferedInputStreamWrap bufferedInputStreamWrap2 = new BufferedInputStreamWrap(contentResolver.openInputStream(uri));
            try {
                int available = bufferedInputStreamWrap2.available();
                if (available <= 0) {
                    available = BufferedInputStreamWrap.DEFAULT_MARK_READ_LIMIT;
                }
                bufferedInputStreamWrap2.mark(available);
                this.bufferedLruCache.put(uri.toString(), bufferedInputStreamWrap2);
                this.keyCache.add(uri.toString());
                return bufferedInputStreamWrap2;
            } catch (Exception e6) {
                e5 = e6;
                bufferedInputStreamWrap = bufferedInputStreamWrap2;
                e5.printStackTrace();
                return bufferedInputStreamWrap;
            }
        } catch (Exception e7) {
            e5 = e7;
            e5.printStackTrace();
            return bufferedInputStreamWrap;
        }
    }

    public void clearMemory() {
        Iterator<String> it = this.keyCache.iterator();
        while (it.hasNext()) {
            String next = it.next();
            PictureFileUtils.close(this.bufferedLruCache.get(next));
            this.bufferedLruCache.remove(next);
        }
        this.keyCache.clear();
        this.arrayPool.clearMemory();
    }

    public byte[] get(int i5) {
        return (byte[]) this.arrayPool.get(i5, byte[].class);
    }

    public InputStream openInputStream(ContentResolver contentResolver, Uri uri) {
        try {
            BufferedInputStreamWrap bufferedInputStreamWrap = this.bufferedLruCache.get(uri.toString());
            if (bufferedInputStreamWrap == null) {
                return wrapInputStream(contentResolver, uri);
            }
            bufferedInputStreamWrap.reset();
            return bufferedInputStreamWrap;
        } catch (Exception unused) {
            return wrapInputStream(contentResolver, uri);
        }
    }

    public void put(byte[] bArr) {
        this.arrayPool.put(bArr);
    }
}
