package com.luck.picture.lib.io;

import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;

public class BufferedInputStreamWrap extends FilterInputStream {
    public static final int DEFAULT_MARK_READ_LIMIT = 5242880;
    private volatile byte[] buf;
    private int count;
    private int markLimit;
    private int markPos;
    private int pos;

    /* access modifiers changed from: package-private */
    public static class InvalidMarkException extends IOException {
        private static final long serialVersionUID = -4338378848813561759L;

        InvalidMarkException(String str) {
            super(str);
        }
    }

    public BufferedInputStreamWrap(InputStream inputStream) {
        this(inputStream, 65536);
    }

    BufferedInputStreamWrap(InputStream inputStream, int i5) {
        super(inputStream);
        this.markPos = -1;
        this.buf = ArrayPoolProvide.getInstance().get(i5);
    }

    private int fillbuf(InputStream inputStream, byte[] bArr) {
        int i5;
        int i6 = this.markPos;
        if (i6 == -1 || this.pos - i6 >= (i5 = this.markLimit)) {
            int read = inputStream.read(bArr);
            if (read > 0) {
                this.markPos = -1;
                this.pos = 0;
                this.count = read;
            }
            return read;
        }
        if (i6 == 0 && i5 > bArr.length && this.count == bArr.length) {
            int length = bArr.length * 2;
            if (length <= i5) {
                i5 = length;
            }
            byte[] bArr2 = ArrayPoolProvide.getInstance().get(i5);
            System.arraycopy(bArr, 0, bArr2, 0, bArr.length);
            this.buf = bArr2;
            ArrayPoolProvide.getInstance().put(bArr);
            bArr = bArr2;
        } else if (i6 > 0) {
            System.arraycopy(bArr, i6, bArr, 0, bArr.length - i6);
        }
        int i7 = this.pos - this.markPos;
        this.pos = i7;
        this.markPos = 0;
        this.count = 0;
        int read2 = inputStream.read(bArr, i7, bArr.length - i7);
        int i8 = this.pos;
        if (read2 > 0) {
            i8 += read2;
        }
        this.count = i8;
        return read2;
    }

    private static IOException streamClosed() {
        throw new IOException("BufferedInputStream is closed");
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public synchronized int available() {
        InputStream inputStream = ((FilterInputStream) this).in;
        if (this.buf != null) {
            if (inputStream != null) {
                return (this.count - this.pos) + inputStream.available();
            }
        }
        return 0;
    }

    @Override // java.io.FilterInputStream, java.io.Closeable, java.lang.AutoCloseable, java.io.InputStream
    public void close() {
        if (this.buf != null) {
            ArrayPoolProvide.getInstance().put(this.buf);
            this.buf = null;
        }
        InputStream inputStream = ((FilterInputStream) this).in;
        ((FilterInputStream) this).in = null;
        if (inputStream != null) {
            inputStream.close();
        }
    }

    public synchronized void fixMarkLimit() {
        this.markLimit = this.buf.length;
    }

    public synchronized void mark(int i5) {
        this.markLimit = Math.max(this.markLimit, i5);
        this.markPos = this.pos;
    }

    public boolean markSupported() {
        return true;
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public synchronized int read() {
        byte[] bArr = this.buf;
        InputStream inputStream = ((FilterInputStream) this).in;
        if (bArr == null || inputStream == null) {
            throw streamClosed();
        } else if (this.pos >= this.count && fillbuf(inputStream, bArr) == -1) {
            return -1;
        } else {
            if (bArr == this.buf || (bArr = this.buf) != null) {
                int i5 = this.count;
                int i6 = this.pos;
                if (i5 - i6 <= 0) {
                    return -1;
                }
                this.pos = i6 + 1;
                return bArr[i6] & 255;
            }
            throw streamClosed();
        }
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public synchronized int read(byte[] bArr, int i5, int i6) {
        int i7;
        int i8;
        byte[] bArr2 = this.buf;
        if (bArr2 == null) {
            throw streamClosed();
        } else if (i6 == 0) {
            return 0;
        } else {
            InputStream inputStream = ((FilterInputStream) this).in;
            if (inputStream != null) {
                int i9 = this.pos;
                int i10 = this.count;
                if (i9 < i10) {
                    int min = Math.min(i10 - i9, i6);
                    System.arraycopy(bArr2, this.pos, bArr, i5, min);
                    this.pos += min;
                    if (min == i6 || inputStream.available() == 0) {
                        return min;
                    }
                    i5 += min;
                    i7 = i6 - min;
                } else {
                    i7 = i6;
                }
                while (true) {
                    int i11 = -1;
                    if (this.markPos == -1 && i7 >= bArr2.length) {
                        i8 = inputStream.read(bArr, i5, i7);
                        if (i8 == -1) {
                            if (i7 != i6) {
                                i11 = i6 - i7;
                            }
                            return i11;
                        }
                    } else if (fillbuf(inputStream, bArr2) == -1) {
                        if (i7 != i6) {
                            i11 = i6 - i7;
                        }
                        return i11;
                    } else if (bArr2 == this.buf || (bArr2 = this.buf) != null) {
                        i8 = Math.min(this.count - this.pos, i7);
                        System.arraycopy(bArr2, this.pos, bArr, i5, i8);
                        this.pos += i8;
                    } else {
                        throw streamClosed();
                    }
                    i7 -= i8;
                    if (i7 == 0) {
                        return i6;
                    }
                    if (inputStream.available() == 0) {
                        return i6 - i7;
                    }
                    i5 += i8;
                }
            } else {
                throw streamClosed();
            }
        }
    }

    public synchronized void release() {
        if (this.buf != null) {
            ArrayPoolProvide.getInstance().put(this.buf);
            this.buf = null;
        }
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public synchronized void reset() {
        if (this.buf != null) {
            int i5 = this.markPos;
            if (-1 != i5) {
                this.pos = i5;
            } else {
                throw new InvalidMarkException("Mark has been invalidated, pos: " + this.pos + " markLimit: " + this.markLimit);
            }
        } else {
            throw new IOException("Stream is closed");
        }
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public synchronized long skip(long j5) {
        if (j5 < 1) {
            return 0;
        }
        byte[] bArr = this.buf;
        if (bArr != null) {
            InputStream inputStream = ((FilterInputStream) this).in;
            if (inputStream != null) {
                int i5 = this.count;
                int i6 = this.pos;
                if (((long) (i5 - i6)) >= j5) {
                    this.pos = (int) (((long) i6) + j5);
                    return j5;
                }
                long j6 = ((long) i5) - ((long) i6);
                this.pos = i5;
                if (this.markPos == -1 || j5 > ((long) this.markLimit)) {
                    return j6 + inputStream.skip(j5 - j6);
                } else if (fillbuf(inputStream, bArr) == -1) {
                    return j6;
                } else {
                    int i7 = this.count;
                    int i8 = this.pos;
                    if (((long) (i7 - i8)) >= j5 - j6) {
                        this.pos = (int) ((((long) i8) + j5) - j6);
                        return j5;
                    }
                    long j7 = (j6 + ((long) i7)) - ((long) i8);
                    this.pos = i7;
                    return j7;
                }
            } else {
                throw streamClosed();
            }
        } else {
            throw streamClosed();
        }
    }
}
