package com.luck.picture.lib.model;

import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.provider.MediaStore;
import android.text.TextUtils;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.listener.OnQueryDataResultListener;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.SortUtils;
import com.yalantis.ucrop.view.CropImageView;
import java.io.File;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;

@Deprecated
public final class LocalMediaLoader extends IBridgeMediaLoader {
    private static final long FILE_SIZE_UNIT = 1048576;
    private static final int MAX_SORT_SIZE = 60;
    private static final String NOT_GIF = " AND (mime_type!='image/gif' AND mime_type!='image/*')";
    private static final String NOT_GIF_UNKNOWN = "!='image/*'";
    private static final String ORDER_BY = "_id DESC";
    private static final String[] PROJECTION = {"_id", "_data", "mime_type", "width", "height", "duration", "_size", "bucket_display_name", "_display_name", PictureConfig.EXTRA_BUCKET_ID, "date_added"};
    private static final Uri QUERY_URI = MediaStore.Files.getContentUri("external");
    private static final String TAG = "LocalMediaLoader";
    private final PictureSelectionConfig config;
    private final boolean isAndroidQ = SdkVersionUtils.isQ();
    private final Context mContext;

    public LocalMediaLoader(Context context, PictureSelectionConfig pictureSelectionConfig) {
        this.mContext = context.getApplicationContext();
        this.config = pictureSelectionConfig;
    }

    private String getDurationCondition() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        int i5 = pictureSelectionConfig.videoMaxSecond;
        long j5 = i5 == 0 ? Long.MAX_VALUE : (long) i5;
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(0L, (long) pictureSelectionConfig.videoMinSecond));
        objArr[1] = Math.max(0, (long) this.config.videoMinSecond) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j5);
        return String.format(locale, "%d <%s duration and duration <= %d", objArr);
    }

    private String getFileSizeCondition() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        long j5 = pictureSelectionConfig.filterMaxFileSize;
        if (j5 == 0) {
            j5 = Long.MAX_VALUE;
        }
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(0L, pictureSelectionConfig.filterMinFileSize));
        objArr[1] = Math.max(0, this.config.filterMinFileSize) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j5);
        return String.format(locale, "%d <%s _size and _size <= %d", objArr);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private LocalMediaFolder getImageFolder(String str, String str2, String str3, List<LocalMediaFolder> list) {
        LocalMediaFolder localMediaFolder;
        if (!this.config.isFallbackVersion) {
            for (LocalMediaFolder localMediaFolder2 : list) {
                String name = localMediaFolder2.getName();
                if (!TextUtils.isEmpty(name) && name.equals(str3)) {
                    return localMediaFolder2;
                }
            }
            localMediaFolder = new LocalMediaFolder();
        } else {
            File parentFile = new File(str).getParentFile();
            for (LocalMediaFolder localMediaFolder3 : list) {
                String name2 = localMediaFolder3.getName();
                if (!TextUtils.isEmpty(name2) && parentFile != null && name2.equals(parentFile.getName())) {
                    return localMediaFolder3;
                }
            }
            localMediaFolder = new LocalMediaFolder();
            str3 = parentFile != null ? parentFile.getName() : "";
        }
        localMediaFolder.setName(str3);
        localMediaFolder.setFirstImagePath(str);
        localMediaFolder.setFirstMimeType(str2);
        list.add(localMediaFolder);
        return localMediaFolder;
    }

    private String getQueryMimeCondition() {
        HashSet<String> hashSet = this.config.queryMimeTypeHashSet;
        if (hashSet == null) {
            hashSet = new HashSet<>();
        }
        if (!TextUtils.isEmpty(this.config.specifiedFormat)) {
            hashSet.add(this.config.specifiedFormat);
        }
        StringBuilder sb = new StringBuilder();
        Iterator<String> it = hashSet.iterator();
        int i5 = -1;
        while (it.hasNext()) {
            String next = it.next();
            if (!TextUtils.isEmpty(next) && (this.config.chooseMode != PictureMimeType.ofVideo() ? this.config.chooseMode != PictureMimeType.ofImage() ? this.config.chooseMode != PictureMimeType.ofAudio() || (!next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_VIDEO) && !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE)) : !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_AUDIO) && !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_VIDEO) : !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE) && !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_AUDIO))) {
                i5++;
                sb.append(i5 == 0 ? " AND " : " OR ");
                sb.append("mime_type");
                sb.append("='");
                sb.append(next);
                sb.append("'");
            }
        }
        if (this.config.chooseMode != PictureMimeType.ofVideo() && !this.config.isGif && !hashSet.contains(PictureMimeType.ofGIF())) {
            sb.append(NOT_GIF);
        }
        return sb.toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getSelection() {
        String durationCondition = getDurationCondition();
        String fileSizeCondition = getFileSizeCondition();
        String queryMimeCondition = getQueryMimeCondition();
        int i5 = this.config.chooseMode;
        if (i5 == 0) {
            return getSelectionArgsForAllMediaCondition(durationCondition, fileSizeCondition, queryMimeCondition);
        }
        if (i5 == 1) {
            return getSelectionArgsForImageMediaCondition(fileSizeCondition, queryMimeCondition);
        }
        if (i5 == 2) {
            return getSelectionArgsForVideoOrAudioMediaCondition(fileSizeCondition, queryMimeCondition);
        }
        if (i5 != 3) {
            return null;
        }
        return getSelectionArgsForVideoOrAudioMediaCondition(durationCondition, queryMimeCondition);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String[] getSelectionArgs() {
        int i5 = this.config.chooseMode;
        if (i5 == 0) {
            return getSelectionArgsForAllMediaType();
        }
        if (i5 == 1) {
            return getSelectionArgsForSingleMediaType(1);
        }
        if (i5 == 2) {
            return getSelectionArgsForSingleMediaType(3);
        }
        if (i5 != 3) {
            return null;
        }
        return getSelectionArgsForSingleMediaType(2);
    }

    private static String getSelectionArgsForAllMediaCondition(String str, String str2, String str3) {
        return "(" + "media_type" + "=?" + str3 + " OR " + "media_type" + "=? AND " + str + ") AND " + str2;
    }

    private static String[] getSelectionArgsForAllMediaType() {
        return new String[]{String.valueOf(1), String.valueOf(3)};
    }

    private static String getSelectionArgsForImageMediaCondition(String str, String str2) {
        return "media_type=?" + str2 + " AND " + str;
    }

    private static String[] getSelectionArgsForSingleMediaType(int i5) {
        return new String[]{String.valueOf(i5)};
    }

    private static String getSelectionArgsForVideoOrAudioMediaCondition(String str, String str2) {
        return "media_type=?" + str2 + " AND " + str;
    }

    @Override // com.luck.picture.lib.model.IBridgeMediaLoader
    public void loadAllMedia(final OnQueryDataResultListener<LocalMediaFolder> onQueryDataResultListener) {
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<LocalMediaFolder>>() {
            /* class com.luck.picture.lib.model.LocalMediaLoader.AnonymousClass2 */

            /* JADX WARNING: Code restructure failed: missing block: B:85:0x030f, code lost:
                if (r3.isClosed() != false) goto L_0x0327;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:92:0x0322, code lost:
                if (r3.isClosed() == false) goto L_0x0324;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:93:0x0324, code lost:
                r3.close();
             */
            /* JADX WARNING: Removed duplicated region for block: B:79:0x02f0 A[LOOP:0: B:6:0x00c0->B:79:0x02f0, LOOP_END] */
            /* JADX WARNING: Removed duplicated region for block: B:95:0x023f A[EDGE_INSN: B:95:0x023f->B:63:0x023f ?: BREAK  , SYNTHETIC] */
            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public List<LocalMediaFolder> doInBackground() {
                int i5;
                String str;
                int i6;
                int i7;
                int i8;
                int i9;
                int i10;
                int i11;
                ArrayList arrayList;
                Context context;
                int i12;
                String str2;
                ArrayList arrayList2 = new ArrayList();
                Cursor query = LocalMediaLoader.this.mContext.getContentResolver().query(LocalMediaLoader.QUERY_URI, LocalMediaLoader.PROJECTION, LocalMediaLoader.this.getSelection(), LocalMediaLoader.this.getSelectionArgs(), LocalMediaLoader.ORDER_BY);
                if (query != null) {
                    try {
                        LocalMediaFolder localMediaFolder = new LocalMediaFolder();
                        ArrayList arrayList3 = new ArrayList();
                        if (query.getCount() > 0) {
                            int columnIndexOrThrow = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[0]);
                            int columnIndexOrThrow2 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[1]);
                            int columnIndexOrThrow3 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[2]);
                            int columnIndexOrThrow4 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[3]);
                            int columnIndexOrThrow5 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[4]);
                            int columnIndexOrThrow6 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[5]);
                            int columnIndexOrThrow7 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[6]);
                            int columnIndexOrThrow8 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[7]);
                            int columnIndexOrThrow9 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[8]);
                            int columnIndexOrThrow10 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[9]);
                            int columnIndexOrThrow11 = query.getColumnIndexOrThrow(LocalMediaLoader.PROJECTION[10]);
                            query.moveToFirst();
                            int i13 = columnIndexOrThrow8;
                            int i14 = columnIndexOrThrow9;
                            while (true) {
                                long j5 = query.getLong(columnIndexOrThrow);
                                String string = query.getString(columnIndexOrThrow3);
                                if (TextUtils.isEmpty(string)) {
                                    string = PictureMimeType.ofJPEG();
                                }
                                String str3 = string;
                                String string2 = query.getString(columnIndexOrThrow2);
                                if (LocalMediaLoader.this.isAndroidQ) {
                                    str = PictureMimeType.getRealPathUri(j5, str3);
                                    i5 = columnIndexOrThrow3;
                                } else {
                                    i5 = columnIndexOrThrow3;
                                    str = string2;
                                }
                                if (str3.endsWith("image/*")) {
                                    str3 = PictureMimeType.isContent(str) ? PictureMimeType.getImageMimeType(string2) : PictureMimeType.getImageMimeType(str);
                                    if (!LocalMediaLoader.this.config.isGif && PictureMimeType.isGif(str3)) {
                                        i9 = columnIndexOrThrow4;
                                        i8 = columnIndexOrThrow5;
                                        i7 = i13;
                                        i6 = i14;
                                        arrayList = arrayList3;
                                        i10 = columnIndexOrThrow10;
                                        i11 = columnIndexOrThrow6;
                                        if (!query.moveToNext()) {
                                            break;
                                        }
                                        arrayList3 = arrayList;
                                        columnIndexOrThrow6 = i11;
                                        columnIndexOrThrow10 = i10;
                                        columnIndexOrThrow = columnIndexOrThrow;
                                        columnIndexOrThrow2 = columnIndexOrThrow2;
                                        columnIndexOrThrow3 = i5;
                                        columnIndexOrThrow4 = i9;
                                        columnIndexOrThrow5 = i8;
                                        i13 = i7;
                                        i14 = i6;
                                    }
                                }
                                if (LocalMediaLoader.this.config.isWebp || !str3.startsWith(PictureMimeType.ofWEBP())) {
                                    if (LocalMediaLoader.this.config.isBmp || !str3.startsWith(PictureMimeType.ofBMP())) {
                                        int i15 = query.getInt(columnIndexOrThrow4);
                                        int i16 = query.getInt(columnIndexOrThrow5);
                                        long j6 = query.getLong(columnIndexOrThrow6);
                                        i9 = columnIndexOrThrow4;
                                        long j7 = query.getLong(columnIndexOrThrow7);
                                        i8 = columnIndexOrThrow5;
                                        i11 = columnIndexOrThrow6;
                                        String string3 = query.getString(i13);
                                        i7 = i13;
                                        String string4 = query.getString(i14);
                                        long j8 = query.getLong(columnIndexOrThrow10);
                                        i10 = columnIndexOrThrow10;
                                        if (LocalMediaLoader.this.config.filterFileSize > CropImageView.DEFAULT_ASPECT_RATIO) {
                                            i6 = i14;
                                            if (((float) j7) > LocalMediaLoader.this.config.filterFileSize * 1048576.0f) {
                                                arrayList = arrayList3;
                                                if (!query.moveToNext()) {
                                                }
                                            }
                                        } else {
                                            i6 = i14;
                                        }
                                        if (PictureMimeType.isHasVideo(str3)) {
                                            if (LocalMediaLoader.this.config.videoMinSecond > 0) {
                                                arrayList = arrayList3;
                                                str2 = str3;
                                                if (j6 < ((long) LocalMediaLoader.this.config.videoMinSecond)) {
                                                    if (!query.moveToNext()) {
                                                    }
                                                }
                                            } else {
                                                arrayList = arrayList3;
                                                str2 = str3;
                                            }
                                            if (LocalMediaLoader.this.config.videoMaxSecond <= 0 || j6 <= ((long) LocalMediaLoader.this.config.videoMaxSecond)) {
                                                if (j6 != 0) {
                                                    if (j7 <= 0) {
                                                    }
                                                }
                                                if (!query.moveToNext()) {
                                                }
                                            } else if (!query.moveToNext()) {
                                            }
                                        } else {
                                            arrayList = arrayList3;
                                            str2 = str3;
                                        }
                                        LocalMedia parseLocalMedia = LocalMedia.parseLocalMedia(j5, str, string2, string4, string3, j6, LocalMediaLoader.this.config.chooseMode, str2, i15, i16, j7, j8, query.getLong(columnIndexOrThrow11));
                                        LocalMediaFolder imageFolder = LocalMediaLoader.this.getImageFolder(str, str2, string3, arrayList2);
                                        imageFolder.setBucketId(parseLocalMedia.getBucketId());
                                        imageFolder.getData().add(parseLocalMedia);
                                        imageFolder.setImageNum(imageFolder.getImageNum() + 1);
                                        imageFolder.setBucketId(parseLocalMedia.getBucketId());
                                        arrayList.add(parseLocalMedia);
                                        localMediaFolder.setImageNum(localMediaFolder.getImageNum() + 1);
                                        if (!query.moveToNext()) {
                                        }
                                    }
                                }
                                i9 = columnIndexOrThrow4;
                                i8 = columnIndexOrThrow5;
                                i7 = i13;
                                i6 = i14;
                                arrayList = arrayList3;
                                i10 = columnIndexOrThrow10;
                                i11 = columnIndexOrThrow6;
                                if (!query.moveToNext()) {
                                }
                            }
                            LocalMediaFolder loadInAppSandboxFolderFile = SandboxFileLoader.loadInAppSandboxFolderFile(LocalMediaLoader.this.mContext, LocalMediaLoader.this.config.sandboxFolderPath);
                            if (loadInAppSandboxFolderFile != null) {
                                arrayList2.add(loadInAppSandboxFolderFile);
                                localMediaFolder.setImageNum(localMediaFolder.getImageNum() + loadInAppSandboxFolderFile.getImageNum());
                                localMediaFolder.setData(loadInAppSandboxFolderFile.getData());
                                arrayList.addAll(0, loadInAppSandboxFolderFile.getData());
                                if (60 > loadInAppSandboxFolderFile.getImageNum()) {
                                    if (arrayList.size() > 60) {
                                        SortUtils.sortLocalMediaAddedTime(arrayList.subList(0, 60));
                                    } else {
                                        SortUtils.sortLocalMediaAddedTime(arrayList);
                                    }
                                }
                            }
                            if (arrayList.size() > 0) {
                                SortUtils.sortFolder(arrayList2);
                                arrayList2.add(0, localMediaFolder);
                                localMediaFolder.setFirstImagePath(arrayList.get(0).getPath());
                                localMediaFolder.setFirstMimeType(arrayList.get(0).getMimeType());
                                if (LocalMediaLoader.this.config.chooseMode == PictureMimeType.ofAudio()) {
                                    context = LocalMediaLoader.this.mContext;
                                    i12 = R.string.picture_all_audio;
                                } else {
                                    context = LocalMediaLoader.this.mContext;
                                    i12 = R.string.picture_camera_roll;
                                }
                                localMediaFolder.setName(context.getString(i12));
                                localMediaFolder.setBucketId(-1);
                                localMediaFolder.setOfAllType(LocalMediaLoader.this.config.chooseMode);
                                localMediaFolder.setCameraFolder(true);
                                localMediaFolder.setData(arrayList);
                            }
                        }
                    } catch (Exception e5) {
                        e5.printStackTrace();
                    } catch (Throwable th) {
                        if (!query.isClosed()) {
                            query.close();
                        }
                        throw th;
                    }
                }
                if (query != null) {
                }
                return arrayList2;
            }

            public void onSuccess(List<LocalMediaFolder> list) {
                PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                OnQueryDataResultListener onQueryDataResultListener = onQueryDataResultListener;
                if (onQueryDataResultListener != null) {
                    onQueryDataResultListener.onComplete((List) list);
                }
            }
        });
    }

    @Override // com.luck.picture.lib.model.IBridgeMediaLoader
    public void loadOnlyInAppDirectoryAllMedia(final OnQueryDataResultListener<LocalMediaFolder> onQueryDataResultListener) {
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<LocalMediaFolder>() {
            /* class com.luck.picture.lib.model.LocalMediaLoader.AnonymousClass1 */

            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public LocalMediaFolder doInBackground() {
                return SandboxFileLoader.loadInAppSandboxFolderFile(LocalMediaLoader.this.mContext, LocalMediaLoader.this.config.sandboxFolderPath);
            }

            public void onSuccess(LocalMediaFolder localMediaFolder) {
                PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                OnQueryDataResultListener onQueryDataResultListener = onQueryDataResultListener;
                if (onQueryDataResultListener != null) {
                    onQueryDataResultListener.onComplete(localMediaFolder);
                }
            }
        });
    }
}
