package com.luck.picture.lib.model;

import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.Log;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.entity.MediaData;
import com.luck.picture.lib.listener.OnQueryDataResultListener;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.SortUtils;
import com.luck.picture.lib.tools.ValueOf;
import com.yalantis.ucrop.view.CropImageView;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;

public final class LocalMediaPageLoader extends IBridgeMediaLoader {
    private static final String COLUMN_BUCKET_DISPLAY_NAME = "bucket_display_name";
    private static final String COLUMN_BUCKET_ID = "bucket_id";
    private static final String COLUMN_COUNT = "count";
    private static final long FILE_SIZE_UNIT = 1048576;
    private static final String GROUP_BY_BUCKET_Id = " GROUP BY (bucket_id";
    private static final String NOT_GIF = " AND (mime_type!='image/gif' AND mime_type!='image/*')";
    private static final String NOT_GIF_UNKNOWN = "!='image/*'";
    private static final String ORDER_BY = "_id DESC";
    private static final String[] PROJECTION = {"_id", "_data", "bucket_id", COLUMN_BUCKET_DISPLAY_NAME, "mime_type", "COUNT(*) AS count"};
    private static final String[] PROJECTION_29 = {"_id", "bucket_id", COLUMN_BUCKET_DISPLAY_NAME, "mime_type"};
    private static final String[] PROJECTION_PAGE = {"_id", "_data", "mime_type", "width", "height", "duration", "_size", COLUMN_BUCKET_DISPLAY_NAME, "_display_name", "bucket_id", "date_added"};
    private static final Uri QUERY_URI = MediaStore.Files.getContentUri("external");
    private static final String TAG = "LocalMediaPageLoader";
    private final PictureSelectionConfig config;
    private final Context mContext;

    public LocalMediaPageLoader(Context context, PictureSelectionConfig pictureSelectionConfig) {
        this.mContext = context;
        this.config = pictureSelectionConfig;
    }

    private String getDurationCondition() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        int i5 = pictureSelectionConfig.videoMaxSecond;
        long j5 = i5 == 0 ? Long.MAX_VALUE : (long) i5;
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(0L, (long) pictureSelectionConfig.videoMinSecond));
        objArr[1] = Math.max(0, (long) this.config.videoMinSecond) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j5);
        return String.format(locale, "%d <%s duration and duration <= %d", objArr);
    }

    private String getFileSizeCondition() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        long j5 = pictureSelectionConfig.filterMaxFileSize;
        if (j5 == 0) {
            j5 = Long.MAX_VALUE;
        }
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(0L, pictureSelectionConfig.filterMinFileSize));
        objArr[1] = Math.max(0, this.config.filterMinFileSize) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j5);
        return String.format(locale, "%d <%s _size and _size <= %d", objArr);
    }

    /* access modifiers changed from: private */
    public static String getFirstCoverMimeType(Cursor cursor) {
        return cursor.getString(cursor.getColumnIndex("mime_type"));
    }

    /* access modifiers changed from: private */
    public static String getFirstUri(Cursor cursor) {
        return PictureMimeType.getRealPathUri(cursor.getLong(cursor.getColumnIndex("_id")), cursor.getString(cursor.getColumnIndex("mime_type")));
    }

    /* access modifiers changed from: private */
    public static String getFirstUrl(Cursor cursor) {
        return cursor.getString(cursor.getColumnIndex("_data"));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getPageSelection(long j5) {
        String durationCondition = getDurationCondition();
        String fileSizeCondition = getFileSizeCondition();
        String queryMimeCondition = getQueryMimeCondition();
        int i5 = this.config.chooseMode;
        if (i5 == 0) {
            return getPageSelectionArgsForAllMediaCondition(j5, queryMimeCondition, durationCondition, fileSizeCondition);
        }
        if (i5 == 1) {
            return getPageSelectionArgsForImageMediaCondition(j5, queryMimeCondition, fileSizeCondition);
        }
        if (i5 == 2 || i5 == 3) {
            return getPageSelectionArgsForVideoOrAudioMediaCondition(j5, queryMimeCondition, durationCondition, fileSizeCondition);
        }
        return null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String[] getPageSelectionArgs(long j5) {
        int i5 = this.config.chooseMode;
        if (i5 != 0) {
            if (i5 == 1) {
                return getSelectionArgsForPageSingleMediaType(1, j5);
            }
            if (i5 == 2) {
                return getSelectionArgsForPageSingleMediaType(3, j5);
            }
            if (i5 != 3) {
                return null;
            }
            return getSelectionArgsForPageSingleMediaType(2, j5);
        } else if (j5 == -1) {
            return new String[]{String.valueOf(1), String.valueOf(3)};
        } else {
            return new String[]{String.valueOf(1), String.valueOf(3), ValueOf.toString(Long.valueOf(j5))};
        }
    }

    private static String getPageSelectionArgsForAllMediaCondition(long j5, String str, String str2, String str3) {
        StringBuilder sb = new StringBuilder();
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        sb.append(str);
        sb.append(" OR ");
        sb.append("media_type");
        sb.append("=? AND ");
        sb.append(str2);
        sb.append(") AND ");
        if (j5 != -1) {
            sb.append("bucket_id");
            sb.append("=? AND ");
        }
        sb.append(str3);
        return sb.toString();
    }

    private static String getPageSelectionArgsForImageMediaCondition(long j5, String str, String str2) {
        StringBuilder sb = new StringBuilder();
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        int i5 = (j5 > -1 ? 1 : (j5 == -1 ? 0 : -1));
        sb.append(str);
        sb.append(") AND ");
        if (i5 != 0) {
            sb.append("bucket_id");
            sb.append("=? AND ");
        }
        sb.append(str2);
        return sb.toString();
    }

    private static String getPageSelectionArgsForVideoOrAudioMediaCondition(long j5, String str, String str2, String str3) {
        StringBuilder sb = new StringBuilder();
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        sb.append(str);
        sb.append(" AND ");
        sb.append(str2);
        sb.append(") AND ");
        if (j5 != -1) {
            sb.append("bucket_id");
            sb.append("=? AND ");
        }
        sb.append(str3);
        return sb.toString();
    }

    private String getQueryMimeCondition() {
        HashSet<String> hashSet = this.config.queryMimeTypeHashSet;
        if (hashSet == null) {
            hashSet = new HashSet<>();
        }
        if (!TextUtils.isEmpty(this.config.specifiedFormat)) {
            hashSet.add(this.config.specifiedFormat);
        }
        StringBuilder sb = new StringBuilder();
        Iterator<String> it = hashSet.iterator();
        int i5 = -1;
        while (it.hasNext()) {
            String next = it.next();
            if (!TextUtils.isEmpty(next) && (this.config.chooseMode != PictureMimeType.ofVideo() ? this.config.chooseMode != PictureMimeType.ofImage() ? this.config.chooseMode != PictureMimeType.ofAudio() || (!next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_VIDEO) && !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE)) : !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_AUDIO) && !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_VIDEO) : !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE) && !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_AUDIO))) {
                i5++;
                sb.append(i5 == 0 ? " AND " : " OR ");
                sb.append("mime_type");
                sb.append("='");
                sb.append(next);
                sb.append("'");
            }
        }
        if (this.config.chooseMode != PictureMimeType.ofVideo() && !this.config.isGif && !hashSet.contains(PictureMimeType.ofGIF())) {
            sb.append(NOT_GIF);
        }
        return sb.toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getSelection() {
        String fileSizeCondition = getFileSizeCondition();
        String queryMimeCondition = getQueryMimeCondition();
        int i5 = this.config.chooseMode;
        if (i5 == 0) {
            return getSelectionArgsForAllMediaCondition(getDurationCondition(), fileSizeCondition, queryMimeCondition);
        }
        if (i5 == 1) {
            return getSelectionArgsForImageMediaCondition(queryMimeCondition, fileSizeCondition);
        }
        if (i5 == 2 || i5 == 3) {
            return getSelectionArgsForVideoOrAudioMediaCondition(queryMimeCondition, fileSizeCondition);
        }
        return null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String[] getSelectionArgs() {
        int i5 = this.config.chooseMode;
        if (i5 == 0) {
            return getSelectionArgsForAllMediaType();
        }
        if (i5 == 1) {
            return getSelectionArgsForSingleMediaType(1);
        }
        if (i5 == 2) {
            return getSelectionArgsForSingleMediaType(3);
        }
        if (i5 != 3) {
            return null;
        }
        return getSelectionArgsForSingleMediaType(2);
    }

    private static String getSelectionArgsForAllMediaCondition(String str, String str2, String str3) {
        StringBuilder sb = new StringBuilder();
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        sb.append(str3);
        sb.append(" OR ");
        sb.append("media_type");
        sb.append("=? AND ");
        sb.append(str);
        sb.append(") AND ");
        sb.append(str2);
        if (SdkVersionUtils.isQ()) {
            return sb.toString();
        }
        sb.append(")");
        sb.append(GROUP_BY_BUCKET_Id);
        return sb.toString();
    }

    private static String[] getSelectionArgsForAllMediaType() {
        return new String[]{String.valueOf(1), String.valueOf(3)};
    }

    private static String getSelectionArgsForImageMediaCondition(String str, String str2) {
        StringBuilder sb = new StringBuilder();
        if (SdkVersionUtils.isQ()) {
            sb.append("media_type");
            sb.append("=?");
            sb.append(str);
            sb.append(" AND ");
            sb.append(str2);
        } else {
            sb.append("(");
            sb.append("media_type");
            sb.append("=?");
            sb.append(str);
            sb.append(") AND ");
            sb.append(str2);
            sb.append(")");
            sb.append(GROUP_BY_BUCKET_Id);
        }
        return sb.toString();
    }

    private static String[] getSelectionArgsForPageSingleMediaType(int i5, long j5) {
        if (j5 == -1) {
            return new String[]{String.valueOf(i5)};
        }
        return new String[]{String.valueOf(i5), ValueOf.toString(Long.valueOf(j5))};
    }

    private static String[] getSelectionArgsForSingleMediaType(int i5) {
        return new String[]{String.valueOf(i5)};
    }

    private static String getSelectionArgsForVideoOrAudioMediaCondition(String str, String str2) {
        StringBuilder sb = new StringBuilder();
        if (SdkVersionUtils.isQ()) {
            sb.append("media_type");
            sb.append("=?");
            sb.append(str);
            sb.append(" AND ");
            sb.append(str2);
        } else {
            sb.append("(");
            sb.append("media_type");
            sb.append("=?");
            sb.append(str);
            sb.append(") AND ");
            sb.append(str2);
            sb.append(")");
            sb.append(GROUP_BY_BUCKET_Id);
        }
        return sb.toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void synchronousFirstCover(List<LocalMediaFolder> list) {
        for (int i5 = 0; i5 < list.size(); i5++) {
            LocalMediaFolder localMediaFolder = list.get(i5);
            if (localMediaFolder != null) {
                String firstCover = getFirstCover(localMediaFolder.getBucketId());
                if (!TextUtils.isEmpty(firstCover)) {
                    localMediaFolder.setFirstImagePath(firstCover);
                }
            }
        }
    }

    @Override // com.luck.picture.lib.model.IBridgeMediaLoader
    public String getFirstCover(long j5) {
        Throwable th;
        Cursor cursor;
        Exception e5;
        Cursor cursor2 = null;
        try {
            Cursor query = SdkVersionUtils.isR() ? this.mContext.getContentResolver().query(QUERY_URI, new String[]{"_id", "mime_type", "_data"}, MediaUtils.createQueryArgsBundle(getPageSelection(j5), getPageSelectionArgs(j5), 1, 0), null) : this.mContext.getContentResolver().query(QUERY_URI, new String[]{"_id", "mime_type", "_data"}, getPageSelection(j5), getPageSelectionArgs(j5), "_id DESC limit 1 offset 0");
            if (query != null) {
                try {
                    if (query.getCount() > 0) {
                        if (query.moveToFirst()) {
                            String realPathUri = SdkVersionUtils.isQ() ? PictureMimeType.getRealPathUri(query.getLong(query.getColumnIndexOrThrow("_id")), query.getString(query.getColumnIndexOrThrow("mime_type"))) : query.getString(query.getColumnIndexOrThrow("_data"));
                            if (!query.isClosed()) {
                                query.close();
                            }
                            return realPathUri;
                        }
                        if (!query.isClosed()) {
                            query.close();
                        }
                        return null;
                    }
                } catch (Exception e6) {
                    cursor = query;
                    e5 = e6;
                    try {
                        e5.printStackTrace();
                        if (cursor != null && !cursor.isClosed()) {
                            cursor.close();
                        }
                        return null;
                    } catch (Throwable th2) {
                        th = th2;
                        cursor2 = cursor;
                        if (cursor2 != null && !cursor2.isClosed()) {
                            cursor2.close();
                        }
                        throw th;
                    }
                } catch (Throwable th3) {
                    cursor2 = query;
                    th = th3;
                    cursor2.close();
                    throw th;
                }
            }
            if (query != null && !query.isClosed()) {
                query.close();
            }
        } catch (Exception e7) {
            e5 = e7;
            cursor = null;
            e5.printStackTrace();
            cursor.close();
            return null;
        } catch (Throwable th4) {
            th = th4;
            cursor2.close();
            throw th;
        }
        return null;
    }

    @Override // com.luck.picture.lib.model.IBridgeMediaLoader
    public void loadAllMedia(final OnQueryDataResultListener<LocalMediaFolder> onQueryDataResultListener) {
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<LocalMediaFolder>>() {
            /* class com.luck.picture.lib.model.LocalMediaPageLoader.AnonymousClass3 */

            /* JADX WARNING: Code restructure failed: missing block: B:71:0x024e, code lost:
                if (r2.isClosed() == false) goto L_0x0263;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:78:0x0261, code lost:
                if (r2.isClosed() == false) goto L_0x0263;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:79:0x0263, code lost:
                r2.close();
             */
            /* JADX WARNING: Removed duplicated region for block: B:49:0x01ca  */
            /* JADX WARNING: Removed duplicated region for block: B:51:0x01d7  */
            /* JADX WARNING: Removed duplicated region for block: B:59:0x0218  */
            /* JADX WARNING: Removed duplicated region for block: B:74:0x0257  */
            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public List<LocalMediaFolder> doInBackground() {
                Throwable th;
                Exception e5;
                int i5;
                Context context;
                int i6;
                String firstCoverMimeType;
                HashMap hashMap;
                Cursor query = LocalMediaPageLoader.this.mContext.getContentResolver().query(LocalMediaPageLoader.QUERY_URI, SdkVersionUtils.isQ() ? LocalMediaPageLoader.PROJECTION_29 : LocalMediaPageLoader.PROJECTION, LocalMediaPageLoader.this.getSelection(), LocalMediaPageLoader.this.getSelectionArgs(), LocalMediaPageLoader.ORDER_BY);
                if (query != null) {
                    try {
                        int count = query.getCount();
                        ArrayList arrayList = new ArrayList();
                        if (count > 0) {
                            if (SdkVersionUtils.isQ()) {
                                try {
                                    HashMap hashMap2 = new HashMap();
                                    while (query.moveToNext()) {
                                        long j5 = query.getLong(query.getColumnIndex("bucket_id"));
                                        Long l5 = (Long) hashMap2.get(Long.valueOf(j5));
                                        hashMap2.put(Long.valueOf(j5), l5 == null ? 1L : Long.valueOf(l5.longValue() + 1));
                                    }
                                    if (query.moveToFirst()) {
                                        HashSet hashSet = new HashSet();
                                        i5 = 0;
                                        while (true) {
                                            long j6 = query.getLong(query.getColumnIndex("bucket_id"));
                                            if (hashSet.contains(Long.valueOf(j6))) {
                                                hashMap = hashMap2;
                                            } else {
                                                LocalMediaFolder localMediaFolder = new LocalMediaFolder();
                                                localMediaFolder.setBucketId(j6);
                                                String string = query.getString(query.getColumnIndex(LocalMediaPageLoader.COLUMN_BUCKET_DISPLAY_NAME));
                                                String string2 = query.getString(query.getColumnIndex("mime_type"));
                                                long longValue = ((Long) hashMap2.get(Long.valueOf(j6))).longValue();
                                                hashMap = hashMap2;
                                                long j7 = query.getLong(query.getColumnIndex("_id"));
                                                localMediaFolder.setName(string);
                                                localMediaFolder.setImageNum(ValueOf.toInt(Long.valueOf(longValue)));
                                                localMediaFolder.setFirstImagePath(PictureMimeType.getRealPathUri(j7, string2));
                                                localMediaFolder.setFirstMimeType(string2);
                                                arrayList.add(localMediaFolder);
                                                hashSet.add(Long.valueOf(j6));
                                                i5 = (int) (((long) i5) + longValue);
                                            }
                                            if (!query.moveToNext()) {
                                                break;
                                            }
                                            hashMap2 = hashMap;
                                        }
                                    } else {
                                        i5 = 0;
                                    }
                                } catch (Exception e6) {
                                    e5 = e6;
                                    try {
                                        e5.printStackTrace();
                                        String str = LocalMediaPageLoader.TAG;
                                        Log.i(str, "loadAllMedia Data Error: " + e5.getMessage());
                                    } catch (Throwable th2) {
                                        th = th2;
                                        if (!query.isClosed()) {
                                            query.close();
                                        }
                                        throw th;
                                    }
                                } catch (Throwable th3) {
                                    th = th3;
                                    if (!query.isClosed()) {
                                    }
                                    throw th;
                                }
                            } else {
                                query.moveToFirst();
                                int i7 = 0;
                                while (true) {
                                    LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
                                    long j8 = query.getLong(query.getColumnIndex("bucket_id"));
                                    String string3 = query.getString(query.getColumnIndex(LocalMediaPageLoader.COLUMN_BUCKET_DISPLAY_NAME));
                                    String string4 = query.getString(query.getColumnIndex("mime_type"));
                                    int i8 = query.getInt(query.getColumnIndex("count"));
                                    localMediaFolder2.setBucketId(j8);
                                    localMediaFolder2.setFirstImagePath(query.getString(query.getColumnIndex("_data")));
                                    localMediaFolder2.setName(string3);
                                    localMediaFolder2.setFirstMimeType(string4);
                                    localMediaFolder2.setImageNum(i8);
                                    arrayList.add(localMediaFolder2);
                                    i7 += i8;
                                    if (!query.moveToNext()) {
                                        break;
                                    }
                                }
                                i5 = i7;
                            }
                            LocalMediaFolder localMediaFolder3 = new LocalMediaFolder();
                            LocalMediaFolder loadInAppSandboxFolderFile = SandboxFileLoader.loadInAppSandboxFolderFile(LocalMediaPageLoader.this.mContext, LocalMediaPageLoader.this.config.sandboxFolderPath);
                            if (loadInAppSandboxFolderFile != null) {
                                arrayList.add(loadInAppSandboxFolderFile);
                                i5 += loadInAppSandboxFolderFile.getImageNum();
                                localMediaFolder3.setData(loadInAppSandboxFolderFile.getData());
                                localMediaFolder3.setFirstImagePath(loadInAppSandboxFolderFile.getFirstImagePath());
                                firstCoverMimeType = loadInAppSandboxFolderFile.getFirstMimeType();
                            } else {
                                if (query.moveToFirst()) {
                                    localMediaFolder3.setFirstImagePath(SdkVersionUtils.isQ() ? LocalMediaPageLoader.getFirstUri(query) : LocalMediaPageLoader.getFirstUrl(query));
                                    firstCoverMimeType = LocalMediaPageLoader.getFirstCoverMimeType(query);
                                }
                                SortUtils.sortFolder(arrayList);
                                localMediaFolder3.setImageNum(i5);
                                localMediaFolder3.setChecked(true);
                                localMediaFolder3.setBucketId(-1);
                                if (LocalMediaPageLoader.this.config.chooseMode != PictureMimeType.ofAudio()) {
                                    context = LocalMediaPageLoader.this.mContext;
                                    i6 = R.string.picture_all_audio;
                                } else {
                                    context = LocalMediaPageLoader.this.mContext;
                                    i6 = R.string.picture_camera_roll;
                                }
                                localMediaFolder3.setName(context.getString(i6));
                                localMediaFolder3.setOfAllType(LocalMediaPageLoader.this.config.chooseMode);
                                localMediaFolder3.setCameraFolder(true);
                                arrayList.add(0, localMediaFolder3);
                                if (LocalMediaPageLoader.this.config.isSyncCover && LocalMediaPageLoader.this.config.chooseMode == PictureMimeType.ofAll()) {
                                    LocalMediaPageLoader.this.synchronousFirstCover(arrayList);
                                }
                                if (!query.isClosed()) {
                                    query.close();
                                }
                                return arrayList;
                            }
                            localMediaFolder3.setFirstMimeType(firstCoverMimeType);
                            SortUtils.sortFolder(arrayList);
                            localMediaFolder3.setImageNum(i5);
                            localMediaFolder3.setChecked(true);
                            localMediaFolder3.setBucketId(-1);
                            if (LocalMediaPageLoader.this.config.chooseMode != PictureMimeType.ofAudio()) {
                            }
                            localMediaFolder3.setName(context.getString(i6));
                            localMediaFolder3.setOfAllType(LocalMediaPageLoader.this.config.chooseMode);
                            localMediaFolder3.setCameraFolder(true);
                            arrayList.add(0, localMediaFolder3);
                            LocalMediaPageLoader.this.synchronousFirstCover(arrayList);
                            if (!query.isClosed()) {
                            }
                            return arrayList;
                        }
                    } catch (Exception e7) {
                        e5 = e7;
                        e5.printStackTrace();
                        String str2 = LocalMediaPageLoader.TAG;
                        Log.i(str2, "loadAllMedia Data Error: " + e5.getMessage());
                    }
                }
                if (query != null) {
                }
                return new ArrayList();
            }

            public void onSuccess(List<LocalMediaFolder> list) {
                PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                OnQueryDataResultListener onQueryDataResultListener = onQueryDataResultListener;
                if (onQueryDataResultListener != null) {
                    onQueryDataResultListener.onComplete((List) list);
                }
            }
        });
    }

    @Override // com.luck.picture.lib.model.IBridgeMediaLoader
    public void loadOnlyInAppDirectoryAllMedia(final OnQueryDataResultListener<LocalMediaFolder> onQueryDataResultListener) {
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<LocalMediaFolder>() {
            /* class com.luck.picture.lib.model.LocalMediaPageLoader.AnonymousClass2 */

            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public LocalMediaFolder doInBackground() {
                return SandboxFileLoader.loadInAppSandboxFolderFile(LocalMediaPageLoader.this.mContext, LocalMediaPageLoader.this.config.sandboxFolderPath);
            }

            public void onSuccess(LocalMediaFolder localMediaFolder) {
                PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                OnQueryDataResultListener onQueryDataResultListener = onQueryDataResultListener;
                if (onQueryDataResultListener != null) {
                    onQueryDataResultListener.onComplete(localMediaFolder);
                }
            }
        });
    }

    @Override // com.luck.picture.lib.model.IBridgeMediaLoader
    public void loadPageMediaData(final long j5, final int i5, final int i6, final int i7, final OnQueryDataResultListener<LocalMedia> onQueryDataResultListener) {
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<MediaData>() {
            /* class com.luck.picture.lib.model.LocalMediaPageLoader.AnonymousClass1 */

            /* JADX WARNING: Removed duplicated region for block: B:110:0x026a A[EDGE_INSN: B:110:0x026a->B:79:0x026a ?: BREAK  , SYNTHETIC] */
            /* JADX WARNING: Removed duplicated region for block: B:80:0x026b A[Catch:{ Exception -> 0x02a5, all -> 0x02a3 }, LOOP:0: B:16:0x011e->B:80:0x026b, LOOP_END] */
            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public MediaData doInBackground() {
                Cursor cursor;
                int i5;
                String str;
                int i6;
                int i7;
                int i8;
                int i9;
                String str2;
                Cursor cursor2 = null;
                try {
                    if (SdkVersionUtils.isR()) {
                        cursor = LocalMediaPageLoader.this.mContext.getContentResolver().query(LocalMediaPageLoader.QUERY_URI, LocalMediaPageLoader.PROJECTION_PAGE, MediaUtils.createQueryArgsBundle(LocalMediaPageLoader.this.getPageSelection(j5), LocalMediaPageLoader.this.getPageSelectionArgs(j5), i6, (i5 - 1) * i7), null);
                    } else {
                        if (i5 == -1) {
                            str2 = LocalMediaPageLoader.ORDER_BY;
                        } else {
                            str2 = "_id DESC limit " + i6 + " offset " + ((i5 - 1) * i7);
                        }
                        cursor = LocalMediaPageLoader.this.mContext.getContentResolver().query(LocalMediaPageLoader.QUERY_URI, LocalMediaPageLoader.PROJECTION_PAGE, LocalMediaPageLoader.this.getPageSelection(j5), LocalMediaPageLoader.this.getPageSelectionArgs(j5), str2);
                    }
                    if (cursor != null) {
                        ArrayList arrayList = new ArrayList();
                        if (cursor.getCount() > 0) {
                            int columnIndexOrThrow = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[0]);
                            int columnIndexOrThrow2 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[1]);
                            int columnIndexOrThrow3 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[2]);
                            int columnIndexOrThrow4 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[3]);
                            int columnIndexOrThrow5 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[4]);
                            int columnIndexOrThrow6 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[5]);
                            int columnIndexOrThrow7 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[6]);
                            int columnIndexOrThrow8 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[7]);
                            int columnIndexOrThrow9 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[8]);
                            int columnIndexOrThrow10 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[9]);
                            int columnIndexOrThrow11 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[10]);
                            cursor.moveToFirst();
                            int i10 = columnIndexOrThrow2;
                            while (true) {
                                long j5 = cursor.getLong(columnIndexOrThrow);
                                String string = cursor.getString(columnIndexOrThrow3);
                                if (TextUtils.isEmpty(string)) {
                                    string = PictureMimeType.ofJPEG();
                                }
                                String str3 = string;
                                String string2 = cursor.getString(i10);
                                if (SdkVersionUtils.isQ()) {
                                    i5 = i10;
                                    str = PictureMimeType.getRealPathUri(j5, str3);
                                } else {
                                    i5 = i10;
                                    str = string2;
                                }
                                if (!LocalMediaPageLoader.this.config.isFilterInvalidFile || PictureFileUtils.isFileExists(string2)) {
                                    if (str3.endsWith("image/*")) {
                                        str3 = PictureMimeType.isContent(str) ? PictureMimeType.getImageMimeType(string2) : PictureMimeType.getImageMimeType(str);
                                        if (!LocalMediaPageLoader.this.config.isGif && PictureMimeType.isGif(str3)) {
                                        }
                                    }
                                    if (LocalMediaPageLoader.this.config.isWebp || !str3.startsWith(PictureMimeType.ofWEBP())) {
                                        if (LocalMediaPageLoader.this.config.isBmp || !str3.startsWith(PictureMimeType.ofBMP())) {
                                            int i11 = cursor.getInt(columnIndexOrThrow4);
                                            int i12 = cursor.getInt(columnIndexOrThrow5);
                                            long j6 = cursor.getLong(columnIndexOrThrow6);
                                            i9 = columnIndexOrThrow4;
                                            long j7 = cursor.getLong(columnIndexOrThrow7);
                                            String string3 = cursor.getString(columnIndexOrThrow8);
                                            String string4 = cursor.getString(columnIndexOrThrow9);
                                            long j8 = cursor.getLong(columnIndexOrThrow10);
                                            i8 = columnIndexOrThrow3;
                                            if (LocalMediaPageLoader.this.config.filterFileSize > CropImageView.DEFAULT_ASPECT_RATIO) {
                                                i7 = columnIndexOrThrow5;
                                                if (((float) j7) > LocalMediaPageLoader.this.config.filterFileSize * 1048576.0f) {
                                                    i6 = columnIndexOrThrow6;
                                                    if (cursor.moveToNext()) {
                                                        break;
                                                    }
                                                    columnIndexOrThrow = columnIndexOrThrow;
                                                    i10 = i5;
                                                    columnIndexOrThrow4 = i9;
                                                    columnIndexOrThrow3 = i8;
                                                    columnIndexOrThrow5 = i7;
                                                    columnIndexOrThrow6 = i6;
                                                }
                                            } else {
                                                i7 = columnIndexOrThrow5;
                                            }
                                            if (PictureMimeType.isHasVideo(str3)) {
                                                if (LocalMediaPageLoader.this.config.videoMinSecond > 0) {
                                                    i6 = columnIndexOrThrow6;
                                                    if (j6 < ((long) LocalMediaPageLoader.this.config.videoMinSecond)) {
                                                        if (cursor.moveToNext()) {
                                                        }
                                                    }
                                                } else {
                                                    i6 = columnIndexOrThrow6;
                                                }
                                                if (LocalMediaPageLoader.this.config.videoMaxSecond <= 0 || j6 <= ((long) LocalMediaPageLoader.this.config.videoMaxSecond)) {
                                                    if (j6 != 0) {
                                                        if (j7 <= 0) {
                                                        }
                                                    }
                                                    if (cursor.moveToNext()) {
                                                    }
                                                } else if (cursor.moveToNext()) {
                                                }
                                            } else {
                                                i6 = columnIndexOrThrow6;
                                            }
                                            arrayList.add(LocalMedia.parseLocalMedia(j5, str, string2, string4, string3, j6, LocalMediaPageLoader.this.config.chooseMode, str3, i11, i12, j7, j8, cursor.getLong(columnIndexOrThrow11)));
                                            if (cursor.moveToNext()) {
                                            }
                                        }
                                    }
                                }
                                i8 = columnIndexOrThrow3;
                                i9 = columnIndexOrThrow4;
                                i7 = columnIndexOrThrow5;
                                i6 = columnIndexOrThrow6;
                                if (cursor.moveToNext()) {
                                }
                            }
                        }
                        MediaData mediaData = new MediaData(cursor.getCount() > 0, arrayList);
                        if (!cursor.isClosed()) {
                            cursor.close();
                        }
                        return mediaData;
                    }
                    if (cursor != null && !cursor.isClosed()) {
                        cursor.close();
                    }
                    return new MediaData();
                } catch (Exception e5) {
                    e5.printStackTrace();
                    Log.i(LocalMediaPageLoader.TAG, "loadMedia Page Data Error: " + e5.getMessage());
                    MediaData mediaData2 = new MediaData();
                    if (0 != 0 && !cursor2.isClosed()) {
                        cursor2.close();
                    }
                    return mediaData2;
                } catch (Throwable th) {
                    if (0 != 0 && !cursor2.isClosed()) {
                        cursor2.close();
                    }
                    throw th;
                }
            }

            public void onSuccess(MediaData mediaData) {
                PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
                OnQueryDataResultListener onQueryDataResultListener = onQueryDataResultListener;
                if (onQueryDataResultListener != null) {
                    Collection collection = mediaData.data;
                    if (collection == null) {
                        collection = new ArrayList();
                    }
                    onQueryDataResultListener.onComplete(collection, i5, mediaData.isHasNextMore);
                }
            }
        });
    }

    @Override // com.luck.picture.lib.model.IBridgeMediaLoader
    public void loadPageMediaData(long j5, int i5, int i6, OnQueryDataResultListener<LocalMedia> onQueryDataResultListener) {
        loadPageMediaData(j5, i5, i6, this.config.pageSize, onQueryDataResultListener);
    }

    @Override // com.luck.picture.lib.model.IBridgeMediaLoader
    public void loadPageMediaData(long j5, int i5, OnQueryDataResultListener<LocalMedia> onQueryDataResultListener) {
        int i6 = this.config.pageSize;
        loadPageMediaData(j5, i5, i6, i6, onQueryDataResultListener);
    }
}
