package com.luck.picture.lib.tools;

import android.content.ContentResolver;
import android.content.ContentValues;
import android.content.Context;
import android.net.Uri;
import android.os.Build;
import android.os.Environment;
import android.provider.MediaStore;
import android.text.TextUtils;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import java.io.File;

public class CameraFileUtils {
    public static ContentValues buildImageContentValues(String str, String str2) {
        String valueOf = ValueOf.toString(Long.valueOf(System.currentTimeMillis()));
        ContentValues contentValues = new ContentValues(3);
        contentValues.put("_display_name", (!TextUtils.isEmpty(str) && str.lastIndexOf(".") != -1) ? str.replaceAll(str.substring(str.lastIndexOf(".")), "") : DateUtils.getCreateFileName("IMG_"));
        if (TextUtils.isEmpty(str2) || str2.startsWith(PictureMimeType.MIME_TYPE_PREFIX_VIDEO)) {
            str2 = "image/jpeg";
        }
        contentValues.put("mime_type", str2);
        if (SdkVersionUtils.isQ()) {
            contentValues.put("datetaken", valueOf);
            contentValues.put("relative_path", PictureMimeType.DCIM);
        }
        return contentValues;
    }

    public static ContentValues buildVideoContentValues(String str, String str2) {
        String valueOf = ValueOf.toString(Long.valueOf(System.currentTimeMillis()));
        ContentValues contentValues = new ContentValues(3);
        contentValues.put("_display_name", (!TextUtils.isEmpty(str) && str.lastIndexOf(".") != -1) ? str.replaceAll(str.substring(str.lastIndexOf(".")), "") : DateUtils.getCreateFileName("VID_"));
        if (TextUtils.isEmpty(str2) || str2.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE)) {
            str2 = "video/mp4";
        }
        contentValues.put("mime_type", str2);
        if (SdkVersionUtils.isQ()) {
            contentValues.put("datetaken", valueOf);
            contentValues.put("relative_path", Environment.DIRECTORY_MOVIES);
        }
        return contentValues;
    }

    public static Uri createAudioUri(Context context, String str) {
        Context applicationContext = context.getApplicationContext();
        Uri[] uriArr = {null};
        String externalStorageState = Environment.getExternalStorageState();
        String valueOf = ValueOf.toString(Long.valueOf(System.currentTimeMillis()));
        ContentValues contentValues = new ContentValues(3);
        contentValues.put("_display_name", DateUtils.getCreateFileName("AUD_"));
        int i5 = Build.VERSION.SDK_INT;
        if (i5 >= 29) {
            contentValues.put("datetaken", valueOf);
        }
        if (TextUtils.isEmpty(str) || str.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE) || str.startsWith(PictureMimeType.MIME_TYPE_PREFIX_VIDEO)) {
            str = "audio/amr";
        }
        contentValues.put("mime_type", str);
        if (externalStorageState.equals("mounted")) {
            if (i5 >= 29) {
                contentValues.put("relative_path", Environment.DIRECTORY_MUSIC);
            }
            uriArr[0] = applicationContext.getContentResolver().insert(MediaStore.Audio.Media.EXTERNAL_CONTENT_URI, contentValues);
        } else {
            uriArr[0] = applicationContext.getContentResolver().insert(MediaStore.Audio.Media.INTERNAL_CONTENT_URI, contentValues);
        }
        return uriArr[0];
    }

    public static Uri createCameraOutAudioUri(Context context, PictureSelectionConfig pictureSelectionConfig) {
        pictureSelectionConfig.cameraMimeType = PictureMimeType.ofAudio();
        String str = null;
        if (!SdkVersionUtils.isQ()) {
            return null;
        }
        Uri createAudioUri = createAudioUri(context, pictureSelectionConfig.cameraAudioFormatForQ);
        if (createAudioUri != null) {
            str = createAudioUri.toString();
        }
        pictureSelectionConfig.cameraPath = str;
        return createAudioUri;
    }

    public static Uri createCameraOutImageUri(Context context, PictureSelectionConfig pictureSelectionConfig) {
        String str;
        pictureSelectionConfig.cameraMimeType = PictureMimeType.ofImage();
        if (TextUtils.isEmpty(pictureSelectionConfig.cameraFileName)) {
            str = "";
        } else {
            str = !PictureMimeType.isSuffixOfImage(pictureSelectionConfig.cameraFileName) ? StringUtils.renameSuffix(pictureSelectionConfig.cameraFileName, PictureMimeType.JPG) : pictureSelectionConfig.cameraFileName;
            pictureSelectionConfig.cameraFileName = str;
            if (!pictureSelectionConfig.camera) {
                str = StringUtils.rename(str);
            }
        }
        if (!SdkVersionUtils.isQ() || !TextUtils.isEmpty(pictureSelectionConfig.outPutCameraPath)) {
            File createCameraFile = PictureFileUtils.createCameraFile(context, 1, str, pictureSelectionConfig.cameraImageFormat, pictureSelectionConfig.outPutCameraPath);
            pictureSelectionConfig.cameraPath = createCameraFile.getAbsolutePath();
            return PictureFileUtils.parUri(context, createCameraFile);
        }
        Uri createImageUri = createImageUri(context, str, pictureSelectionConfig.cameraImageFormatForQ);
        pictureSelectionConfig.cameraPath = createImageUri != null ? createImageUri.toString() : null;
        return createImageUri;
    }

    public static Uri createCameraOutVideoUri(Context context, PictureSelectionConfig pictureSelectionConfig) {
        String str;
        pictureSelectionConfig.cameraMimeType = PictureMimeType.ofVideo();
        String str2 = "";
        if (TextUtils.isEmpty(pictureSelectionConfig.cameraFileName)) {
            str = str2;
        } else {
            str = PictureMimeType.isSuffixOfImage(pictureSelectionConfig.cameraFileName) ? StringUtils.renameSuffix(pictureSelectionConfig.cameraFileName, ".mp4") : pictureSelectionConfig.cameraFileName;
            pictureSelectionConfig.cameraFileName = str;
            if (!pictureSelectionConfig.camera) {
                str = StringUtils.rename(str);
            }
        }
        if (!SdkVersionUtils.isQ() || !TextUtils.isEmpty(pictureSelectionConfig.outPutCameraPath)) {
            File createCameraFile = PictureFileUtils.createCameraFile(context, 2, str, pictureSelectionConfig.cameraVideoFormat, pictureSelectionConfig.outPutCameraPath);
            pictureSelectionConfig.cameraPath = createCameraFile.getAbsolutePath();
            return PictureFileUtils.parUri(context, createCameraFile);
        }
        Uri createVideoUri = createVideoUri(context, str, pictureSelectionConfig.cameraVideoFormatForQ);
        if (createVideoUri != null) {
            str2 = createVideoUri.toString();
        }
        pictureSelectionConfig.cameraPath = str2;
        return createVideoUri;
    }

    public static Uri createImageUri(Context context, String str, String str2) {
        Context applicationContext = context.getApplicationContext();
        Uri[] uriArr = {null};
        String externalStorageState = Environment.getExternalStorageState();
        ContentValues buildImageContentValues = buildImageContentValues(str, str2);
        boolean equals = externalStorageState.equals("mounted");
        ContentResolver contentResolver = applicationContext.getContentResolver();
        if (equals) {
            uriArr[0] = contentResolver.insert(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, buildImageContentValues);
        } else {
            uriArr[0] = contentResolver.insert(MediaStore.Images.Media.INTERNAL_CONTENT_URI, buildImageContentValues);
        }
        return uriArr[0];
    }

    public static Uri createVideoUri(Context context, String str, String str2) {
        Context applicationContext = context.getApplicationContext();
        Uri[] uriArr = {null};
        String externalStorageState = Environment.getExternalStorageState();
        ContentValues buildVideoContentValues = buildVideoContentValues(str, str2);
        boolean equals = externalStorageState.equals("mounted");
        ContentResolver contentResolver = applicationContext.getContentResolver();
        if (equals) {
            uriArr[0] = contentResolver.insert(MediaStore.Video.Media.EXTERNAL_CONTENT_URI, buildVideoContentValues);
        } else {
            uriArr[0] = contentResolver.insert(MediaStore.Video.Media.INTERNAL_CONTENT_URI, buildVideoContentValues);
        }
        return uriArr[0];
    }
}
