package com.luck.picture.lib.tools;

import android.content.Context;
import android.database.Cursor;
import android.graphics.BitmapFactory;
import android.media.MediaMetadataRetriever;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.provider.MediaStore;
import android.text.TextUtils;
import androidx.exifinterface.media.a;
import com.luck.picture.lib.PictureContentResolver;
import com.luck.picture.lib.app.PictureAppMaster;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.MediaExtraInfo;
import java.io.FileInputStream;

public class MediaUtils {
    public static Bundle createQueryArgsBundle(String str, String[] strArr, int i5, int i6) {
        Bundle bundle = new Bundle();
        int i7 = Build.VERSION.SDK_INT;
        if (i7 >= 26) {
            bundle.putString("android:query-arg-sql-selection", str);
            bundle.putStringArray("android:query-arg-sql-selection-args", strArr);
            bundle.putString("android:query-arg-sql-sort-order", "_id DESC");
            if (i7 >= 30) {
                bundle.putString("android:query-arg-sql-limit", i5 + " offset " + i6);
            }
        }
        return bundle;
    }

    public static void deleteCamera(Context context, String str) {
        try {
            if (PictureMimeType.isContent(str)) {
                context.getContentResolver().delete(Uri.parse(str), null, null);
            }
        } catch (Exception e5) {
            e5.printStackTrace();
        }
    }

    public static void deleteUri(Context context, Uri uri) {
        if (uri != null) {
            try {
                context.getContentResolver().delete(uri, null, null);
            } catch (Exception e5) {
                e5.printStackTrace();
            }
        }
    }

    public static MediaExtraInfo getAudioSize(Context context, String str) {
        MediaExtraInfo mediaExtraInfo = new MediaExtraInfo();
        MediaMetadataRetriever mediaMetadataRetriever = new MediaMetadataRetriever();
        try {
            if (PictureMimeType.isContent(str)) {
                mediaMetadataRetriever.setDataSource(context, Uri.parse(str));
            } else {
                mediaMetadataRetriever.setDataSource(str);
            }
            mediaExtraInfo.setDuration(ValueOf.toLong(mediaMetadataRetriever.extractMetadata(9)));
        } catch (Exception e5) {
            e5.printStackTrace();
        } catch (Throwable th) {
            mediaMetadataRetriever.release();
            throw th;
        }
        mediaMetadataRetriever.release();
        return mediaExtraInfo;
    }

    public static long getCameraFirstBucketId(Context context) {
        Cursor cursor;
        Cursor cursor2 = null;
        try {
            String dCIMCameraPath = PictureFileUtils.getDCIMCameraPath();
            String[] strArr = {dCIMCameraPath + "%"};
            if (SdkVersionUtils.isR()) {
                cursor = context.getApplicationContext().getContentResolver().query(MediaStore.Files.getContentUri("external"), null, createQueryArgsBundle("_data like ?", strArr, 1, 0), null);
            } else {
                cursor = context.getApplicationContext().getContentResolver().query(MediaStore.Files.getContentUri("external"), null, "_data like ?", strArr, "_id DESC limit 1 offset 0");
            }
            cursor2 = cursor;
            if (cursor2 == null || cursor2.getCount() <= 0 || !cursor2.moveToFirst()) {
                if (cursor2 == null) {
                    return -1;
                }
                cursor2.close();
                return -1;
            }
            long j5 = cursor2.getLong(cursor2.getColumnIndex(PictureConfig.EXTRA_BUCKET_ID));
            cursor2.close();
            return j5;
        } catch (Exception e5) {
            e5.printStackTrace();
            if (0 == 0) {
                return -1;
            }
        } catch (Throwable th) {
            if (0 != 0) {
                cursor2.close();
            }
            throw th;
        }
    }

    public static int getDCIMLastImageId(Context context) {
        Cursor cursor;
        int i5 = -1;
        Cursor cursor2 = null;
        try {
            String dCIMCameraPath = PictureFileUtils.getDCIMCameraPath();
            String[] strArr = {dCIMCameraPath + "%"};
            if (SdkVersionUtils.isR()) {
                cursor = context.getApplicationContext().getContentResolver().query(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, null, createQueryArgsBundle("_data like ?", strArr, 1, 0), null);
            } else {
                cursor = context.getApplicationContext().getContentResolver().query(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, null, "_data like ?", strArr, "_id DESC limit 1 offset 0");
            }
            if (cursor == null || cursor.getCount() <= 0 || !cursor.moveToFirst()) {
                if (cursor != null) {
                    cursor.close();
                }
                return -1;
            }
            int i6 = cursor.getInt(cursor.getColumnIndex("_id"));
            if (DateUtils.dateDiffer(cursor.getLong(cursor.getColumnIndex("date_added"))) <= 1) {
                i5 = i6;
            }
            cursor.close();
            return i5;
        } catch (Exception e5) {
            e5.printStackTrace();
            if (0 != 0) {
                cursor2.close();
            }
            return -1;
        } catch (Throwable th) {
            if (0 != 0) {
                cursor2.close();
            }
            throw th;
        }
    }

    public static MediaExtraInfo getImageSize(Context context, String str) {
        MediaExtraInfo mediaExtraInfo = new MediaExtraInfo();
        try {
            a aVar = PictureMimeType.isContent(str) ? new a(PictureContentResolver.getContentResolverOpenInputStream(context, Uri.parse(str))) : new a(str);
            mediaExtraInfo.setWidth(aVar.i("ImageWidth", 1));
            mediaExtraInfo.setHeight(aVar.i("ImageLength", 1));
        } catch (Exception e5) {
            e5.printStackTrace();
        }
        return mediaExtraInfo;
    }

    public static MediaExtraInfo getImageSize(String str) {
        MediaExtraInfo mediaExtraInfo = new MediaExtraInfo();
        try {
            BitmapFactory.Options options = new BitmapFactory.Options();
            options.inJustDecodeBounds = true;
            BitmapFactory.decodeStream(PictureMimeType.isContent(str) ? PictureContentResolver.getContentResolverOpenInputStream(PictureAppMaster.getInstance().getAppContext(), Uri.parse(str)) : new FileInputStream(str), null, options);
            mediaExtraInfo.setWidth(options.outWidth);
            mediaExtraInfo.setHeight(options.outHeight);
        } catch (Exception e5) {
            e5.printStackTrace();
        }
        return mediaExtraInfo;
    }

    public static MediaExtraInfo getVideoSize(Context context, String str) {
        int i5;
        int i6;
        MediaExtraInfo mediaExtraInfo = new MediaExtraInfo();
        MediaMetadataRetriever mediaMetadataRetriever = new MediaMetadataRetriever();
        try {
            if (PictureMimeType.isContent(str)) {
                mediaMetadataRetriever.setDataSource(context, Uri.parse(str));
            } else {
                mediaMetadataRetriever.setDataSource(str);
            }
            String extractMetadata = mediaMetadataRetriever.extractMetadata(24);
            if (!TextUtils.equals("90", extractMetadata)) {
                if (!TextUtils.equals("270", extractMetadata)) {
                    i6 = ValueOf.toInt(mediaMetadataRetriever.extractMetadata(18));
                    i5 = ValueOf.toInt(mediaMetadataRetriever.extractMetadata(19));
                    mediaExtraInfo.setWidth(i6);
                    mediaExtraInfo.setHeight(i5);
                    mediaExtraInfo.setDuration(ValueOf.toLong(mediaMetadataRetriever.extractMetadata(9)));
                    mediaMetadataRetriever.release();
                    return mediaExtraInfo;
                }
            }
            i5 = ValueOf.toInt(mediaMetadataRetriever.extractMetadata(18));
            i6 = ValueOf.toInt(mediaMetadataRetriever.extractMetadata(19));
            mediaExtraInfo.setWidth(i6);
            mediaExtraInfo.setHeight(i5);
            mediaExtraInfo.setDuration(ValueOf.toLong(mediaMetadataRetriever.extractMetadata(9)));
        } catch (Exception e5) {
            e5.printStackTrace();
        } catch (Throwable th) {
            mediaMetadataRetriever.release();
            throw th;
        }
        mediaMetadataRetriever.release();
        return mediaExtraInfo;
    }

    public static boolean isLongImg(int i5, int i6) {
        return i5 > 0 && i6 > 0 && i6 > i5 * 3;
    }

    public static boolean isLongImg(LocalMedia localMedia) {
        int width = localMedia.getWidth();
        int height = localMedia.getHeight();
        return width > 0 && height > 0 && height > width * 3;
    }

    public static void removeMedia(Context context, int i5) {
        try {
            context.getApplicationContext().getContentResolver().delete(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, "_id=?", new String[]{Long.toString((long) i5)});
        } catch (Exception e5) {
            e5.printStackTrace();
        }
    }
}
