package com.luck.picture.lib.tools;

import android.content.ContentUris;
import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.os.Build;
import android.os.Environment;
import android.provider.DocumentsContract;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.Log;
import androidx.core.content.b;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.channels.FileChannel;
import java.util.Locale;
import java.util.Objects;

public class PictureFileUtils {
    private static final int BYTE_SIZE = 1024;
    public static final int GB = 1073741824;
    public static final int KB = 1024;
    public static final int MB = 1048576;
    public static final String POSTFIX = ".jpeg";
    public static final String POST_AUDIO = ".amr";
    public static final String POST_VIDEO = ".mp4";
    static final String TAG = "PictureFileUtils";

    private PictureFileUtils() {
    }

    public static void close(Closeable closeable) {
        if (closeable instanceof Closeable) {
            try {
                closeable.close();
            } catch (Exception unused) {
            }
        }
    }

    public static void copyFile(String str, String str2) {
        Throwable th;
        FileChannel fileChannel;
        Exception e5;
        if (!str.equalsIgnoreCase(str2)) {
            FileChannel fileChannel2 = null;
            try {
                FileChannel channel = new FileInputStream(str).getChannel();
                try {
                    fileChannel2 = new FileOutputStream(str2).getChannel();
                    channel.transferTo(0, channel.size(), fileChannel2);
                    close(channel);
                    close(fileChannel2);
                } catch (Exception e6) {
                    e5 = e6;
                    fileChannel2 = channel;
                    fileChannel = fileChannel2;
                    try {
                        e5.printStackTrace();
                        close(fileChannel2);
                        close(fileChannel);
                    } catch (Throwable th2) {
                        th = th2;
                        close(fileChannel2);
                        close(fileChannel);
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    fileChannel2 = channel;
                    fileChannel = fileChannel2;
                    close(fileChannel2);
                    close(fileChannel);
                    throw th;
                }
            } catch (Exception e7) {
                e5 = e7;
                fileChannel = null;
                e5.printStackTrace();
                close(fileChannel2);
                close(fileChannel);
            } catch (Throwable th4) {
                th = th4;
                fileChannel = null;
                close(fileChannel2);
                close(fileChannel);
                throw th;
            }
        }
    }

    public static File createCameraFile(Context context, int i5, String str, String str2, String str3) {
        return createMediaFile(context, i5, str, str2, str3);
    }

    public static String createFilePath(Context context, String str, String str2, String str3) {
        String str4;
        StringBuilder sb;
        String lastImgSuffix = PictureMimeType.getLastImgSuffix(str2);
        if (PictureMimeType.isHasVideo(str2)) {
            str4 = getVideoDiskCacheDir(context) + File.separator;
            if (TextUtils.isEmpty(str)) {
                if (TextUtils.isEmpty(str3)) {
                    str3 = DateUtils.getCreateFileName("VID_") + lastImgSuffix;
                }
                sb = new StringBuilder();
            } else {
                if (TextUtils.isEmpty(str3)) {
                    str3 = "VID_" + str.toUpperCase() + lastImgSuffix;
                }
                sb = new StringBuilder();
            }
        } else if (PictureMimeType.isHasAudio(str2)) {
            str4 = getAudioDiskCacheDir(context) + File.separator;
            if (TextUtils.isEmpty(str)) {
                if (TextUtils.isEmpty(str3)) {
                    str3 = DateUtils.getCreateFileName("AUD_") + lastImgSuffix;
                }
                sb = new StringBuilder();
            } else {
                if (TextUtils.isEmpty(str3)) {
                    str3 = "AUD_" + str.toUpperCase() + lastImgSuffix;
                }
                sb = new StringBuilder();
            }
        } else {
            str4 = getDiskCacheDir(context) + File.separator;
            if (TextUtils.isEmpty(str)) {
                if (TextUtils.isEmpty(str3)) {
                    str3 = DateUtils.getCreateFileName("IMG_") + lastImgSuffix;
                }
                sb = new StringBuilder();
            } else {
                if (TextUtils.isEmpty(str3)) {
                    str3 = "IMG_" + str.toUpperCase() + lastImgSuffix;
                }
                sb = new StringBuilder();
            }
        }
        sb.append(str4);
        sb.append(str3);
        return sb.toString();
    }

    private static File createMediaFile(Context context, int i5, String str, String str2, String str3) {
        return createOutFile(context, i5, str, str2, str3);
    }

    private static File createOutFile(Context context, int i5, String str, String str2, String str3) {
        File file;
        File file2;
        Context applicationContext = context.getApplicationContext();
        if (TextUtils.isEmpty(str3)) {
            if (TextUtils.equals("mounted", Environment.getExternalStorageState())) {
                file2 = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DCIM);
                StringBuilder sb = new StringBuilder();
                sb.append(file2.getAbsolutePath());
                String str4 = File.separator;
                sb.append(str4);
                sb.append(PictureMimeType.CAMERA);
                sb.append(str4);
                file = new File(sb.toString());
            } else {
                file2 = getRootDirFile(applicationContext, i5);
                file = new File(file2.getAbsolutePath() + File.separator);
            }
            if (!file2.exists()) {
                file2.mkdirs();
            }
        } else {
            File file3 = new File(str3);
            File parentFile = file3.getParentFile();
            Objects.requireNonNull(parentFile);
            if (!parentFile.exists()) {
                file3.getParentFile().mkdirs();
            }
            file = file3;
        }
        if (!file.exists()) {
            file.mkdirs();
        }
        boolean isEmpty = TextUtils.isEmpty(str);
        if (i5 == 2) {
            if (isEmpty) {
                str = DateUtils.getCreateFileName("VID_") + ".mp4";
            }
            return new File(file, str);
        } else if (i5 != 3) {
            if (TextUtils.isEmpty(str2)) {
                str2 = ".jpeg";
            }
            if (isEmpty) {
                str = DateUtils.getCreateFileName("IMG_") + str2;
            }
            return new File(file, str);
        } else {
            if (isEmpty) {
                str = DateUtils.getCreateFileName("AUD_") + ".amr";
            }
            return new File(file, str);
        }
    }

    @Deprecated
    public static void deleteAllCacheDirFile(Context context) {
        File[] listFiles;
        File[] listFiles2;
        File[] listFiles3;
        File externalFilesDir = context.getExternalFilesDir(Environment.DIRECTORY_PICTURES);
        if (!(externalFilesDir == null || (listFiles3 = externalFilesDir.listFiles()) == null)) {
            for (File file : listFiles3) {
                if (file.isFile()) {
                    file.delete();
                }
            }
        }
        File externalFilesDir2 = context.getExternalFilesDir(Environment.DIRECTORY_MOVIES);
        if (!(externalFilesDir2 == null || (listFiles2 = externalFilesDir2.listFiles()) == null)) {
            for (File file2 : listFiles2) {
                if (file2.isFile()) {
                    file2.delete();
                }
            }
        }
        File externalFilesDir3 = context.getExternalFilesDir(Environment.DIRECTORY_MUSIC);
        if (!(externalFilesDir3 == null || (listFiles = externalFilesDir3.listFiles()) == null)) {
            for (File file3 : listFiles) {
                if (file3.isFile()) {
                    file3.delete();
                }
            }
        }
    }

    @Deprecated
    public static void deleteCacheDirFile(Context context, int i5) {
        File[] listFiles;
        File externalFilesDir = context.getExternalFilesDir(i5 == PictureMimeType.ofImage() ? Environment.DIRECTORY_PICTURES : Environment.DIRECTORY_MOVIES);
        if (!(externalFilesDir == null || (listFiles = externalFilesDir.listFiles()) == null)) {
            for (File file : listFiles) {
                if (file.isFile()) {
                    file.delete();
                }
            }
        }
    }

    public static String formatFileSize(long j5, int i5) {
        StringBuilder sb;
        if (i5 < 0) {
            throw new IllegalArgumentException("precision shouldn't be less than zero!");
        } else if (j5 < 0) {
            throw new IllegalArgumentException("byteSize shouldn't be less than zero!");
        } else if (j5 < 1024) {
            return String.format("%." + i5 + "fB", Double.valueOf((double) j5));
        } else if (j5 < PictureConfig.MB) {
            return String.format("%." + i5 + "fKB", Double.valueOf(((double) j5) / 1024.0d));
        } else if (j5 < 1073741824) {
            sb.append("%.");
            sb.append(i5);
            sb.append("fMB");
            return String.format(sb.toString(), Double.valueOf(((double) j5) / 1048576.0d));
        } else {
            sb = new StringBuilder();
            sb.append("%.");
            sb.append(i5);
            sb.append("fGB");
            return String.format(sb.toString(), Double.valueOf(((double) j5) / 1.073741824E9d));
        }
    }

    public static String getAudioDiskCacheDir(Context context) {
        File externalFilesDir = context.getExternalFilesDir(Environment.DIRECTORY_MUSIC);
        return externalFilesDir == null ? "" : externalFilesDir.getPath();
    }

    public static String getDCIMCameraPath() {
        try {
            return "%" + Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DCIM).getAbsolutePath() + "/Camera";
        } catch (Exception e5) {
            e5.printStackTrace();
            return "";
        }
    }

    public static String getDataColumn(Context context, Uri uri, String str, String[] strArr) {
        Cursor cursor = null;
        try {
            cursor = context.getContentResolver().query(uri, new String[]{"_data"}, str, strArr, null);
            if (cursor == null || !cursor.moveToFirst()) {
                if (cursor == null) {
                    return "";
                }
                cursor.close();
                return "";
            }
            String string = cursor.getString(cursor.getColumnIndexOrThrow("_data"));
            cursor.close();
            return string;
        } catch (IllegalArgumentException e5) {
            Log.i(TAG, String.format(Locale.getDefault(), "getDataColumn: _data - [%s]", e5.getMessage()));
            if (0 == 0) {
                return "";
            }
        } catch (Throwable th) {
            if (0 != 0) {
                cursor.close();
            }
            throw th;
        }
    }

    public static String getDiskCacheDir(Context context) {
        File externalFilesDir = context.getExternalFilesDir(Environment.DIRECTORY_PICTURES);
        return externalFilesDir == null ? "" : externalFilesDir.getPath();
    }

    public static String getPath(Context context, Uri uri) {
        Context applicationContext = context.getApplicationContext();
        Uri uri2 = null;
        if (!(Build.VERSION.SDK_INT >= 19) || !DocumentsContract.isDocumentUri(applicationContext, uri)) {
            return "content".equalsIgnoreCase(uri.getScheme()) ? isGooglePhotosUri(uri) ? uri.getLastPathSegment() : getDataColumn(applicationContext, uri, null, null) : "file".equalsIgnoreCase(uri.getScheme()) ? uri.getPath() : "";
        }
        if (isExternalStorageDocument(uri)) {
            String[] split = DocumentsContract.getDocumentId(uri).split(":");
            if (!"primary".equalsIgnoreCase(split[0])) {
                return "";
            }
            if (SdkVersionUtils.isQ()) {
                return applicationContext.getExternalFilesDir(Environment.DIRECTORY_PICTURES) + "/" + split[1];
            }
            return Environment.getExternalStorageDirectory() + "/" + split[1];
        } else if (isDownloadsDocument(uri)) {
            return getDataColumn(applicationContext, ContentUris.withAppendedId(Uri.parse("content://downloads/public_downloads"), ValueOf.toLong(DocumentsContract.getDocumentId(uri))), null, null);
        } else if (!isMediaDocument(uri)) {
            return "";
        } else {
            String[] split2 = DocumentsContract.getDocumentId(uri).split(":");
            String str = split2[0];
            if (PictureMimeType.MIME_TYPE_PREFIX_IMAGE.equals(str)) {
                uri2 = MediaStore.Images.Media.EXTERNAL_CONTENT_URI;
            } else if (PictureMimeType.MIME_TYPE_PREFIX_VIDEO.equals(str)) {
                uri2 = MediaStore.Video.Media.EXTERNAL_CONTENT_URI;
            } else if (PictureMimeType.MIME_TYPE_PREFIX_AUDIO.equals(str)) {
                uri2 = MediaStore.Audio.Media.EXTERNAL_CONTENT_URI;
            }
            return getDataColumn(applicationContext, uri2, "_id=?", new String[]{split2[1]});
        }
    }

    private static File getRootDirFile(Context context, int i5) {
        return context.getExternalFilesDir(i5 != 2 ? i5 != 3 ? Environment.DIRECTORY_PICTURES : Environment.DIRECTORY_MUSIC : Environment.DIRECTORY_MOVIES);
    }

    public static String getVideoDiskCacheDir(Context context) {
        File externalFilesDir = context.getExternalFilesDir(Environment.DIRECTORY_MOVIES);
        return externalFilesDir == null ? "" : externalFilesDir.getPath();
    }

    public static boolean isDownloadsDocument(Uri uri) {
        return "com.android.providers.downloads.documents".equals(uri.getAuthority());
    }

    public static boolean isExternalStorageDocument(Uri uri) {
        return "com.android.externalstorage.documents".equals(uri.getAuthority());
    }

    public static boolean isFileExists(String str) {
        return TextUtils.isEmpty(str) || new File(str).exists();
    }

    public static boolean isGooglePhotosUri(Uri uri) {
        return "com.google.android.apps.photos.content".equals(uri.getAuthority());
    }

    public static boolean isMediaDocument(Uri uri) {
        return "com.android.providers.media.documents".equals(uri.getAuthority());
    }

    public static Uri parUri(Context context, File file) {
        return Build.VERSION.SDK_INT > 23 ? b.getUriForFile(context, context.getPackageName() + ".luckProvider", file) : Uri.fromFile(file);
    }

    public static String rename(String str) {
        String substring = str.substring(0, str.lastIndexOf("."));
        String substring2 = str.substring(str.lastIndexOf("."));
        return substring + "_" + DateUtils.getCreateFileName() + substring2;
    }

    public static boolean writeFileFromIS(InputStream inputStream, OutputStream outputStream) {
        Throwable th;
        BufferedOutputStream bufferedOutputStream;
        Exception e5;
        BufferedInputStream bufferedInputStream = null;
        try {
            BufferedInputStream bufferedInputStream2 = new BufferedInputStream(inputStream);
            try {
                bufferedOutputStream = new BufferedOutputStream(outputStream);
            } catch (Exception e6) {
                e5 = e6;
                bufferedOutputStream = null;
                bufferedInputStream = bufferedInputStream2;
                try {
                    e5.printStackTrace();
                    close(bufferedInputStream);
                    close(bufferedOutputStream);
                    return false;
                } catch (Throwable th2) {
                    th = th2;
                    close(bufferedInputStream);
                    close(bufferedOutputStream);
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                bufferedOutputStream = null;
                bufferedInputStream = bufferedInputStream2;
                close(bufferedInputStream);
                close(bufferedOutputStream);
                throw th;
            }
            try {
                byte[] bArr = new byte[1024];
                while (true) {
                    int read = bufferedInputStream2.read(bArr);
                    if (read != -1) {
                        outputStream.write(bArr, 0, read);
                    } else {
                        outputStream.flush();
                        close(bufferedInputStream2);
                        close(bufferedOutputStream);
                        return true;
                    }
                }
            } catch (Exception e7) {
                e5 = e7;
                bufferedInputStream = bufferedInputStream2;
                e5.printStackTrace();
                close(bufferedInputStream);
                close(bufferedOutputStream);
                return false;
            } catch (Throwable th4) {
                th = th4;
                bufferedInputStream = bufferedInputStream2;
                close(bufferedInputStream);
                close(bufferedOutputStream);
                throw th;
            }
        } catch (Exception e8) {
            e5 = e8;
            bufferedOutputStream = null;
            e5.printStackTrace();
            close(bufferedInputStream);
            close(bufferedOutputStream);
            return false;
        } catch (Throwable th5) {
            th = th5;
            bufferedOutputStream = null;
            close(bufferedInputStream);
            close(bufferedOutputStream);
            throw th;
        }
    }
}
