package com.yalantis.ucrop.task;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Matrix;
import android.net.Uri;
import android.os.AsyncTask;
import android.text.TextUtils;
import android.util.Log;
import androidx.core.content.a;
import com.luck.picture.lib.PictureContentResolver;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.yalantis.ucrop.callback.BitmapLoadCallback;
import com.yalantis.ucrop.model.ExifInfo;
import com.yalantis.ucrop.util.BitmapLoadUtils;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;
import java.util.Objects;

public class BitmapLoadTask extends AsyncTask<Void, Void, BitmapWorkerResult> {
    private static final int MAX_BITMAP_SIZE = 104857600;
    private static final String TAG = "BitmapWorkerTask";
    private final BitmapLoadCallback mBitmapLoadCallback;
    private final Context mContext;
    private final int mInputImageHeight;
    private final int mInputImageWidth;
    private Uri mInputUri;
    private final Uri mOutputUri;
    private final int mRequiredHeight;
    private final int mRequiredWidth;

    public static class BitmapWorkerResult {
        Bitmap mBitmapResult;
        Exception mBitmapWorkerException;
        ExifInfo mExifInfo;

        public BitmapWorkerResult(Bitmap bitmap, ExifInfo exifInfo) {
            this.mBitmapResult = bitmap;
            this.mExifInfo = exifInfo;
        }

        public BitmapWorkerResult(Exception exc) {
            this.mBitmapWorkerException = exc;
        }
    }

    public BitmapLoadTask(Context context, Uri uri, Uri uri2, int i5, int i6, int i7, int i8, BitmapLoadCallback bitmapLoadCallback) {
        this.mContext = context;
        this.mInputUri = uri;
        this.mOutputUri = uri2;
        this.mRequiredWidth = i5;
        this.mRequiredHeight = i6;
        this.mInputImageWidth = i7;
        this.mInputImageHeight = i8;
        this.mBitmapLoadCallback = bitmapLoadCallback;
    }

    private boolean checkSize(Bitmap bitmap, BitmapFactory.Options options) {
        if ((bitmap != null ? bitmap.getByteCount() : 0) <= MAX_BITMAP_SIZE) {
            return false;
        }
        options.inSampleSize *= 2;
        return true;
    }

    private void copyFile(Uri uri, Uri uri2) {
        Throwable th;
        InputStream inputStream;
        Log.d(TAG, "copyFile");
        Objects.requireNonNull(uri2, "Output Uri is null - cannot copy image");
        FileOutputStream fileOutputStream = null;
        try {
            inputStream = PictureContentResolver.getContentResolverOpenInputStream(this.mContext, uri);
            try {
                FileOutputStream fileOutputStream2 = new FileOutputStream(uri2.getPath());
                if (inputStream != null) {
                    try {
                        byte[] bArr = new byte[PictureFileUtils.KB];
                        while (true) {
                            int read = inputStream.read(bArr);
                            if (read > 0) {
                                fileOutputStream2.write(bArr, 0, read);
                            } else {
                                BitmapLoadUtils.close(fileOutputStream2);
                                BitmapLoadUtils.close(inputStream);
                                this.mInputUri = this.mOutputUri;
                                return;
                            }
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        fileOutputStream = fileOutputStream2;
                        BitmapLoadUtils.close(fileOutputStream);
                        BitmapLoadUtils.close(inputStream);
                        this.mInputUri = this.mOutputUri;
                        throw th;
                    }
                } else {
                    throw new NullPointerException("InputStream for given input Uri is null");
                }
            } catch (Throwable th3) {
                th = th3;
                BitmapLoadUtils.close(fileOutputStream);
                BitmapLoadUtils.close(inputStream);
                this.mInputUri = this.mOutputUri;
                throw th;
            }
        } catch (Throwable th4) {
            th = th4;
            inputStream = null;
            BitmapLoadUtils.close(fileOutputStream);
            BitmapLoadUtils.close(inputStream);
            this.mInputUri = this.mOutputUri;
            throw th;
        }
    }

    private void downloadFile(Uri uri, Uri uri2) {
        OutputStream outputStream;
        Throwable th;
        BufferedInputStream bufferedInputStream;
        Exception e5;
        Log.d(TAG, "downloadFile");
        Objects.requireNonNull(uri2, "Output Uri is null - cannot download image");
        BufferedOutputStream bufferedOutputStream = null;
        try {
            URL url = new URL(uri.toString());
            byte[] bArr = new byte[PictureFileUtils.KB];
            bufferedInputStream = new BufferedInputStream(url.openStream());
            try {
                outputStream = PictureContentResolver.getContentResolverOpenOutputStream(this.mContext, uri2);
                if (outputStream != null) {
                    try {
                        BufferedOutputStream bufferedOutputStream2 = new BufferedOutputStream(outputStream);
                        while (true) {
                            try {
                                int read = bufferedInputStream.read(bArr);
                                if (read <= -1) {
                                    break;
                                }
                                bufferedOutputStream2.write(bArr, 0, read);
                            } catch (Exception e6) {
                                e5 = e6;
                                bufferedOutputStream = bufferedOutputStream2;
                                try {
                                    e5.printStackTrace();
                                    this.mInputUri = this.mOutputUri;
                                    BitmapLoadUtils.close(bufferedOutputStream);
                                    BitmapLoadUtils.close(bufferedInputStream);
                                    BitmapLoadUtils.close(outputStream);
                                } catch (Throwable th2) {
                                    th = th2;
                                    this.mInputUri = this.mOutputUri;
                                    BitmapLoadUtils.close(bufferedOutputStream);
                                    BitmapLoadUtils.close(bufferedInputStream);
                                    BitmapLoadUtils.close(outputStream);
                                    throw th;
                                }
                            } catch (Throwable th3) {
                                th = th3;
                                bufferedOutputStream = bufferedOutputStream2;
                                this.mInputUri = this.mOutputUri;
                                BitmapLoadUtils.close(bufferedOutputStream);
                                BitmapLoadUtils.close(bufferedInputStream);
                                BitmapLoadUtils.close(outputStream);
                                throw th;
                            }
                        }
                        bufferedOutputStream2.flush();
                        bufferedOutputStream = bufferedOutputStream2;
                    } catch (Exception e7) {
                        e5 = e7;
                        e5.printStackTrace();
                        this.mInputUri = this.mOutputUri;
                        BitmapLoadUtils.close(bufferedOutputStream);
                        BitmapLoadUtils.close(bufferedInputStream);
                        BitmapLoadUtils.close(outputStream);
                    }
                }
            } catch (Exception e8) {
                e5 = e8;
                outputStream = null;
                e5.printStackTrace();
                this.mInputUri = this.mOutputUri;
                BitmapLoadUtils.close(bufferedOutputStream);
                BitmapLoadUtils.close(bufferedInputStream);
                BitmapLoadUtils.close(outputStream);
            } catch (Throwable th4) {
                th = th4;
                outputStream = null;
                this.mInputUri = this.mOutputUri;
                BitmapLoadUtils.close(bufferedOutputStream);
                BitmapLoadUtils.close(bufferedInputStream);
                BitmapLoadUtils.close(outputStream);
                throw th;
            }
        } catch (Exception e9) {
            e5 = e9;
            outputStream = null;
            bufferedInputStream = null;
            e5.printStackTrace();
            this.mInputUri = this.mOutputUri;
            BitmapLoadUtils.close(bufferedOutputStream);
            BitmapLoadUtils.close(bufferedInputStream);
            BitmapLoadUtils.close(outputStream);
        } catch (Throwable th5) {
            th = th5;
            outputStream = null;
            bufferedInputStream = null;
            this.mInputUri = this.mOutputUri;
            BitmapLoadUtils.close(bufferedOutputStream);
            BitmapLoadUtils.close(bufferedInputStream);
            BitmapLoadUtils.close(outputStream);
            throw th;
        }
        this.mInputUri = this.mOutputUri;
        BitmapLoadUtils.close(bufferedOutputStream);
        BitmapLoadUtils.close(bufferedInputStream);
        BitmapLoadUtils.close(outputStream);
    }

    private String getFilePath() {
        return a.a(this.mContext, "android.permission.READ_EXTERNAL_STORAGE") == 0 ? PictureFileUtils.getPath(this.mContext, this.mInputUri) : "";
    }

    private void processInputUri() {
        String scheme = this.mInputUri.getScheme();
        Log.d(TAG, "Uri scheme: " + scheme);
        if ("http".equals(scheme) || "https".equals(scheme)) {
            try {
                downloadFile(this.mInputUri, this.mOutputUri);
            } catch (IOException | NullPointerException e5) {
                Log.e(TAG, "Downloading failed", e5);
                throw e5;
            }
        } else if ("content".equals(scheme)) {
            String filePath = getFilePath();
            if (TextUtils.isEmpty(filePath) || !new File(filePath).exists()) {
                try {
                    copyFile(this.mInputUri, this.mOutputUri);
                } catch (IOException | NullPointerException e6) {
                    Log.e(TAG, "Copying failed", e6);
                    throw e6;
                }
            } else {
                this.mInputUri = SdkVersionUtils.isQ() ? this.mInputUri : Uri.fromFile(new File(filePath));
            }
        } else if (!"file".equals(scheme)) {
            Log.e(TAG, "Invalid Uri scheme " + scheme);
            throw new IllegalArgumentException("Invalid Uri scheme" + scheme);
        }
    }

    /* access modifiers changed from: protected */
    public BitmapWorkerResult doInBackground(Void... voidArr) {
        int i5;
        if (this.mInputUri == null) {
            return new BitmapWorkerResult(new NullPointerException("Input Uri cannot be null"));
        }
        try {
            processInputUri();
            BitmapFactory.Options options = new BitmapFactory.Options();
            options.inJustDecodeBounds = true;
            int i6 = options.outWidth;
            if (i6 == 0 && options.outHeight == 0) {
                int i7 = this.mInputImageWidth;
                int i8 = this.mInputImageHeight;
                i5 = BitmapLoadUtils.calculateInSampleSize(i7, i8, i7, i8);
            } else {
                i5 = BitmapLoadUtils.calculateInSampleSize(i6, options.outHeight, this.mRequiredWidth, this.mRequiredHeight);
            }
            options.inSampleSize = i5;
            boolean z4 = false;
            options.inJustDecodeBounds = false;
            Bitmap bitmap = null;
            while (!z4) {
                try {
                    bitmap = BitmapFactory.decodeStream(PictureContentResolver.getContentResolverOpenInputStream(this.mContext, this.mInputUri), null, options);
                    if (options.outWidth != -1) {
                        if (options.outHeight != -1) {
                            if (!checkSize(bitmap, options)) {
                                z4 = true;
                            }
                        }
                    }
                    return new BitmapWorkerResult(new IllegalArgumentException("Bounds for bitmap could not be retrieved from the Uri: [" + this.mInputUri + "]"));
                } catch (OutOfMemoryError e5) {
                    Log.e(TAG, "doInBackground: BitmapFactory.decodeFileDescriptor: ", e5);
                    options.inSampleSize *= 2;
                } catch (Exception e6) {
                    Log.e(TAG, "doInBackground: ImageDecoder.createSource: ", e6);
                    return new BitmapWorkerResult(new IllegalArgumentException("Bitmap could not be decoded from the Uri: [" + this.mInputUri + "]", e6));
                }
            }
            if (bitmap == null) {
                return new BitmapWorkerResult(new IllegalArgumentException("Bitmap could not be decoded from the Uri: [" + this.mInputUri + "]"));
            }
            int exifOrientation = BitmapLoadUtils.getExifOrientation(this.mContext, this.mInputUri);
            int exifToDegrees = BitmapLoadUtils.exifToDegrees(exifOrientation);
            int exifToTranslation = BitmapLoadUtils.exifToTranslation(exifOrientation);
            ExifInfo exifInfo = new ExifInfo(exifOrientation, exifToDegrees, exifToTranslation);
            Matrix matrix = new Matrix();
            if (exifToDegrees != 0) {
                matrix.preRotate((float) exifToDegrees);
            }
            if (exifToTranslation != 1) {
                matrix.postScale((float) exifToTranslation, 1.0f);
            }
            return !matrix.isIdentity() ? new BitmapWorkerResult(BitmapLoadUtils.transformBitmap(bitmap, matrix), exifInfo) : new BitmapWorkerResult(bitmap, exifInfo);
        } catch (IOException | NullPointerException e7) {
            return new BitmapWorkerResult(e7);
        }
    }

    /* access modifiers changed from: protected */
    public void onPostExecute(BitmapWorkerResult bitmapWorkerResult) {
        Exception exc = bitmapWorkerResult.mBitmapWorkerException;
        if (exc == null) {
            String uri = this.mInputUri.toString();
            BitmapLoadCallback bitmapLoadCallback = this.mBitmapLoadCallback;
            Bitmap bitmap = bitmapWorkerResult.mBitmapResult;
            ExifInfo exifInfo = bitmapWorkerResult.mExifInfo;
            if (!PictureMimeType.isContent(uri)) {
                uri = this.mInputUri.getPath();
            }
            Uri uri2 = this.mOutputUri;
            bitmapLoadCallback.onBitmapLoaded(bitmap, exifInfo, uri, uri2 == null ? null : uri2.getPath());
            return;
        }
        this.mBitmapLoadCallback.onFailure(exc);
    }
}
