package com.yalantis.ucrop.util;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Point;
import android.net.Uri;
import android.util.Log;
import android.view.WindowManager;
import com.luck.picture.lib.PictureContentResolver;
import com.luck.picture.lib.widget.longimage.SubsamplingScaleImageView;
import com.yalantis.ucrop.callback.BitmapLoadCallback;
import com.yalantis.ucrop.task.BitmapLoadTask;
import java.io.Closeable;
import java.io.IOException;
import java.io.InputStream;
import java.util.concurrent.Executors;

public class BitmapLoadUtils {
    private static final String TAG = "BitmapLoadUtils";

    public static int calculateInSampleSize(int i5, int i6, int i7, int i8) {
        if (i5 == 0 && i6 == 0) {
            return 2;
        }
        if (i5 == i7 && i6 == i8) {
            return 2;
        }
        int i9 = 1;
        if (i6 > i8 || i5 > i7) {
            while (true) {
                if (i6 / i9 <= i8 && i5 / i9 <= i7) {
                    break;
                }
                i9 *= 2;
            }
        }
        return i9;
    }

    public static int calculateMaxBitmapSize(Context context) {
        WindowManager windowManager = (WindowManager) context.getSystemService("window");
        Point point = new Point();
        if (windowManager != null) {
            windowManager.getDefaultDisplay().getSize(point);
        }
        int sqrt = (int) Math.sqrt(Math.pow((double) point.x, 2.0d) + Math.pow((double) point.y, 2.0d));
        Canvas canvas = new Canvas();
        int min = Math.min(canvas.getMaximumBitmapWidth(), canvas.getMaximumBitmapHeight());
        if (min > 0) {
            sqrt = Math.min(sqrt, min);
        }
        int maxTextureSize = EglUtils.getMaxTextureSize();
        if (maxTextureSize > 0) {
            sqrt = Math.min(sqrt, maxTextureSize);
        }
        Log.d(TAG, "maxBitmapSize: " + sqrt);
        return sqrt;
    }

    public static void close(Closeable closeable) {
        if (closeable instanceof Closeable) {
            try {
                closeable.close();
            } catch (IOException unused) {
            }
        }
    }

    public static void decodeBitmapInBackground(Context context, Uri uri, Uri uri2, int i5, int i6, int i7, int i8, BitmapLoadCallback bitmapLoadCallback) {
        new BitmapLoadTask(context, uri, uri2, i5, i6, i7, i8, bitmapLoadCallback).executeOnExecutor(Executors.newCachedThreadPool(), new Void[0]);
    }

    public static int exifToDegrees(int i5) {
        switch (i5) {
            case 3:
            case 4:
                return SubsamplingScaleImageView.ORIENTATION_180;
            case 5:
            case 6:
                return 90;
            case 7:
            case 8:
                return SubsamplingScaleImageView.ORIENTATION_270;
            default:
                return 0;
        }
    }

    public static int exifToTranslation(int i5) {
        return (i5 == 2 || i5 == 7 || i5 == 4 || i5 == 5) ? -1 : 1;
    }

    public static int getExifOrientation(Context context, Uri uri) {
        try {
            InputStream contentResolverOpenInputStream = PictureContentResolver.getContentResolverOpenInputStream(context, uri);
            if (contentResolverOpenInputStream == null) {
                return 0;
            }
            return new ImageHeaderParser(contentResolverOpenInputStream).getOrientation();
        } catch (IOException e5) {
            Log.e(TAG, "getExifOrientation: " + uri.toString(), e5);
            return 0;
        }
    }

    public static Bitmap transformBitmap(Bitmap bitmap, Matrix matrix) {
        try {
            Bitmap createBitmap = Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), matrix, true);
            return !bitmap.sameAs(createBitmap) ? createBitmap : bitmap;
        } catch (OutOfMemoryError e5) {
            Log.e(TAG, "transformBitmap: ", e5);
            return bitmap;
        }
    }
}
