package androidx.core.graphics.drawable;

import android.content.res.ColorStateList;
import android.graphics.Bitmap;
import android.graphics.PorterDuff;
import android.graphics.drawable.Icon;
import android.os.Build;
import android.os.Parcelable;
import android.util.Log;
import androidx.versionedparcelable.CustomVersionedParcelable;
import java.io.ByteArrayOutputStream;
import java.lang.reflect.InvocationTargetException;
import java.nio.charset.Charset;

public class IconCompat extends CustomVersionedParcelable {

    /* renamed from: k  reason: collision with root package name */
    static final PorterDuff.Mode f1941k = PorterDuff.Mode.SRC_IN;

    /* renamed from: a  reason: collision with root package name */
    public int f1942a = -1;

    /* renamed from: b  reason: collision with root package name */
    Object f1943b;

    /* renamed from: c  reason: collision with root package name */
    public byte[] f1944c = null;

    /* renamed from: d  reason: collision with root package name */
    public Parcelable f1945d = null;

    /* renamed from: e  reason: collision with root package name */
    public int f1946e = 0;

    /* renamed from: f  reason: collision with root package name */
    public int f1947f = 0;

    /* renamed from: g  reason: collision with root package name */
    public ColorStateList f1948g = null;

    /* renamed from: h  reason: collision with root package name */
    PorterDuff.Mode f1949h = f1941k;

    /* renamed from: i  reason: collision with root package name */
    public String f1950i = null;

    /* renamed from: j  reason: collision with root package name */
    public String f1951j;

    private static int b(Icon icon) {
        if (Build.VERSION.SDK_INT >= 28) {
            return icon.getResId();
        }
        try {
            return ((Integer) icon.getClass().getMethod("getResId", new Class[0]).invoke(icon, new Object[0])).intValue();
        } catch (IllegalAccessException e5) {
            Log.e("IconCompat", "Unable to get icon resource", e5);
            return 0;
        } catch (InvocationTargetException e6) {
            Log.e("IconCompat", "Unable to get icon resource", e6);
            return 0;
        } catch (NoSuchMethodException e7) {
            Log.e("IconCompat", "Unable to get icon resource", e7);
            return 0;
        }
    }

    private static String e(int i5) {
        switch (i5) {
            case 1:
                return "BITMAP";
            case 2:
                return "RESOURCE";
            case 3:
                return "DATA";
            case 4:
                return "URI";
            case 5:
                return "BITMAP_MASKABLE";
            case 6:
                return "URI_MASKABLE";
            default:
                return "UNKNOWN";
        }
    }

    public int a() {
        int i5 = this.f1942a;
        if (i5 == -1 && Build.VERSION.SDK_INT >= 23) {
            return b((Icon) this.f1943b);
        }
        if (i5 == 2) {
            return this.f1946e;
        }
        throw new IllegalStateException("called getResId() on " + this);
    }

    public void c() {
        Parcelable parcelable;
        this.f1949h = PorterDuff.Mode.valueOf(this.f1950i);
        switch (this.f1942a) {
            case -1:
                parcelable = this.f1945d;
                if (parcelable == null) {
                    throw new IllegalArgumentException("Invalid icon");
                }
                break;
            case 0:
            default:
                return;
            case 1:
            case 5:
                parcelable = this.f1945d;
                if (parcelable == null) {
                    byte[] bArr = this.f1944c;
                    this.f1943b = bArr;
                    this.f1942a = 3;
                    this.f1946e = 0;
                    this.f1947f = bArr.length;
                    return;
                }
                break;
            case 2:
            case 4:
            case 6:
                String str = new String(this.f1944c, Charset.forName("UTF-16"));
                this.f1943b = str;
                if (this.f1942a == 2 && this.f1951j == null) {
                    this.f1951j = str.split(":", -1)[0];
                    return;
                }
                return;
            case 3:
                this.f1943b = this.f1944c;
                return;
        }
        this.f1943b = parcelable;
    }

    public void d(boolean z4) {
        this.f1950i = this.f1949h.name();
        switch (this.f1942a) {
            case -1:
                if (z4) {
                    throw new IllegalArgumentException("Can't serialize Icon created with IconCompat#createFromIcon");
                }
                break;
            case 0:
            default:
                return;
            case 1:
            case 5:
                if (z4) {
                    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                    ((Bitmap) this.f1943b).compress(Bitmap.CompressFormat.PNG, 90, byteArrayOutputStream);
                    this.f1944c = byteArrayOutputStream.toByteArray();
                    return;
                }
                break;
            case 2:
                this.f1944c = ((String) this.f1943b).getBytes(Charset.forName("UTF-16"));
                return;
            case 3:
                this.f1944c = (byte[]) this.f1943b;
                return;
            case 4:
            case 6:
                this.f1944c = this.f1943b.toString().getBytes(Charset.forName("UTF-16"));
                return;
        }
        this.f1945d = (Parcelable) this.f1943b;
    }

    public String toString() {
        int i5;
        if (this.f1942a == -1) {
            return String.valueOf(this.f1943b);
        }
        StringBuilder sb = new StringBuilder("Icon(typ=");
        sb.append(e(this.f1942a));
        switch (this.f1942a) {
            case 1:
            case 5:
                sb.append(" size=");
                sb.append(((Bitmap) this.f1943b).getWidth());
                sb.append("x");
                i5 = ((Bitmap) this.f1943b).getHeight();
                sb.append(i5);
                break;
            case 2:
                sb.append(" pkg=");
                sb.append(this.f1951j);
                sb.append(" id=");
                sb.append(String.format("0x%08x", Integer.valueOf(a())));
                break;
            case 3:
                sb.append(" len=");
                sb.append(this.f1946e);
                if (this.f1947f != 0) {
                    sb.append(" off=");
                    i5 = this.f1947f;
                    sb.append(i5);
                    break;
                }
                break;
            case 4:
            case 6:
                sb.append(" uri=");
                sb.append(this.f1943b);
                break;
        }
        if (this.f1948g != null) {
            sb.append(" tint=");
            sb.append(this.f1948g);
        }
        if (this.f1949h != f1941k) {
            sb.append(" mode=");
            sb.append(this.f1949h);
        }
        sb.append(")");
        return sb.toString();
    }
}
