package com.luck.picture.lib.camera.view;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.AnimatorSet;
import android.animation.ValueAnimator;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.RectF;
import android.os.CountDownTimer;
import android.view.MotionEvent;
import android.view.View;
import com.luck.picture.lib.camera.CheckPermission;
import com.luck.picture.lib.camera.CustomCameraType;
import com.luck.picture.lib.camera.CustomCameraView;
import com.luck.picture.lib.camera.listener.CaptureListener;
import com.luck.picture.lib.tools.DoubleUtils;
import com.yalantis.ucrop.view.CropImageView;

public class CaptureButton extends View {
    public static final int STATE_BAN;
    public static final int STATE_IDLE;
    public static final int STATE_LONG_PRESS;
    public static final int STATE_PRESS;
    public static final int STATE_RECORDERING;
    private float button_inside_radius;
    private float button_outside_radius;
    private float button_radius;
    private int button_size;
    private int button_state;
    private CaptureListener captureLisenter;
    private float center_X;
    private float center_Y;
    private int duration;
    private float event_Y;
    private int inside_color = -1;
    private int inside_reduce_size;
    private boolean isTakeCamera = true;
    private LongPressRunnable longPressRunnable;
    private Paint mPaint;
    private int min_duration;
    private int outside_add_size;
    private int outside_color = -287515428;
    private float progress;
    private int progress_color = -300503530;
    private int recorded_time;
    private RectF rectF;
    private int state;
    private float strokeWidth;
    private RecordCountDownTimer timer;

    public class LongPressRunnable implements Runnable {
        private LongPressRunnable() {
            CaptureButton.this = r1;
        }

        public void run() {
            CaptureButton.this.state = 3;
            if (CheckPermission.getRecordState() != 1) {
                CaptureButton.this.state = 1;
                if (CaptureButton.this.captureLisenter != null) {
                    CaptureButton.this.captureLisenter.recordError();
                    return;
                }
            }
            CaptureButton captureButton = CaptureButton.this;
            captureButton.startRecordAnimation(captureButton.button_outside_radius, CaptureButton.this.button_outside_radius + ((float) CaptureButton.this.outside_add_size), CaptureButton.this.button_inside_radius, CaptureButton.this.button_inside_radius - ((float) CaptureButton.this.inside_reduce_size));
        }
    }

    public class RecordCountDownTimer extends CountDownTimer {
        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        RecordCountDownTimer(long j5, long j6) {
            super(j5, j6);
            CaptureButton.this = r1;
        }

        public void onFinish() {
            CaptureButton.this.recordEnd();
        }

        public void onTick(long j5) {
            CaptureButton.this.updateProgress(j5);
        }
    }

    public CaptureButton(Context context) {
        super(context);
    }

    public CaptureButton(Context context, int i5) {
        super(context);
        this.button_size = i5;
        float f5 = ((float) i5) / 2.0f;
        this.button_radius = f5;
        this.button_outside_radius = f5;
        this.button_inside_radius = f5 * 0.75f;
        this.strokeWidth = (float) (i5 / 15);
        int i6 = i5 / 8;
        this.outside_add_size = i6;
        this.inside_reduce_size = i6;
        Paint paint = new Paint();
        this.mPaint = paint;
        paint.setAntiAlias(true);
        this.progress = CropImageView.DEFAULT_ASPECT_RATIO;
        this.longPressRunnable = new LongPressRunnable();
        this.state = 1;
        this.button_state = CustomCameraType.BUTTON_STATE_BOTH;
        this.duration = 10000;
        this.min_duration = CustomCameraView.DEFAULT_MIN_RECORD_VIDEO;
        int i7 = this.button_size;
        int i8 = this.outside_add_size;
        this.center_X = (float) (((i8 * 2) + i7) / 2);
        this.center_Y = (float) ((i7 + (i8 * 2)) / 2);
        float f6 = this.center_X;
        float f7 = this.button_radius;
        int i9 = this.outside_add_size;
        float f8 = this.strokeWidth;
        float f9 = this.center_Y;
        this.rectF = new RectF(f6 - ((((float) i9) + f7) - (f8 / 2.0f)), f9 - ((((float) i9) + f7) - (f8 / 2.0f)), f6 + ((((float) i9) + f7) - (f8 / 2.0f)), f9 + ((f7 + ((float) i9)) - (f8 / 2.0f)));
        int i10 = this.duration;
        this.timer = new RecordCountDownTimer((long) i10, (long) (i10 / 360));
    }

    private void handlerPressByState() {
        int i5;
        removeCallbacks(this.longPressRunnable);
        int i6 = this.state;
        if (i6 != 2) {
            if (i6 == 3 || i6 == 4) {
                this.timer.cancel();
                recordEnd();
            }
        } else if (this.captureLisenter == null || !((i5 = this.button_state) == 257 || i5 == 259)) {
            this.state = 1;
        } else {
            startCaptureAnimation(this.button_inside_radius);
        }
        this.state = 1;
    }

    /* access modifiers changed from: public */
    private /* synthetic */ void lambda$startCaptureAnimation$0(ValueAnimator valueAnimator) {
        this.button_inside_radius = ((Float) valueAnimator.getAnimatedValue()).floatValue();
        invalidate();
    }

    /* access modifiers changed from: public */
    private /* synthetic */ void lambda$startRecordAnimation$1(ValueAnimator valueAnimator) {
        this.button_outside_radius = ((Float) valueAnimator.getAnimatedValue()).floatValue();
        invalidate();
    }

    /* access modifiers changed from: public */
    private /* synthetic */ void lambda$startRecordAnimation$2(ValueAnimator valueAnimator) {
        this.button_inside_radius = ((Float) valueAnimator.getAnimatedValue()).floatValue();
        invalidate();
    }

    private void resetRecordAnim() {
        this.state = 5;
        this.progress = CropImageView.DEFAULT_ASPECT_RATIO;
        invalidate();
        float f5 = this.button_outside_radius;
        float f6 = this.button_radius;
        startRecordAnimation(f5, f6, this.button_inside_radius, 0.75f * f6);
    }

    private void startCaptureAnimation(float f5) {
        ValueAnimator ofFloat = ValueAnimator.ofFloat(f5, 0.75f * f5, f5);
        ofFloat.addUpdateListener(new b(this));
        ofFloat.addListener(new AnimatorListenerAdapter() {
            /* class com.luck.picture.lib.camera.view.CaptureButton.AnonymousClass1 */

            public void onAnimationEnd(Animator animator) {
                super.onAnimationEnd(animator);
            }

            public void onAnimationStart(Animator animator) {
                super.onAnimationStart(animator);
                if (CaptureButton.this.captureLisenter != null) {
                    CaptureButton.this.captureLisenter.takePictures();
                }
                CaptureButton.this.state = 5;
            }
        });
        ofFloat.setDuration(50L);
        ofFloat.start();
    }

    private void startRecordAnimation(float f5, float f6, float f7, float f8) {
        ValueAnimator ofFloat = ValueAnimator.ofFloat(f5, f6);
        ValueAnimator ofFloat2 = ValueAnimator.ofFloat(f7, f8);
        ofFloat.addUpdateListener(new c(this));
        ofFloat2.addUpdateListener(new a(this));
        AnimatorSet animatorSet = new AnimatorSet();
        animatorSet.addListener(new AnimatorListenerAdapter() {
            /* class com.luck.picture.lib.camera.view.CaptureButton.AnonymousClass2 */

            public void onAnimationEnd(Animator animator) {
                super.onAnimationEnd(animator);
                if (!DoubleUtils.isFastDoubleClick()) {
                    if (CaptureButton.this.state == 3) {
                        if (CaptureButton.this.captureLisenter != null) {
                            CaptureButton.this.captureLisenter.recordStart();
                        }
                        CaptureButton.this.state = 4;
                        CaptureButton.this.timer.start();
                        return;
                    }
                    CaptureButton.this.state = 1;
                }
            }
        });
        animatorSet.playTogether(ofFloat, ofFloat2);
        animatorSet.setDuration(100L);
        animatorSet.start();
    }

    private void updateProgress(long j5) {
        int i5 = this.duration;
        this.recorded_time = (int) (((long) i5) - j5);
        this.progress = 360.0f - ((((float) j5) / ((float) i5)) * 360.0f);
        invalidate();
    }

    public int getButtonFeatures() {
        return this.button_state;
    }

    public boolean isIdle() {
        return this.state == 1;
    }

    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        this.mPaint.setStyle(Paint.Style.FILL);
        this.mPaint.setColor(this.outside_color);
        canvas.drawCircle(this.center_X, this.center_Y, this.button_outside_radius, this.mPaint);
        this.mPaint.setColor(this.inside_color);
        canvas.drawCircle(this.center_X, this.center_Y, this.button_inside_radius, this.mPaint);
        if (this.state == 4) {
            this.mPaint.setColor(this.progress_color);
            this.mPaint.setStyle(Paint.Style.STROKE);
            this.mPaint.setStrokeWidth(this.strokeWidth);
            canvas.drawArc(this.rectF, -90.0f, this.progress, false, this.mPaint);
        }
    }

    public void onMeasure(int i5, int i6) {
        super.onMeasure(i5, i6);
        int i7 = this.button_size;
        int i8 = this.outside_add_size;
        setMeasuredDimension((i8 * 2) + i7, i7 + (i8 * 2));
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        CaptureListener captureListener;
        int i5;
        if (this.isTakeCamera) {
            int action = motionEvent.getAction();
            if (action != 0) {
                if (action == 1) {
                    handlerPressByState();
                } else if (action == 2 && (captureListener = this.captureLisenter) != null && this.state == 4 && ((i5 = this.button_state) == 258 || i5 == 259)) {
                    captureListener.recordZoom(this.event_Y - motionEvent.getY());
                }
            } else if (motionEvent.getPointerCount() <= 1 && this.state == 1) {
                this.event_Y = motionEvent.getY();
                this.state = 2;
                int i6 = this.button_state;
                if (i6 == 258 || i6 == 259) {
                    postDelayed(this.longPressRunnable, 500);
                }
            }
        }
        return true;
    }

    public void recordEnd() {
        CaptureListener captureListener = this.captureLisenter;
        if (captureListener != null) {
            int i5 = this.recorded_time;
            if (i5 < this.min_duration) {
                captureListener.recordShort((long) i5);
            } else {
                captureListener.recordEnd((long) i5);
            }
        }
        resetRecordAnim();
    }

    public void resetState() {
        this.state = 1;
    }

    public void setButtonCaptureEnabled(boolean z4) {
        this.isTakeCamera = z4;
    }

    public void setButtonFeatures(int i5) {
        this.button_state = i5;
    }

    public void setCaptureListener(CaptureListener captureListener) {
        this.captureLisenter = captureListener;
    }

    public void setDuration(int i5) {
        this.duration = i5;
        this.timer = new RecordCountDownTimer((long) i5, (long) (i5 / 360));
    }

    public void setMinDuration(int i5) {
        this.min_duration = i5;
    }
}
