package com.luck.picture.lib.photoview;

import android.content.Context;
import android.graphics.Matrix;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewParent;
import android.view.animation.AccelerateDecelerateInterpolator;
import android.view.animation.Interpolator;
import android.widget.ImageView;
import android.widget.OverScroller;
import com.luck.picture.lib.widget.longimage.SubsamplingScaleImageView;
import com.yalantis.ucrop.view.CropImageView;

public class PhotoViewAttacher implements View.OnTouchListener, View.OnLayoutChangeListener {
    private static final float DEFAULT_MAX_SCALE = 3.0f;
    private static final float DEFAULT_MID_SCALE = 1.75f;
    private static final float DEFAULT_MIN_SCALE = 1.0f;
    private static final int DEFAULT_ZOOM_DURATION = 200;
    private static final int HORIZONTAL_EDGE_BOTH = 2;
    private static final int HORIZONTAL_EDGE_LEFT = 0;
    private static final int HORIZONTAL_EDGE_NONE = -1;
    private static final int HORIZONTAL_EDGE_RIGHT = 1;
    private static final int SINGLE_TOUCH = 1;
    private static final int VERTICAL_EDGE_BOTH = 2;
    private static final int VERTICAL_EDGE_BOTTOM = 1;
    private static final int VERTICAL_EDGE_NONE = -1;
    private static final int VERTICAL_EDGE_TOP = 0;
    private boolean mAllowParentInterceptOnEdge = true;
    private final Matrix mBaseMatrix = new Matrix();
    private float mBaseRotation;
    private boolean mBlockParentIntercept = false;
    private FlingRunnable mCurrentFlingRunnable;
    private final RectF mDisplayRect = new RectF();
    private final Matrix mDrawMatrix = new Matrix();
    private GestureDetector mGestureDetector;
    private int mHorizontalScrollEdge = 2;
    private final ImageView mImageView;
    private Interpolator mInterpolator = new AccelerateDecelerateInterpolator();
    private View.OnLongClickListener mLongClickListener;
    private OnMatrixChangedListener mMatrixChangeListener;
    private final float[] mMatrixValues = new float[9];
    private float mMaxScale = DEFAULT_MAX_SCALE;
    private float mMidScale = DEFAULT_MID_SCALE;
    private float mMinScale = DEFAULT_MIN_SCALE;
    private View.OnClickListener mOnClickListener;
    private OnViewDragListener mOnViewDragListener;
    private OnOutsidePhotoTapListener mOutsidePhotoTapListener;
    private OnPhotoTapListener mPhotoTapListener;
    private OnScaleChangedListener mScaleChangeListener;
    private CustomGestureDetector mScaleDragDetector;
    private ImageView.ScaleType mScaleType = ImageView.ScaleType.FIT_CENTER;
    private OnSingleFlingListener mSingleFlingListener;
    private final Matrix mSuppMatrix = new Matrix();
    private int mVerticalScrollEdge = 2;
    private OnViewTapListener mViewTapListener;
    private int mZoomDuration = DEFAULT_ZOOM_DURATION;
    private boolean mZoomEnabled = true;
    private final OnGestureListener onGestureListener;

    /* access modifiers changed from: package-private */
    /* renamed from: com.luck.picture.lib.photoview.PhotoViewAttacher$4  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass4 {
        static final /* synthetic */ int[] $SwitchMap$android$widget$ImageView$ScaleType;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|1|2|3|4|5|6|(3:7|8|10)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0028 */
        static {
            int[] iArr = new int[ImageView.ScaleType.values().length];
            $SwitchMap$android$widget$ImageView$ScaleType = iArr;
            iArr[ImageView.ScaleType.FIT_CENTER.ordinal()] = 1;
            $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.FIT_START.ordinal()] = 2;
            $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.FIT_END.ordinal()] = 3;
            try {
                $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.FIT_XY.ordinal()] = 4;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    /* access modifiers changed from: private */
    public class AnimatedZoomRunnable implements Runnable {
        private final float mFocalX;
        private final float mFocalY;
        private final long mStartTime = System.currentTimeMillis();
        private final float mZoomEnd;
        private final float mZoomStart;

        public AnimatedZoomRunnable(float f5, float f6, float f7, float f8) {
            this.mFocalX = f7;
            this.mFocalY = f8;
            this.mZoomStart = f5;
            this.mZoomEnd = f6;
        }

        private float interpolate() {
            return PhotoViewAttacher.this.mInterpolator.getInterpolation(Math.min((float) PhotoViewAttacher.DEFAULT_MIN_SCALE, (((float) (System.currentTimeMillis() - this.mStartTime)) * PhotoViewAttacher.DEFAULT_MIN_SCALE) / ((float) PhotoViewAttacher.this.mZoomDuration)));
        }

        public void run() {
            float interpolate = interpolate();
            float f5 = this.mZoomStart;
            PhotoViewAttacher.this.onGestureListener.onScale((f5 + ((this.mZoomEnd - f5) * interpolate)) / PhotoViewAttacher.this.getScale(), this.mFocalX, this.mFocalY);
            if (interpolate < PhotoViewAttacher.DEFAULT_MIN_SCALE) {
                Compat.postOnAnimation(PhotoViewAttacher.this.mImageView, this);
            }
        }
    }

    /* access modifiers changed from: private */
    public class FlingRunnable implements Runnable {
        private int mCurrentX;
        private int mCurrentY;
        private final OverScroller mScroller;

        public FlingRunnable(Context context) {
            this.mScroller = new OverScroller(context);
        }

        public void cancelFling() {
            this.mScroller.forceFinished(true);
        }

        public void fling(int i5, int i6, int i7, int i8) {
            int i9;
            int i10;
            int i11;
            int i12;
            RectF displayRect = PhotoViewAttacher.this.getDisplayRect();
            if (displayRect != null) {
                int round = Math.round(-displayRect.left);
                float f5 = (float) i5;
                if (f5 < displayRect.width()) {
                    i9 = Math.round(displayRect.width() - f5);
                    i10 = 0;
                } else {
                    i10 = round;
                    i9 = i10;
                }
                int round2 = Math.round(-displayRect.top);
                float f6 = (float) i6;
                if (f6 < displayRect.height()) {
                    i11 = Math.round(displayRect.height() - f6);
                    i12 = 0;
                } else {
                    i12 = round2;
                    i11 = i12;
                }
                this.mCurrentX = round;
                this.mCurrentY = round2;
                if (round != i9 || round2 != i11) {
                    this.mScroller.fling(round, round2, i7, i8, i10, i9, i12, i11, 0, 0);
                }
            }
        }

        public void run() {
            if (!this.mScroller.isFinished() && this.mScroller.computeScrollOffset()) {
                int currX = this.mScroller.getCurrX();
                int currY = this.mScroller.getCurrY();
                PhotoViewAttacher.this.mSuppMatrix.postTranslate((float) (this.mCurrentX - currX), (float) (this.mCurrentY - currY));
                PhotoViewAttacher.this.checkAndDisplayMatrix();
                this.mCurrentX = currX;
                this.mCurrentY = currY;
                Compat.postOnAnimation(PhotoViewAttacher.this.mImageView, this);
            }
        }
    }

    public PhotoViewAttacher(ImageView imageView) {
        AnonymousClass1 r02 = new OnGestureListener() {
            /* class com.luck.picture.lib.photoview.PhotoViewAttacher.AnonymousClass1 */

            @Override // com.luck.picture.lib.photoview.OnGestureListener
            public void onDrag(float f5, float f6) {
                if (!PhotoViewAttacher.this.mScaleDragDetector.isScaling()) {
                    if (PhotoViewAttacher.this.mOnViewDragListener != null) {
                        PhotoViewAttacher.this.mOnViewDragListener.onDrag(f5, f6);
                    }
                    PhotoViewAttacher.this.mSuppMatrix.postTranslate(f5, f6);
                    PhotoViewAttacher.this.checkAndDisplayMatrix();
                    ViewParent parent = PhotoViewAttacher.this.mImageView.getParent();
                    if (!PhotoViewAttacher.this.mAllowParentInterceptOnEdge || PhotoViewAttacher.this.mScaleDragDetector.isScaling() || PhotoViewAttacher.this.mBlockParentIntercept) {
                        if (parent != null) {
                            parent.requestDisallowInterceptTouchEvent(true);
                        }
                    } else if ((PhotoViewAttacher.this.mHorizontalScrollEdge == 2 || ((PhotoViewAttacher.this.mHorizontalScrollEdge == 0 && f5 >= PhotoViewAttacher.DEFAULT_MIN_SCALE) || ((PhotoViewAttacher.this.mHorizontalScrollEdge == 1 && f5 <= -1.0f) || ((PhotoViewAttacher.this.mVerticalScrollEdge == 0 && f6 >= PhotoViewAttacher.DEFAULT_MIN_SCALE) || (PhotoViewAttacher.this.mVerticalScrollEdge == 1 && f6 <= -1.0f))))) && parent != null) {
                        parent.requestDisallowInterceptTouchEvent(false);
                    }
                }
            }

            @Override // com.luck.picture.lib.photoview.OnGestureListener
            public void onFling(float f5, float f6, float f7, float f8) {
                PhotoViewAttacher photoViewAttacher = PhotoViewAttacher.this;
                photoViewAttacher.mCurrentFlingRunnable = new FlingRunnable(photoViewAttacher.mImageView.getContext());
                FlingRunnable flingRunnable = PhotoViewAttacher.this.mCurrentFlingRunnable;
                PhotoViewAttacher photoViewAttacher2 = PhotoViewAttacher.this;
                int imageViewWidth = photoViewAttacher2.getImageViewWidth(photoViewAttacher2.mImageView);
                PhotoViewAttacher photoViewAttacher3 = PhotoViewAttacher.this;
                flingRunnable.fling(imageViewWidth, photoViewAttacher3.getImageViewHeight(photoViewAttacher3.mImageView), (int) f7, (int) f8);
                PhotoViewAttacher.this.mImageView.post(PhotoViewAttacher.this.mCurrentFlingRunnable);
            }

            @Override // com.luck.picture.lib.photoview.OnGestureListener
            public void onScale(float f5, float f6, float f7) {
                onScale(f5, f6, f7, CropImageView.DEFAULT_ASPECT_RATIO, CropImageView.DEFAULT_ASPECT_RATIO);
            }

            @Override // com.luck.picture.lib.photoview.OnGestureListener
            public void onScale(float f5, float f6, float f7, float f8, float f9) {
                if (PhotoViewAttacher.this.getScale() < PhotoViewAttacher.this.mMaxScale || f5 < PhotoViewAttacher.DEFAULT_MIN_SCALE) {
                    if (PhotoViewAttacher.this.mScaleChangeListener != null) {
                        PhotoViewAttacher.this.mScaleChangeListener.onScaleChange(f5, f6, f7);
                    }
                    PhotoViewAttacher.this.mSuppMatrix.postScale(f5, f5, f6, f7);
                    PhotoViewAttacher.this.mSuppMatrix.postTranslate(f8, f9);
                    PhotoViewAttacher.this.checkAndDisplayMatrix();
                }
            }
        };
        this.onGestureListener = r02;
        this.mImageView = imageView;
        imageView.setOnTouchListener(this);
        imageView.addOnLayoutChangeListener(this);
        if (!imageView.isInEditMode()) {
            this.mBaseRotation = CropImageView.DEFAULT_ASPECT_RATIO;
            this.mScaleDragDetector = new CustomGestureDetector(imageView.getContext(), r02);
            GestureDetector gestureDetector = new GestureDetector(imageView.getContext(), new GestureDetector.SimpleOnGestureListener() {
                /* class com.luck.picture.lib.photoview.PhotoViewAttacher.AnonymousClass2 */

                public boolean onFling(MotionEvent motionEvent, MotionEvent motionEvent2, float f5, float f6) {
                    if (PhotoViewAttacher.this.mSingleFlingListener == null || PhotoViewAttacher.this.getScale() > PhotoViewAttacher.DEFAULT_MIN_SCALE || motionEvent.getPointerCount() > 1 || motionEvent2.getPointerCount() > 1) {
                        return false;
                    }
                    return PhotoViewAttacher.this.mSingleFlingListener.onFling(motionEvent, motionEvent2, f5, f6);
                }

                public void onLongPress(MotionEvent motionEvent) {
                    if (PhotoViewAttacher.this.mLongClickListener != null) {
                        PhotoViewAttacher.this.mLongClickListener.onLongClick(PhotoViewAttacher.this.mImageView);
                    }
                }
            });
            this.mGestureDetector = gestureDetector;
            gestureDetector.setOnDoubleTapListener(new GestureDetector.OnDoubleTapListener() {
                /* class com.luck.picture.lib.photoview.PhotoViewAttacher.AnonymousClass3 */

                public boolean onDoubleTap(MotionEvent motionEvent) {
                    PhotoViewAttacher photoViewAttacher;
                    float minimumScale;
                    try {
                        float scale = PhotoViewAttacher.this.getScale();
                        float x5 = motionEvent.getX();
                        float y5 = motionEvent.getY();
                        if (scale < PhotoViewAttacher.this.getMediumScale()) {
                            photoViewAttacher = PhotoViewAttacher.this;
                            minimumScale = photoViewAttacher.getMediumScale();
                        } else if (scale < PhotoViewAttacher.this.getMediumScale() || scale >= PhotoViewAttacher.this.getMaximumScale()) {
                            photoViewAttacher = PhotoViewAttacher.this;
                            minimumScale = photoViewAttacher.getMinimumScale();
                        } else {
                            photoViewAttacher = PhotoViewAttacher.this;
                            minimumScale = photoViewAttacher.getMaximumScale();
                        }
                        photoViewAttacher.setScale(minimumScale, x5, y5, true);
                    } catch (ArrayIndexOutOfBoundsException unused) {
                    }
                    return true;
                }

                public boolean onDoubleTapEvent(MotionEvent motionEvent) {
                    return false;
                }

                public boolean onSingleTapConfirmed(MotionEvent motionEvent) {
                    if (PhotoViewAttacher.this.mOnClickListener != null) {
                        PhotoViewAttacher.this.mOnClickListener.onClick(PhotoViewAttacher.this.mImageView);
                    }
                    RectF displayRect = PhotoViewAttacher.this.getDisplayRect();
                    float x5 = motionEvent.getX();
                    float y5 = motionEvent.getY();
                    if (PhotoViewAttacher.this.mViewTapListener != null) {
                        PhotoViewAttacher.this.mViewTapListener.onViewTap(PhotoViewAttacher.this.mImageView, x5, y5);
                    }
                    if (displayRect == null) {
                        return false;
                    }
                    if (displayRect.contains(x5, y5)) {
                        float width = (x5 - displayRect.left) / displayRect.width();
                        float height = (y5 - displayRect.top) / displayRect.height();
                        if (PhotoViewAttacher.this.mPhotoTapListener == null) {
                            return true;
                        }
                        PhotoViewAttacher.this.mPhotoTapListener.onPhotoTap(PhotoViewAttacher.this.mImageView, width, height);
                        return true;
                    } else if (PhotoViewAttacher.this.mOutsidePhotoTapListener == null) {
                        return false;
                    } else {
                        PhotoViewAttacher.this.mOutsidePhotoTapListener.onOutsidePhotoTap(PhotoViewAttacher.this.mImageView);
                        return false;
                    }
                }
            });
        }
    }

    private void cancelFling() {
        FlingRunnable flingRunnable = this.mCurrentFlingRunnable;
        if (flingRunnable != null) {
            flingRunnable.cancelFling();
            this.mCurrentFlingRunnable = null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void checkAndDisplayMatrix() {
        if (checkMatrixBounds()) {
            setImageViewMatrix(getDrawMatrix());
        }
    }

    private boolean checkMatrixBounds() {
        float f5;
        RectF displayRect = getDisplayRect(getDrawMatrix());
        if (displayRect == null) {
            return false;
        }
        float height = displayRect.height();
        float width = displayRect.width();
        float imageViewHeight = (float) getImageViewHeight(this.mImageView);
        float f6 = CropImageView.DEFAULT_ASPECT_RATIO;
        if (height <= imageViewHeight) {
            int i5 = AnonymousClass4.$SwitchMap$android$widget$ImageView$ScaleType[this.mScaleType.ordinal()];
            if (i5 != 2) {
                float f7 = imageViewHeight - height;
                if (i5 != 3) {
                    f7 /= 2.0f;
                }
                f5 = f7 - displayRect.top;
            } else {
                f5 = -displayRect.top;
            }
            this.mVerticalScrollEdge = 2;
        } else {
            float f8 = displayRect.top;
            if (f8 > CropImageView.DEFAULT_ASPECT_RATIO) {
                this.mVerticalScrollEdge = 0;
                f5 = -f8;
            } else {
                float f9 = displayRect.bottom;
                if (f9 < imageViewHeight) {
                    this.mVerticalScrollEdge = 1;
                    f5 = imageViewHeight - f9;
                } else {
                    this.mVerticalScrollEdge = -1;
                    f5 = CropImageView.DEFAULT_ASPECT_RATIO;
                }
            }
        }
        float imageViewWidth = (float) getImageViewWidth(this.mImageView);
        if (width <= imageViewWidth) {
            int i6 = AnonymousClass4.$SwitchMap$android$widget$ImageView$ScaleType[this.mScaleType.ordinal()];
            if (i6 != 2) {
                float f10 = imageViewWidth - width;
                if (i6 != 3) {
                    f10 /= 2.0f;
                }
                f6 = f10 - displayRect.left;
            } else {
                f6 = -displayRect.left;
            }
            this.mHorizontalScrollEdge = 2;
        } else {
            float f11 = displayRect.left;
            if (f11 > CropImageView.DEFAULT_ASPECT_RATIO) {
                this.mHorizontalScrollEdge = 0;
                f6 = -f11;
            } else {
                float f12 = displayRect.right;
                if (f12 < imageViewWidth) {
                    f6 = imageViewWidth - f12;
                    this.mHorizontalScrollEdge = 1;
                } else {
                    this.mHorizontalScrollEdge = -1;
                }
            }
        }
        this.mSuppMatrix.postTranslate(f6, f5);
        return true;
    }

    private RectF getDisplayRect(Matrix matrix) {
        Drawable drawable = this.mImageView.getDrawable();
        if (drawable == null) {
            return null;
        }
        this.mDisplayRect.set(CropImageView.DEFAULT_ASPECT_RATIO, CropImageView.DEFAULT_ASPECT_RATIO, (float) drawable.getIntrinsicWidth(), (float) drawable.getIntrinsicHeight());
        matrix.mapRect(this.mDisplayRect);
        return this.mDisplayRect;
    }

    private Matrix getDrawMatrix() {
        this.mDrawMatrix.set(this.mBaseMatrix);
        this.mDrawMatrix.postConcat(this.mSuppMatrix);
        return this.mDrawMatrix;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getImageViewHeight(ImageView imageView) {
        return (imageView.getHeight() - imageView.getPaddingTop()) - imageView.getPaddingBottom();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getImageViewWidth(ImageView imageView) {
        return (imageView.getWidth() - imageView.getPaddingLeft()) - imageView.getPaddingRight();
    }

    private float getValue(Matrix matrix, int i5) {
        matrix.getValues(this.mMatrixValues);
        return this.mMatrixValues[i5];
    }

    private void resetMatrix() {
        this.mSuppMatrix.reset();
        setRotationBy(this.mBaseRotation);
        setImageViewMatrix(getDrawMatrix());
        checkMatrixBounds();
    }

    private void setImageViewMatrix(Matrix matrix) {
        RectF displayRect;
        this.mImageView.setImageMatrix(matrix);
        if (this.mMatrixChangeListener != null && (displayRect = getDisplayRect(matrix)) != null) {
            this.mMatrixChangeListener.onMatrixChanged(displayRect);
        }
    }

    private void updateBaseMatrix(Drawable drawable) {
        Matrix matrix;
        Matrix.ScaleToFit scaleToFit;
        float min;
        if (drawable != null) {
            float imageViewWidth = (float) getImageViewWidth(this.mImageView);
            float imageViewHeight = (float) getImageViewHeight(this.mImageView);
            int intrinsicWidth = drawable.getIntrinsicWidth();
            int intrinsicHeight = drawable.getIntrinsicHeight();
            this.mBaseMatrix.reset();
            float f5 = (float) intrinsicWidth;
            float f6 = imageViewWidth / f5;
            float f7 = (float) intrinsicHeight;
            float f8 = imageViewHeight / f7;
            ImageView.ScaleType scaleType = this.mScaleType;
            if (scaleType == ImageView.ScaleType.CENTER) {
                this.mBaseMatrix.postTranslate((imageViewWidth - f5) / 2.0f, (imageViewHeight - f7) / 2.0f);
            } else {
                if (scaleType == ImageView.ScaleType.CENTER_CROP) {
                    min = Math.max(f6, f8);
                } else if (scaleType == ImageView.ScaleType.CENTER_INSIDE) {
                    min = Math.min((float) DEFAULT_MIN_SCALE, Math.min(f6, f8));
                } else {
                    RectF rectF = new RectF(CropImageView.DEFAULT_ASPECT_RATIO, CropImageView.DEFAULT_ASPECT_RATIO, f5, f7);
                    RectF rectF2 = new RectF(CropImageView.DEFAULT_ASPECT_RATIO, CropImageView.DEFAULT_ASPECT_RATIO, imageViewWidth, imageViewHeight);
                    if (((int) this.mBaseRotation) % SubsamplingScaleImageView.ORIENTATION_180 != 0) {
                        rectF = new RectF(CropImageView.DEFAULT_ASPECT_RATIO, CropImageView.DEFAULT_ASPECT_RATIO, f7, f5);
                    }
                    int i5 = AnonymousClass4.$SwitchMap$android$widget$ImageView$ScaleType[this.mScaleType.ordinal()];
                    if (i5 == 1) {
                        matrix = this.mBaseMatrix;
                        scaleToFit = Matrix.ScaleToFit.CENTER;
                    } else if (i5 == 2) {
                        matrix = this.mBaseMatrix;
                        scaleToFit = Matrix.ScaleToFit.START;
                    } else if (i5 == 3) {
                        matrix = this.mBaseMatrix;
                        scaleToFit = Matrix.ScaleToFit.END;
                    } else if (i5 == 4) {
                        matrix = this.mBaseMatrix;
                        scaleToFit = Matrix.ScaleToFit.FILL;
                    }
                    matrix.setRectToRect(rectF, rectF2, scaleToFit);
                }
                this.mBaseMatrix.postScale(min, min);
                this.mBaseMatrix.postTranslate((imageViewWidth - (f5 * min)) / 2.0f, (imageViewHeight - (f7 * min)) / 2.0f);
            }
            resetMatrix();
        }
    }

    public void getDisplayMatrix(Matrix matrix) {
        matrix.set(getDrawMatrix());
    }

    public RectF getDisplayRect() {
        checkMatrixBounds();
        return getDisplayRect(getDrawMatrix());
    }

    public Matrix getImageMatrix() {
        return this.mDrawMatrix;
    }

    public float getMaximumScale() {
        return this.mMaxScale;
    }

    public float getMediumScale() {
        return this.mMidScale;
    }

    public float getMinimumScale() {
        return this.mMinScale;
    }

    public float getScale() {
        return (float) Math.sqrt((double) (((float) Math.pow((double) getValue(this.mSuppMatrix, 0), 2.0d)) + ((float) Math.pow((double) getValue(this.mSuppMatrix, 3), 2.0d))));
    }

    public ImageView.ScaleType getScaleType() {
        return this.mScaleType;
    }

    public void getSuppMatrix(Matrix matrix) {
        matrix.set(this.mSuppMatrix);
    }

    @Deprecated
    public boolean isZoomEnabled() {
        return this.mZoomEnabled;
    }

    public boolean isZoomable() {
        return this.mZoomEnabled;
    }

    public void onLayoutChange(View view, int i5, int i6, int i7, int i8, int i9, int i10, int i11, int i12) {
        if (i5 != i9 || i6 != i10 || i7 != i11 || i8 != i12) {
            updateBaseMatrix(this.mImageView.getDrawable());
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:27:0x007c  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00af  */
    public boolean onTouch(View view, MotionEvent motionEvent) {
        boolean z4;
        CustomGestureDetector customGestureDetector;
        boolean z5;
        GestureDetector gestureDetector;
        AnimatedZoomRunnable animatedZoomRunnable;
        RectF displayRect;
        boolean z6 = false;
        if (!this.mZoomEnabled || !Util.hasDrawable((ImageView) view)) {
            return false;
        }
        int action = motionEvent.getAction();
        if (action == 0) {
            ViewParent parent = view.getParent();
            if (parent != null) {
                parent.requestDisallowInterceptTouchEvent(true);
            }
            cancelFling();
        } else if (action == 1 || action == 3) {
            if (getScale() < this.mMinScale) {
                RectF displayRect2 = getDisplayRect();
                if (displayRect2 != null) {
                    animatedZoomRunnable = new AnimatedZoomRunnable(getScale(), this.mMinScale, displayRect2.centerX(), displayRect2.centerY());
                }
            } else if (getScale() > this.mMaxScale && (displayRect = getDisplayRect()) != null) {
                animatedZoomRunnable = new AnimatedZoomRunnable(getScale(), this.mMaxScale, displayRect.centerX(), displayRect.centerY());
            }
            view.post(animatedZoomRunnable);
            z4 = true;
            customGestureDetector = this.mScaleDragDetector;
            if (customGestureDetector == null) {
                boolean isScaling = customGestureDetector.isScaling();
                boolean isDragging = this.mScaleDragDetector.isDragging();
                boolean onTouchEvent = this.mScaleDragDetector.onTouchEvent(motionEvent);
                boolean z7 = !isScaling && !this.mScaleDragDetector.isScaling();
                boolean z8 = !isDragging && !this.mScaleDragDetector.isDragging();
                if (z7 && z8) {
                    z6 = true;
                }
                this.mBlockParentIntercept = z6;
                z5 = onTouchEvent;
            } else {
                z5 = z4;
            }
            gestureDetector = this.mGestureDetector;
            if (gestureDetector == null && gestureDetector.onTouchEvent(motionEvent)) {
                return true;
            }
        }
        z4 = false;
        customGestureDetector = this.mScaleDragDetector;
        if (customGestureDetector == null) {
        }
        gestureDetector = this.mGestureDetector;
        return gestureDetector == null ? z5 : z5;
    }

    public void setAllowParentInterceptOnEdge(boolean z4) {
        this.mAllowParentInterceptOnEdge = z4;
    }

    public void setBaseRotation(float f5) {
        this.mBaseRotation = f5 % 360.0f;
        update();
        setRotationBy(this.mBaseRotation);
        checkAndDisplayMatrix();
    }

    public boolean setDisplayMatrix(Matrix matrix) {
        if (matrix == null) {
            throw new IllegalArgumentException("Matrix cannot be null");
        } else if (this.mImageView.getDrawable() == null) {
            return false;
        } else {
            this.mSuppMatrix.set(matrix);
            checkAndDisplayMatrix();
            return true;
        }
    }

    public void setMaximumScale(float f5) {
        Util.checkZoomLevels(this.mMinScale, this.mMidScale, f5);
        this.mMaxScale = f5;
    }

    public void setMediumScale(float f5) {
        Util.checkZoomLevels(this.mMinScale, f5, this.mMaxScale);
        this.mMidScale = f5;
    }

    public void setMinimumScale(float f5) {
        Util.checkZoomLevels(f5, this.mMidScale, this.mMaxScale);
        this.mMinScale = f5;
    }

    public void setOnClickListener(View.OnClickListener onClickListener) {
        this.mOnClickListener = onClickListener;
    }

    public void setOnDoubleTapListener(GestureDetector.OnDoubleTapListener onDoubleTapListener) {
        this.mGestureDetector.setOnDoubleTapListener(onDoubleTapListener);
    }

    public void setOnLongClickListener(View.OnLongClickListener onLongClickListener) {
        this.mLongClickListener = onLongClickListener;
    }

    public void setOnMatrixChangeListener(OnMatrixChangedListener onMatrixChangedListener) {
        this.mMatrixChangeListener = onMatrixChangedListener;
    }

    public void setOnOutsidePhotoTapListener(OnOutsidePhotoTapListener onOutsidePhotoTapListener) {
        this.mOutsidePhotoTapListener = onOutsidePhotoTapListener;
    }

    public void setOnPhotoTapListener(OnPhotoTapListener onPhotoTapListener) {
        this.mPhotoTapListener = onPhotoTapListener;
    }

    public void setOnScaleChangeListener(OnScaleChangedListener onScaleChangedListener) {
        this.mScaleChangeListener = onScaleChangedListener;
    }

    public void setOnSingleFlingListener(OnSingleFlingListener onSingleFlingListener) {
        this.mSingleFlingListener = onSingleFlingListener;
    }

    public void setOnViewDragListener(OnViewDragListener onViewDragListener) {
        this.mOnViewDragListener = onViewDragListener;
    }

    public void setOnViewTapListener(OnViewTapListener onViewTapListener) {
        this.mViewTapListener = onViewTapListener;
    }

    public void setRotationBy(float f5) {
        this.mSuppMatrix.postRotate(f5 % 360.0f);
        checkAndDisplayMatrix();
    }

    public void setRotationTo(float f5) {
        this.mSuppMatrix.setRotate(f5 % 360.0f);
        checkAndDisplayMatrix();
    }

    public void setScale(float f5) {
        setScale(f5, false);
    }

    public void setScale(float f5, float f6, float f7, boolean z4) {
        if (f5 < this.mMinScale || f5 > this.mMaxScale) {
            throw new IllegalArgumentException("Scale must be within the range of minScale and maxScale");
        } else if (z4) {
            this.mImageView.post(new AnimatedZoomRunnable(getScale(), f5, f6, f7));
        } else {
            this.mSuppMatrix.setScale(f5, f5, f6, f7);
            checkAndDisplayMatrix();
        }
    }

    public void setScale(float f5, boolean z4) {
        setScale(f5, (float) (this.mImageView.getRight() / 2), (float) (this.mImageView.getBottom() / 2), z4);
    }

    public void setScaleLevels(float f5, float f6, float f7) {
        Util.checkZoomLevels(f5, f6, f7);
        this.mMinScale = f5;
        this.mMidScale = f6;
        this.mMaxScale = f7;
    }

    public void setScaleType(ImageView.ScaleType scaleType) {
        if (Util.isSupportedScaleType(scaleType) && scaleType != this.mScaleType) {
            this.mScaleType = scaleType;
            update();
        }
    }

    public void setZoomInterpolator(Interpolator interpolator) {
        this.mInterpolator = interpolator;
    }

    public void setZoomTransitionDuration(int i5) {
        this.mZoomDuration = i5;
    }

    public void setZoomable(boolean z4) {
        this.mZoomEnabled = z4;
        update();
    }

    public void update() {
        if (this.mZoomEnabled) {
            updateBaseMatrix(this.mImageView.getDrawable());
        } else {
            resetMatrix();
        }
    }
}
